/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison implementation for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output, and Bison version.  */
#define YYBISON 30802

/* Bison version string.  */
#define YYBISON_VERSION "3.8.2"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1

/* Substitute the type names.  */
#define YYSTYPE         YLSTYPE
/* Substitute the variable and function names.  */
#define yyparse         ylparse
#define yylex           yllex
#define yyerror         ylerror
#define yydebug         yldebug
#define yynerrs         ylnerrs
#define yylval          yllval
#define yychar          ylchar

/* First part of user prologue.  */
#line 27 "llgrammar.y"


# include "splintMacros.nf"
# include "basic.h"
# include "lclscan.h"
# include "checking.h"
# include "lslparse.h" 
# include "lh.h"
# include "usymtab_interface.h"

/*@constant int YYDEBUG;@*/
# define YYDEBUG 0

/*
** This is necessary, or else when the bison-generated code #include's malloc.h,
** there will be a parse error.
**
** Unfortunately, it means the error checking on malloc, etc. is lost for allocations
** in bison-generated files under Win32.
*/

# ifdef WIN32
# undef malloc
# undef calloc
# undef realloc
# endif


#line 108 "llgrammar.c"

# ifndef YY_CAST
#  ifdef __cplusplus
#   define YY_CAST(Type, Val) static_cast<Type> (Val)
#   define YY_REINTERPRET_CAST(Type, Val) reinterpret_cast<Type> (Val)
#  else
#   define YY_CAST(Type, Val) ((Type) (Val))
#   define YY_REINTERPRET_CAST(Type, Val) ((Type) (Val))
#  endif
# endif
# ifndef YY_NULLPTR
#  if defined __cplusplus
#   if 201103L <= __cplusplus
#    define YY_NULLPTR nullptr
#   else
#    define YY_NULLPTR 0
#   endif
#  else
#   define YY_NULLPTR ((void*)0)
#  endif
# endif

/* Use api.header.include to #include this header
   instead of duplicating it here.  */
#ifndef YY_YL_LLGRAMMAR_H_INCLUDED
# define YY_YL_LLGRAMMAR_H_INCLUDED
/* Debug traces.  */
#ifndef YLDEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define YLDEBUG 1
#  else
#   define YLDEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define YLDEBUG 0
# endif /* ! defined YYDEBUG */
#endif  /* ! defined YLDEBUG */
#if YLDEBUG
extern int yldebug;
#endif

/* Token kinds.  */
#ifndef YLTOKENTYPE
# define YLTOKENTYPE
  enum yltokentype
  {
    YLEMPTY = -2,
    YLEOF = 0,                     /* "end of file"  */
    YLerror = 256,                 /* error  */
    YLUNDEF = 257,                 /* "invalid token"  */
    PREFIX_OP = 258,               /* PREFIX_OP  */
    POSTFIX_OP = 259,              /* POSTFIX_OP  */
    ITERATION_OP = 260,            /* ITERATION_OP  */
    LLT_IF_THEN_ELSE = 261,        /* LLT_IF_THEN_ELSE  */
    eqSepSym = 262,                /* eqSepSym  */
    equationSym = 263,             /* equationSym  */
    commentSym = 264,              /* commentSym  */
    LLT_WHITESPACE = 265,          /* LLT_WHITESPACE  */
    LLT_EOL = 266,                 /* LLT_EOL  */
    LLT_TYPEDEF_NAME = 267,        /* LLT_TYPEDEF_NAME  */
    quantifierSym = 268,           /* quantifierSym  */
    logicalOp = 269,               /* logicalOp  */
    selectSym = 270,               /* selectSym  */
    openSym = 271,                 /* openSym  */
    closeSym = 272,                /* closeSym  */
    sepSym = 273,                  /* sepSym  */
    simpleId = 274,                /* simpleId  */
    mapSym = 275,                  /* mapSym  */
    markerSym = 276,               /* markerSym  */
    preSym = 277,                  /* preSym  */
    postSym = 278,                 /* postSym  */
    anySym = 279,                  /* anySym  */
    simpleOp = 280,                /* simpleOp  */
    LLT_COLON = 281,               /* LLT_COLON  */
    LLT_COMMA = 282,               /* LLT_COMMA  */
    LLT_EQUALS = 283,              /* LLT_EQUALS  */
    LLT_LBRACE = 284,              /* LLT_LBRACE  */
    LLT_RBRACE = 285,              /* LLT_RBRACE  */
    LLT_LBRACKET = 286,            /* LLT_LBRACKET  */
    LLT_RBRACKET = 287,            /* LLT_RBRACKET  */
    LLT_LPAR = 288,                /* LLT_LPAR  */
    LLT_RPAR = 289,                /* LLT_RPAR  */
    LLT_QUOTE = 290,               /* LLT_QUOTE  */
    LLT_SEMI = 291,                /* LLT_SEMI  */
    LLT_VERTICALBAR = 292,         /* LLT_VERTICALBAR  */
    eqOp = 293,                    /* eqOp  */
    LLT_MULOP = 294,               /* LLT_MULOP  */
    LLT_CCHAR = 295,               /* LLT_CCHAR  */
    LLT_CFLOAT = 296,              /* LLT_CFLOAT  */
    LLT_CINTEGER = 297,            /* LLT_CINTEGER  */
    LLT_LCSTRING = 298,            /* LLT_LCSTRING  */
    LLT_ALL = 299,                 /* LLT_ALL  */
    LLT_ANYTHING = 300,            /* LLT_ANYTHING  */
    LLT_BE = 301,                  /* LLT_BE  */
    LLT_BODY = 302,                /* LLT_BODY  */
    LLT_CLAIMS = 303,              /* LLT_CLAIMS  */
    LLT_CHECKS = 304,              /* LLT_CHECKS  */
    LLT_CONSTANT = 305,            /* LLT_CONSTANT  */
    LLT_ELSE = 306,                /* LLT_ELSE  */
    LLT_ENSURES = 307,             /* LLT_ENSURES  */
    LLT_FOR = 308,                 /* LLT_FOR  */
    LLT_FRESH = 309,               /* LLT_FRESH  */
    LLT_IF = 310,                  /* LLT_IF  */
    LLT_IMMUTABLE = 311,           /* LLT_IMMUTABLE  */
    LLT_IMPORTS = 312,             /* LLT_IMPORTS  */
    LLT_CONSTRAINT = 313,          /* LLT_CONSTRAINT  */
    LLT_ISSUB = 314,               /* LLT_ISSUB  */
    LLT_LET = 315,                 /* LLT_LET  */
    LLT_MODIFIES = 316,            /* LLT_MODIFIES  */
    LLT_MUTABLE = 317,             /* LLT_MUTABLE  */
    LLT_NOTHING = 318,             /* LLT_NOTHING  */
    LLT_INTERNAL = 319,            /* LLT_INTERNAL  */
    LLT_FILESYS = 320,             /* LLT_FILESYS  */
    LLT_OBJ = 321,                 /* LLT_OBJ  */
    LLT_OUT = 322,                 /* LLT_OUT  */
    LLT_SEF = 323,                 /* LLT_SEF  */
    LLT_ONLY = 324,                /* LLT_ONLY  */
    LLT_PARTIAL = 325,             /* LLT_PARTIAL  */
    LLT_OWNED = 326,               /* LLT_OWNED  */
    LLT_DEPENDENT = 327,           /* LLT_DEPENDENT  */
    LLT_KEEP = 328,                /* LLT_KEEP  */
    LLT_KEPT = 329,                /* LLT_KEPT  */
    LLT_TEMP = 330,                /* LLT_TEMP  */
    LLT_SHARED = 331,              /* LLT_SHARED  */
    LLT_UNIQUE = 332,              /* LLT_UNIQUE  */
    LLT_UNUSED = 333,              /* LLT_UNUSED  */
    LLT_EXITS = 334,               /* LLT_EXITS  */
    LLT_MAYEXIT = 335,             /* LLT_MAYEXIT  */
    LLT_NEVEREXIT = 336,           /* LLT_NEVEREXIT  */
    LLT_TRUEEXIT = 337,            /* LLT_TRUEEXIT  */
    LLT_FALSEEXIT = 338,           /* LLT_FALSEEXIT  */
    LLT_UNDEF = 339,               /* LLT_UNDEF  */
    LLT_KILLED = 340,              /* LLT_KILLED  */
    LLT_CHECKMOD = 341,            /* LLT_CHECKMOD  */
    LLT_CHECKED = 342,             /* LLT_CHECKED  */
    LLT_UNCHECKED = 343,           /* LLT_UNCHECKED  */
    LLT_CHECKEDSTRICT = 344,       /* LLT_CHECKEDSTRICT  */
    LLT_TRUENULL = 345,            /* LLT_TRUENULL  */
    LLT_FALSENULL = 346,           /* LLT_FALSENULL  */
    LLT_LNULL = 347,               /* LLT_LNULL  */
    LLT_LNOTNULL = 348,            /* LLT_LNOTNULL  */
    LLT_RETURNED = 349,            /* LLT_RETURNED  */
    LLT_OBSERVER = 350,            /* LLT_OBSERVER  */
    LLT_EXPOSED = 351,             /* LLT_EXPOSED  */
    LLT_REFCOUNTED = 352,          /* LLT_REFCOUNTED  */
    LLT_REFS = 353,                /* LLT_REFS  */
    LLT_RELNULL = 354,             /* LLT_RELNULL  */
    LLT_RELDEF = 355,              /* LLT_RELDEF  */
    LLT_KILLREF = 356,             /* LLT_KILLREF  */
    LLT_NULLTERMINATED = 357,      /* LLT_NULLTERMINATED  */
    LLT_TEMPREF = 358,             /* LLT_TEMPREF  */
    LLT_NEWREF = 359,              /* LLT_NEWREF  */
    LLT_PRIVATE = 360,             /* LLT_PRIVATE  */
    LLT_REQUIRES = 361,            /* LLT_REQUIRES  */
    LLT_RESULT = 362,              /* LLT_RESULT  */
    LLT_SIZEOF = 363,              /* LLT_SIZEOF  */
    LLT_SPEC = 364,                /* LLT_SPEC  */
    LLT_TAGGEDUNION = 365,         /* LLT_TAGGEDUNION  */
    LLT_THEN = 366,                /* LLT_THEN  */
    LLT_TYPE = 367,                /* LLT_TYPE  */
    LLT_TYPEDEF = 368,             /* LLT_TYPEDEF  */
    LLT_UNCHANGED = 369,           /* LLT_UNCHANGED  */
    LLT_USES = 370,                /* LLT_USES  */
    LLT_CHAR = 371,                /* LLT_CHAR  */
    LLT_CONST = 372,               /* LLT_CONST  */
    LLT_DOUBLE = 373,              /* LLT_DOUBLE  */
    LLT_ENUM = 374,                /* LLT_ENUM  */
    LLT_FLOAT = 375,               /* LLT_FLOAT  */
    LLT_INT = 376,                 /* LLT_INT  */
    LLT_ITER = 377,                /* LLT_ITER  */
    LLT_YIELD = 378,               /* LLT_YIELD  */
    LLT_LONG = 379,                /* LLT_LONG  */
    LLT_SHORT = 380,               /* LLT_SHORT  */
    LLT_SIGNED = 381,              /* LLT_SIGNED  */
    LLT_UNKNOWN = 382,             /* LLT_UNKNOWN  */
    LLT_STRUCT = 383,              /* LLT_STRUCT  */
    LLT_TELIPSIS = 384,            /* LLT_TELIPSIS  */
    LLT_UNION = 385,               /* LLT_UNION  */
    LLT_UNSIGNED = 386,            /* LLT_UNSIGNED  */
    LLT_VOID = 387,                /* LLT_VOID  */
    LLT_VOLATILE = 388,            /* LLT_VOLATILE  */
    LLT_PRINTFLIKE = 389,          /* LLT_PRINTFLIKE  */
    LLT_SCANFLIKE = 390,           /* LLT_SCANFLIKE  */
    LLT_MESSAGELIKE = 391          /* LLT_MESSAGELIKE  */
  };
  typedef enum yltokentype yltoken_kind_t;
#endif
/* Token kinds.  */
#define YLEMPTY -2
#define YLEOF 0
#define YLerror 256
#define YLUNDEF 257
#define PREFIX_OP 258
#define POSTFIX_OP 259
#define ITERATION_OP 260
#define LLT_IF_THEN_ELSE 261
#define eqSepSym 262
#define equationSym 263
#define commentSym 264
#define LLT_WHITESPACE 265
#define LLT_EOL 266
#define LLT_TYPEDEF_NAME 267
#define quantifierSym 268
#define logicalOp 269
#define selectSym 270
#define openSym 271
#define closeSym 272
#define sepSym 273
#define simpleId 274
#define mapSym 275
#define markerSym 276
#define preSym 277
#define postSym 278
#define anySym 279
#define simpleOp 280
#define LLT_COLON 281
#define LLT_COMMA 282
#define LLT_EQUALS 283
#define LLT_LBRACE 284
#define LLT_RBRACE 285
#define LLT_LBRACKET 286
#define LLT_RBRACKET 287
#define LLT_LPAR 288
#define LLT_RPAR 289
#define LLT_QUOTE 290
#define LLT_SEMI 291
#define LLT_VERTICALBAR 292
#define eqOp 293
#define LLT_MULOP 294
#define LLT_CCHAR 295
#define LLT_CFLOAT 296
#define LLT_CINTEGER 297
#define LLT_LCSTRING 298
#define LLT_ALL 299
#define LLT_ANYTHING 300
#define LLT_BE 301
#define LLT_BODY 302
#define LLT_CLAIMS 303
#define LLT_CHECKS 304
#define LLT_CONSTANT 305
#define LLT_ELSE 306
#define LLT_ENSURES 307
#define LLT_FOR 308
#define LLT_FRESH 309
#define LLT_IF 310
#define LLT_IMMUTABLE 311
#define LLT_IMPORTS 312
#define LLT_CONSTRAINT 313
#define LLT_ISSUB 314
#define LLT_LET 315
#define LLT_MODIFIES 316
#define LLT_MUTABLE 317
#define LLT_NOTHING 318
#define LLT_INTERNAL 319
#define LLT_FILESYS 320
#define LLT_OBJ 321
#define LLT_OUT 322
#define LLT_SEF 323
#define LLT_ONLY 324
#define LLT_PARTIAL 325
#define LLT_OWNED 326
#define LLT_DEPENDENT 327
#define LLT_KEEP 328
#define LLT_KEPT 329
#define LLT_TEMP 330
#define LLT_SHARED 331
#define LLT_UNIQUE 332
#define LLT_UNUSED 333
#define LLT_EXITS 334
#define LLT_MAYEXIT 335
#define LLT_NEVEREXIT 336
#define LLT_TRUEEXIT 337
#define LLT_FALSEEXIT 338
#define LLT_UNDEF 339
#define LLT_KILLED 340
#define LLT_CHECKMOD 341
#define LLT_CHECKED 342
#define LLT_UNCHECKED 343
#define LLT_CHECKEDSTRICT 344
#define LLT_TRUENULL 345
#define LLT_FALSENULL 346
#define LLT_LNULL 347
#define LLT_LNOTNULL 348
#define LLT_RETURNED 349
#define LLT_OBSERVER 350
#define LLT_EXPOSED 351
#define LLT_REFCOUNTED 352
#define LLT_REFS 353
#define LLT_RELNULL 354
#define LLT_RELDEF 355
#define LLT_KILLREF 356
#define LLT_NULLTERMINATED 357
#define LLT_TEMPREF 358
#define LLT_NEWREF 359
#define LLT_PRIVATE 360
#define LLT_REQUIRES 361
#define LLT_RESULT 362
#define LLT_SIZEOF 363
#define LLT_SPEC 364
#define LLT_TAGGEDUNION 365
#define LLT_THEN 366
#define LLT_TYPE 367
#define LLT_TYPEDEF 368
#define LLT_UNCHANGED 369
#define LLT_USES 370
#define LLT_CHAR 371
#define LLT_CONST 372
#define LLT_DOUBLE 373
#define LLT_ENUM 374
#define LLT_FLOAT 375
#define LLT_INT 376
#define LLT_ITER 377
#define LLT_YIELD 378
#define LLT_LONG 379
#define LLT_SHORT 380
#define LLT_SIGNED 381
#define LLT_UNKNOWN 382
#define LLT_STRUCT 383
#define LLT_TELIPSIS 384
#define LLT_UNION 385
#define LLT_UNSIGNED 386
#define LLT_VOID 387
#define LLT_VOLATILE 388
#define LLT_PRINTFLIKE 389
#define LLT_SCANFLIKE 390
#define LLT_MESSAGELIKE 391

/* Value type.  */
#if ! defined YLSTYPE && ! defined YLSTYPE_IS_DECLARED
union YLSTYPE
{
#line 61 "llgrammar.y"

  ltoken ltok;  /* a leaf is also an ltoken */
  qual typequal;
  unsigned int count;
  /*@only@*/ ltokenList ltokenList;
  /*@only@*/ abstDeclaratorNode abstDecl; 
  /*@only@*/ declaratorNode declare;
  /*@only@*/ declaratorNodeList declarelist;
  /*@only@*/ typeExpr typeexpr;
  /*@only@*/ arrayQualNode array;
  /*@only@*/ quantifierNode quantifier;
  /*@only@*/ quantifierNodeList quantifiers;
  /*@only@*/ varNode var;
  /*@only@*/ varNodeList vars;
  /*@only@*/ storeRefNode storeref;
  /*@only@*/ storeRefNodeList storereflist;
  /*@only@*/ termNode term;
  /*@only@*/ termNodeList termlist;
  /*@only@*/ programNode program; 
  /*@only@*/ stmtNode stmt;
  /*@only@*/ claimNode claim;
  /*@only@*/ typeNode type;
  /*@only@*/ iterNode iter;
  /*@only@*/ fcnNode fcn;
  /*@only@*/ fcnNodeList fcns;
  /*@only@*/ letDeclNode letdecl;
  /*@only@*/ letDeclNodeList letdecls;
  /*@only@*/ lclPredicateNode lclpredicate;
  /*@only@*/ modifyNode modify;
  /*@only@*/ paramNode param;
  /*@only@*/ paramNodeList paramlist;
  /*@only@*/ declaratorInvNodeList declaratorinvs;	
  /*@only@*/ declaratorInvNode declaratorinv;	
  /*@only@*/ abstBodyNode abstbody;
  /*@only@*/ abstractNode abstract;
  /*@only@*/ exposedNode exposed;
  /*@only@*/ pointers pointers;
  /*    taggedUnionNode taggedunion; */
  /*@only@*/ globalList globals;
  /*@only@*/ constDeclarationNode constdeclaration;
  /*@only@*/ varDeclarationNode vardeclaration;
  /*@only@*/ varDeclarationNodeList vardeclarationlist;
  /*@only@*/ initDeclNodeList initdecls;
  /*@only@*/ initDeclNode initdecl;
  /*@only@*/ stDeclNodeList structdecls;
  /*@only@*/ stDeclNode structdecl;
  /*@only@*/ strOrUnionNode structorunion;
  /*@only@*/ enumSpecNode enumspec; 
  /*@only@*/ lclTypeSpecNode lcltypespec;
  /*@only@*/ typeNameNode typname;
  /*@only@*/ opFormNode opform;
  /*@only@*/ sigNode signature;
  /*@only@*/ nameNode name;
  /*@only@*/ typeNameNodeList namelist;
  /*@only@*/ replaceNode replace;	
  /*@only@*/ replaceNodeList replacelist;
  /*@only@*/ renamingNode renaming;
  /*@only@*/ traitRefNode traitref;
  /*@only@*/ traitRefNodeList traitreflist;
  /*@only@*/ importNode import;
  /*@only@*/ importNodeList importlist;
  /*@only@*/ interfaceNode iface;
  /*@only@*/ interfaceNodeList interfacelist; 
  /*@only@*/ CTypesNode ctypes;
  /*@-redef@*/

#line 508 "llgrammar.c"

};
typedef union YLSTYPE YLSTYPE;
# define YLSTYPE_IS_TRIVIAL 1
# define YLSTYPE_IS_DECLARED 1
#endif


extern YLSTYPE yllval;


int ylparse (void);


#endif /* !YY_YL_LLGRAMMAR_H_INCLUDED  */
/* Symbol kind.  */
enum yysymbol_kind_t
{
  YYSYMBOL_YYEMPTY = -2,
  YYSYMBOL_YYEOF = 0,                      /* "end of file"  */
  YYSYMBOL_YYerror = 1,                    /* error  */
  YYSYMBOL_YYUNDEF = 2,                    /* "invalid token"  */
  YYSYMBOL_PREFIX_OP = 3,                  /* PREFIX_OP  */
  YYSYMBOL_POSTFIX_OP = 4,                 /* POSTFIX_OP  */
  YYSYMBOL_ITERATION_OP = 5,               /* ITERATION_OP  */
  YYSYMBOL_LLT_IF_THEN_ELSE = 6,           /* LLT_IF_THEN_ELSE  */
  YYSYMBOL_eqSepSym = 7,                   /* eqSepSym  */
  YYSYMBOL_equationSym = 8,                /* equationSym  */
  YYSYMBOL_commentSym = 9,                 /* commentSym  */
  YYSYMBOL_LLT_WHITESPACE = 10,            /* LLT_WHITESPACE  */
  YYSYMBOL_LLT_EOL = 11,                   /* LLT_EOL  */
  YYSYMBOL_LLT_TYPEDEF_NAME = 12,          /* LLT_TYPEDEF_NAME  */
  YYSYMBOL_quantifierSym = 13,             /* quantifierSym  */
  YYSYMBOL_logicalOp = 14,                 /* logicalOp  */
  YYSYMBOL_selectSym = 15,                 /* selectSym  */
  YYSYMBOL_openSym = 16,                   /* openSym  */
  YYSYMBOL_closeSym = 17,                  /* closeSym  */
  YYSYMBOL_sepSym = 18,                    /* sepSym  */
  YYSYMBOL_simpleId = 19,                  /* simpleId  */
  YYSYMBOL_mapSym = 20,                    /* mapSym  */
  YYSYMBOL_markerSym = 21,                 /* markerSym  */
  YYSYMBOL_preSym = 22,                    /* preSym  */
  YYSYMBOL_postSym = 23,                   /* postSym  */
  YYSYMBOL_anySym = 24,                    /* anySym  */
  YYSYMBOL_simpleOp = 25,                  /* simpleOp  */
  YYSYMBOL_LLT_COLON = 26,                 /* LLT_COLON  */
  YYSYMBOL_LLT_COMMA = 27,                 /* LLT_COMMA  */
  YYSYMBOL_LLT_EQUALS = 28,                /* LLT_EQUALS  */
  YYSYMBOL_LLT_LBRACE = 29,                /* LLT_LBRACE  */
  YYSYMBOL_LLT_RBRACE = 30,                /* LLT_RBRACE  */
  YYSYMBOL_LLT_LBRACKET = 31,              /* LLT_LBRACKET  */
  YYSYMBOL_LLT_RBRACKET = 32,              /* LLT_RBRACKET  */
  YYSYMBOL_LLT_LPAR = 33,                  /* LLT_LPAR  */
  YYSYMBOL_LLT_RPAR = 34,                  /* LLT_RPAR  */
  YYSYMBOL_LLT_QUOTE = 35,                 /* LLT_QUOTE  */
  YYSYMBOL_LLT_SEMI = 36,                  /* LLT_SEMI  */
  YYSYMBOL_LLT_VERTICALBAR = 37,           /* LLT_VERTICALBAR  */
  YYSYMBOL_eqOp = 38,                      /* eqOp  */
  YYSYMBOL_LLT_MULOP = 39,                 /* LLT_MULOP  */
  YYSYMBOL_LLT_CCHAR = 40,                 /* LLT_CCHAR  */
  YYSYMBOL_LLT_CFLOAT = 41,                /* LLT_CFLOAT  */
  YYSYMBOL_LLT_CINTEGER = 42,              /* LLT_CINTEGER  */
  YYSYMBOL_LLT_LCSTRING = 43,              /* LLT_LCSTRING  */
  YYSYMBOL_LLT_ALL = 44,                   /* LLT_ALL  */
  YYSYMBOL_LLT_ANYTHING = 45,              /* LLT_ANYTHING  */
  YYSYMBOL_LLT_BE = 46,                    /* LLT_BE  */
  YYSYMBOL_LLT_BODY = 47,                  /* LLT_BODY  */
  YYSYMBOL_LLT_CLAIMS = 48,                /* LLT_CLAIMS  */
  YYSYMBOL_LLT_CHECKS = 49,                /* LLT_CHECKS  */
  YYSYMBOL_LLT_CONSTANT = 50,              /* LLT_CONSTANT  */
  YYSYMBOL_LLT_ELSE = 51,                  /* LLT_ELSE  */
  YYSYMBOL_LLT_ENSURES = 52,               /* LLT_ENSURES  */
  YYSYMBOL_LLT_FOR = 53,                   /* LLT_FOR  */
  YYSYMBOL_LLT_FRESH = 54,                 /* LLT_FRESH  */
  YYSYMBOL_LLT_IF = 55,                    /* LLT_IF  */
  YYSYMBOL_LLT_IMMUTABLE = 56,             /* LLT_IMMUTABLE  */
  YYSYMBOL_LLT_IMPORTS = 57,               /* LLT_IMPORTS  */
  YYSYMBOL_LLT_CONSTRAINT = 58,            /* LLT_CONSTRAINT  */
  YYSYMBOL_LLT_ISSUB = 59,                 /* LLT_ISSUB  */
  YYSYMBOL_LLT_LET = 60,                   /* LLT_LET  */
  YYSYMBOL_LLT_MODIFIES = 61,              /* LLT_MODIFIES  */
  YYSYMBOL_LLT_MUTABLE = 62,               /* LLT_MUTABLE  */
  YYSYMBOL_LLT_NOTHING = 63,               /* LLT_NOTHING  */
  YYSYMBOL_LLT_INTERNAL = 64,              /* LLT_INTERNAL  */
  YYSYMBOL_LLT_FILESYS = 65,               /* LLT_FILESYS  */
  YYSYMBOL_LLT_OBJ = 66,                   /* LLT_OBJ  */
  YYSYMBOL_LLT_OUT = 67,                   /* LLT_OUT  */
  YYSYMBOL_LLT_SEF = 68,                   /* LLT_SEF  */
  YYSYMBOL_LLT_ONLY = 69,                  /* LLT_ONLY  */
  YYSYMBOL_LLT_PARTIAL = 70,               /* LLT_PARTIAL  */
  YYSYMBOL_LLT_OWNED = 71,                 /* LLT_OWNED  */
  YYSYMBOL_LLT_DEPENDENT = 72,             /* LLT_DEPENDENT  */
  YYSYMBOL_LLT_KEEP = 73,                  /* LLT_KEEP  */
  YYSYMBOL_LLT_KEPT = 74,                  /* LLT_KEPT  */
  YYSYMBOL_LLT_TEMP = 75,                  /* LLT_TEMP  */
  YYSYMBOL_LLT_SHARED = 76,                /* LLT_SHARED  */
  YYSYMBOL_LLT_UNIQUE = 77,                /* LLT_UNIQUE  */
  YYSYMBOL_LLT_UNUSED = 78,                /* LLT_UNUSED  */
  YYSYMBOL_LLT_EXITS = 79,                 /* LLT_EXITS  */
  YYSYMBOL_LLT_MAYEXIT = 80,               /* LLT_MAYEXIT  */
  YYSYMBOL_LLT_NEVEREXIT = 81,             /* LLT_NEVEREXIT  */
  YYSYMBOL_LLT_TRUEEXIT = 82,              /* LLT_TRUEEXIT  */
  YYSYMBOL_LLT_FALSEEXIT = 83,             /* LLT_FALSEEXIT  */
  YYSYMBOL_LLT_UNDEF = 84,                 /* LLT_UNDEF  */
  YYSYMBOL_LLT_KILLED = 85,                /* LLT_KILLED  */
  YYSYMBOL_LLT_CHECKMOD = 86,              /* LLT_CHECKMOD  */
  YYSYMBOL_LLT_CHECKED = 87,               /* LLT_CHECKED  */
  YYSYMBOL_LLT_UNCHECKED = 88,             /* LLT_UNCHECKED  */
  YYSYMBOL_LLT_CHECKEDSTRICT = 89,         /* LLT_CHECKEDSTRICT  */
  YYSYMBOL_LLT_TRUENULL = 90,              /* LLT_TRUENULL  */
  YYSYMBOL_LLT_FALSENULL = 91,             /* LLT_FALSENULL  */
  YYSYMBOL_LLT_LNULL = 92,                 /* LLT_LNULL  */
  YYSYMBOL_LLT_LNOTNULL = 93,              /* LLT_LNOTNULL  */
  YYSYMBOL_LLT_RETURNED = 94,              /* LLT_RETURNED  */
  YYSYMBOL_LLT_OBSERVER = 95,              /* LLT_OBSERVER  */
  YYSYMBOL_LLT_EXPOSED = 96,               /* LLT_EXPOSED  */
  YYSYMBOL_LLT_REFCOUNTED = 97,            /* LLT_REFCOUNTED  */
  YYSYMBOL_LLT_REFS = 98,                  /* LLT_REFS  */
  YYSYMBOL_LLT_RELNULL = 99,               /* LLT_RELNULL  */
  YYSYMBOL_LLT_RELDEF = 100,               /* LLT_RELDEF  */
  YYSYMBOL_LLT_KILLREF = 101,              /* LLT_KILLREF  */
  YYSYMBOL_LLT_NULLTERMINATED = 102,       /* LLT_NULLTERMINATED  */
  YYSYMBOL_LLT_TEMPREF = 103,              /* LLT_TEMPREF  */
  YYSYMBOL_LLT_NEWREF = 104,               /* LLT_NEWREF  */
  YYSYMBOL_LLT_PRIVATE = 105,              /* LLT_PRIVATE  */
  YYSYMBOL_LLT_REQUIRES = 106,             /* LLT_REQUIRES  */
  YYSYMBOL_LLT_RESULT = 107,               /* LLT_RESULT  */
  YYSYMBOL_LLT_SIZEOF = 108,               /* LLT_SIZEOF  */
  YYSYMBOL_LLT_SPEC = 109,                 /* LLT_SPEC  */
  YYSYMBOL_LLT_TAGGEDUNION = 110,          /* LLT_TAGGEDUNION  */
  YYSYMBOL_LLT_THEN = 111,                 /* LLT_THEN  */
  YYSYMBOL_LLT_TYPE = 112,                 /* LLT_TYPE  */
  YYSYMBOL_LLT_TYPEDEF = 113,              /* LLT_TYPEDEF  */
  YYSYMBOL_LLT_UNCHANGED = 114,            /* LLT_UNCHANGED  */
  YYSYMBOL_LLT_USES = 115,                 /* LLT_USES  */
  YYSYMBOL_LLT_CHAR = 116,                 /* LLT_CHAR  */
  YYSYMBOL_LLT_CONST = 117,                /* LLT_CONST  */
  YYSYMBOL_LLT_DOUBLE = 118,               /* LLT_DOUBLE  */
  YYSYMBOL_LLT_ENUM = 119,                 /* LLT_ENUM  */
  YYSYMBOL_LLT_FLOAT = 120,                /* LLT_FLOAT  */
  YYSYMBOL_LLT_INT = 121,                  /* LLT_INT  */
  YYSYMBOL_LLT_ITER = 122,                 /* LLT_ITER  */
  YYSYMBOL_LLT_YIELD = 123,                /* LLT_YIELD  */
  YYSYMBOL_LLT_LONG = 124,                 /* LLT_LONG  */
  YYSYMBOL_LLT_SHORT = 125,                /* LLT_SHORT  */
  YYSYMBOL_LLT_SIGNED = 126,               /* LLT_SIGNED  */
  YYSYMBOL_LLT_UNKNOWN = 127,              /* LLT_UNKNOWN  */
  YYSYMBOL_LLT_STRUCT = 128,               /* LLT_STRUCT  */
  YYSYMBOL_LLT_TELIPSIS = 129,             /* LLT_TELIPSIS  */
  YYSYMBOL_LLT_UNION = 130,                /* LLT_UNION  */
  YYSYMBOL_LLT_UNSIGNED = 131,             /* LLT_UNSIGNED  */
  YYSYMBOL_LLT_VOID = 132,                 /* LLT_VOID  */
  YYSYMBOL_LLT_VOLATILE = 133,             /* LLT_VOLATILE  */
  YYSYMBOL_LLT_PRINTFLIKE = 134,           /* LLT_PRINTFLIKE  */
  YYSYMBOL_LLT_SCANFLIKE = 135,            /* LLT_SCANFLIKE  */
  YYSYMBOL_LLT_MESSAGELIKE = 136,          /* LLT_MESSAGELIKE  */
  YYSYMBOL_YYACCEPT = 137,                 /* $accept  */
  YYSYMBOL_interface = 138,                /* interface  */
  YYSYMBOL_139_1 = 139,                    /* $@1  */
  YYSYMBOL_externals = 140,                /* externals  */
  YYSYMBOL_external = 141,                 /* external  */
  YYSYMBOL_optDeclarations = 142,          /* optDeclarations  */
  YYSYMBOL_declarations = 143,             /* declarations  */
  YYSYMBOL_declaration = 144,              /* declaration  */
  YYSYMBOL_imports = 145,                  /* imports  */
  YYSYMBOL_uses = 146,                     /* uses  */
  YYSYMBOL_export = 147,                   /* export  */
  YYSYMBOL_iter = 148,                     /* iter  */
  YYSYMBOL_iterParamList = 149,            /* iterParamList  */
  YYSYMBOL_realIterParamList = 150,        /* realIterParamList  */
  YYSYMBOL_iterParam = 151,                /* iterParam  */
  YYSYMBOL_private = 152,                  /* private  */
  YYSYMBOL_153_2 = 153,                    /* $@2  */
  YYSYMBOL_private2 = 154,                 /* private2  */
  YYSYMBOL_constDeclaration = 155,         /* constDeclaration  */
  YYSYMBOL_varDeclaration = 156,           /* varDeclaration  */
  YYSYMBOL_type = 157,                     /* type  */
  YYSYMBOL_special = 158,                  /* special  */
  YYSYMBOL_fcn = 159,                      /* fcn  */
  YYSYMBOL_160_3 = 160,                    /* $@3  */
  YYSYMBOL_161_4 = 161,                    /* $@4  */
  YYSYMBOL_claim = 162,                    /* claim  */
  YYSYMBOL_163_5 = 163,                    /* $@5  */
  YYSYMBOL_abstract = 164,                 /* abstract  */
  YYSYMBOL_165_6 = 165,                    /* $@6  */
  YYSYMBOL_166_7 = 166,                    /* $@7  */
  YYSYMBOL_167_8 = 167,                    /* $@8  */
  YYSYMBOL_168_9 = 168,                    /* $@9  */
  YYSYMBOL_169_10 = 169,                   /* $@10  */
  YYSYMBOL_170_11 = 170,                   /* $@11  */
  YYSYMBOL_171_12 = 171,                   /* $@12  */
  YYSYMBOL_172_13 = 172,                   /* $@13  */
  YYSYMBOL_exposed = 173,                  /* exposed  */
  YYSYMBOL_174_14 = 174,                   /* $@14  */
  YYSYMBOL_175_15 = 175,                   /* $@15  */
  YYSYMBOL_importNameList = 176,           /* importNameList  */
  YYSYMBOL_importName = 177,               /* importName  */
  YYSYMBOL_interfaceNameList = 178,        /* interfaceNameList  */
  YYSYMBOL_interfaceName = 179,            /* interfaceName  */
  YYSYMBOL_traitRefNodeList = 180,         /* traitRefNodeList  */
  YYSYMBOL_traitRef = 181,                 /* traitRef  */
  YYSYMBOL_traitIdList = 182,              /* traitIdList  */
  YYSYMBOL_renaming = 183,                 /* renaming  */
  YYSYMBOL_nameList = 184,                 /* nameList  */
  YYSYMBOL_replaceNodeList = 185,          /* replaceNodeList  */
  YYSYMBOL_replace = 186,                  /* replace  */
  YYSYMBOL_name = 187,                     /* name  */
  YYSYMBOL_initializer = 188,              /* initializer  */
  YYSYMBOL_constLclExpr = 189,             /* constLclExpr  */
  YYSYMBOL_initDecls = 190,                /* initDecls  */
  YYSYMBOL_initDecl = 191,                 /* initDecl  */
  YYSYMBOL_globals = 192,                  /* globals  */
  YYSYMBOL_globalDecl = 193,               /* globalDecl  */
  YYSYMBOL_privateInits = 194,             /* privateInits  */
  YYSYMBOL_privateInit = 195,              /* privateInit  */
  YYSYMBOL_optLetDecl = 196,               /* optLetDecl  */
  YYSYMBOL_beDeclList = 197,               /* beDeclList  */
  YYSYMBOL_beDecl = 198,                   /* beDecl  */
  YYSYMBOL_sortSpec = 199,                 /* sortSpec  */
  YYSYMBOL_optChecks = 200,                /* optChecks  */
  YYSYMBOL_optRequire = 201,               /* optRequire  */
  YYSYMBOL_optModify = 202,                /* optModify  */
  YYSYMBOL_storeRefList = 203,             /* storeRefList  */
  YYSYMBOL_storeRef = 204,                 /* storeRef  */
  YYSYMBOL_optEnsure = 205,                /* optEnsure  */
  YYSYMBOL_optClaim = 206,                 /* optClaim  */
  YYSYMBOL_optParamList = 207,             /* optParamList  */
  YYSYMBOL_realParamList = 208,            /* realParamList  */
  YYSYMBOL_paramList = 209,                /* paramList  */
  YYSYMBOL_optBody = 210,                  /* optBody  */
  YYSYMBOL_callExpr = 211,                 /* callExpr  */
  YYSYMBOL_stmt = 212,                     /* stmt  */
  YYSYMBOL_valueList = 213,                /* valueList  */
  YYSYMBOL_value = 214,                    /* value  */
  YYSYMBOL_abstBody = 215,                 /* abstBody  */
  YYSYMBOL_fcns = 216,                     /* fcns  */
  YYSYMBOL_optTypeInv = 217,               /* optTypeInv  */
  YYSYMBOL_typeInv = 218,                  /* typeInv  */
  YYSYMBOL_219_16 = 219,                   /* $@16  */
  YYSYMBOL_declaratorInvs = 220,           /* declaratorInvs  */
  YYSYMBOL_declaratorInv = 221,            /* declaratorInv  */
  YYSYMBOL_222_17 = 222,                   /* $@17  */
  YYSYMBOL_optExposedBody = 223,           /* optExposedBody  */
  YYSYMBOL_CType = 224,                    /* CType  */
  YYSYMBOL_CTypes = 225,                   /* CTypes  */
  YYSYMBOL_typeSpecifier = 226,            /* typeSpecifier  */
  YYSYMBOL_specialQualifier = 227,         /* specialQualifier  */
  YYSYMBOL_lclTypeSpec = 228,              /* lclTypeSpec  */
  YYSYMBOL_lclType = 229,                  /* lclType  */
  YYSYMBOL_pointers = 230,                 /* pointers  */
  YYSYMBOL_structOrUnionSpec = 231,        /* structOrUnionSpec  */
  YYSYMBOL_232_18 = 232,                   /* $@18  */
  YYSYMBOL_233_19 = 233,                   /* $@19  */
  YYSYMBOL_optTagId = 234,                 /* optTagId  */
  YYSYMBOL_structDecls = 235,              /* structDecls  */
  YYSYMBOL_structDecl = 236,               /* structDecl  */
  YYSYMBOL_declaratorList = 237,           /* declaratorList  */
  YYSYMBOL_optCOMMA = 238,                 /* optCOMMA  */
  YYSYMBOL_enumSpec = 239,                 /* enumSpec  */
  YYSYMBOL_enumeratorList = 240,           /* enumeratorList  */
  YYSYMBOL_declarator = 241,               /* declarator  */
  YYSYMBOL_notype_decl = 242,              /* notype_decl  */
  YYSYMBOL_after_type_decl = 243,          /* after_type_decl  */
  YYSYMBOL_parameter_decl = 244,           /* parameter_decl  */
  YYSYMBOL_param = 245,                    /* param  */
  YYSYMBOL_typeName = 246,                 /* typeName  */
  YYSYMBOL_optAbstDeclarator = 247,        /* optAbstDeclarator  */
  YYSYMBOL_abstDeclarator = 248,           /* abstDeclarator  */
  YYSYMBOL_arrayQual = 249,                /* arrayQual  */
  YYSYMBOL_opForm = 250,                   /* opForm  */
  YYSYMBOL_open = 251,                     /* open  */
  YYSYMBOL_close = 252,                    /* close  */
  YYSYMBOL_anyOp = 253,                    /* anyOp  */
  YYSYMBOL_middle = 254,                   /* middle  */
  YYSYMBOL_placeList = 255,                /* placeList  */
  YYSYMBOL_separator = 256,                /* separator  */
  YYSYMBOL_signature = 257,                /* signature  */
  YYSYMBOL_domain = 258,                   /* domain  */
  YYSYMBOL_sortList = 259,                 /* sortList  */
  YYSYMBOL_lclPredicate = 260,             /* lclPredicate  */
  YYSYMBOL_term = 261,                     /* term  */
  YYSYMBOL_term0 = 262,                    /* term0  */
  YYSYMBOL_equalityTerm = 263,             /* equalityTerm  */
  YYSYMBOL_simpleOpTerm = 264,             /* simpleOpTerm  */
  YYSYMBOL_simpleOp2 = 265,                /* simpleOp2  */
  YYSYMBOL_prefixOpTerm = 266,             /* prefixOpTerm  */
  YYSYMBOL_postfixOps = 267,               /* postfixOps  */
  YYSYMBOL_infixOpPart = 268,              /* infixOpPart  */
  YYSYMBOL_secondary = 269,                /* secondary  */
  YYSYMBOL_bracketed = 270,                /* bracketed  */
  YYSYMBOL_sqBracketed = 271,              /* sqBracketed  */
  YYSYMBOL_matched = 272,                  /* matched  */
  YYSYMBOL_args = 273,                     /* args  */
  YYSYMBOL_primary = 274,                  /* primary  */
  YYSYMBOL_termList = 275,                 /* termList  */
  YYSYMBOL_stateFcn = 276,                 /* stateFcn  */
  YYSYMBOL_lclPrimary = 277,               /* lclPrimary  */
  YYSYMBOL_cLiteral = 278,                 /* cLiteral  */
  YYSYMBOL_quantifiers = 279,              /* quantifiers  */
  YYSYMBOL_quantifier = 280,               /* quantifier  */
  YYSYMBOL_281_20 = 281,                   /* $@20  */
  YYSYMBOL_quantifiedList = 282,           /* quantifiedList  */
  YYSYMBOL_quantified = 283,               /* quantified  */
  YYSYMBOL_simpleIdOrTypedefName = 284,    /* simpleIdOrTypedefName  */
  YYSYMBOL_fcnId = 285,                    /* fcnId  */
  YYSYMBOL_varId = 286,                    /* varId  */
  YYSYMBOL_tagId = 287,                    /* tagId  */
  YYSYMBOL_claimId = 288,                  /* claimId  */
  YYSYMBOL_sortId = 289,                   /* sortId  */
  YYSYMBOL_traitId = 290,                  /* traitId  */
  YYSYMBOL_opId = 291                      /* opId  */
};
typedef enum yysymbol_kind_t yysymbol_kind_t;


/* Second part of user prologue.  */
#line 129 "llgrammar.y"

bool g_inTypeDef = FALSE;
static void ylerror (const char *) /*@modifies *g_warningstream@*/ ;
static void checkBrackets (ltoken lb, ltoken rb);
static void ylprint (FILE *p_file, int p_type, YLSTYPE p_value);
/*@notfunction@*/
# define YYPRINT(file, type, value) ylprint (file, type, value)

#line 834 "llgrammar.c"


#ifdef short
# undef short
#endif

/* On compilers that do not define __PTRDIFF_MAX__ etc., make sure
   <limits.h> and (if available) <stdint.h> are included
   so that the code can choose integer types of a good width.  */

#ifndef __PTRDIFF_MAX__
# include <limits.h> /* INFRINGES ON USER NAME SPACE */
# if defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
#  include <stdint.h> /* INFRINGES ON USER NAME SPACE */
#  define YY_STDINT_H
# endif
#endif

/* Narrow types that promote to a signed type and that can represent a
   signed or unsigned integer of at least N bits.  In tables they can
   save space and decrease cache pressure.  Promoting to a signed type
   helps avoid bugs in integer arithmetic.  */

#ifdef __INT_LEAST8_MAX__
typedef __INT_LEAST8_TYPE__ yytype_int8;
#elif defined YY_STDINT_H
typedef int_least8_t yytype_int8;
#else
typedef signed char yytype_int8;
#endif

#ifdef __INT_LEAST16_MAX__
typedef __INT_LEAST16_TYPE__ yytype_int16;
#elif defined YY_STDINT_H
typedef int_least16_t yytype_int16;
#else
typedef short yytype_int16;
#endif

/* Work around bug in HP-UX 11.23, which defines these macros
   incorrectly for preprocessor constants.  This workaround can likely
   be removed in 2023, as HPE has promised support for HP-UX 11.23
   (aka HP-UX 11i v2) only through the end of 2022; see Table 2 of
   <https://h20195.www2.hpe.com/V2/getpdf.aspx/4AA4-7673ENW.pdf>.  */
#ifdef __hpux
# undef UINT_LEAST8_MAX
# undef UINT_LEAST16_MAX
# define UINT_LEAST8_MAX 255
# define UINT_LEAST16_MAX 65535
#endif

#if defined __UINT_LEAST8_MAX__ && __UINT_LEAST8_MAX__ <= __INT_MAX__
typedef __UINT_LEAST8_TYPE__ yytype_uint8;
#elif (!defined __UINT_LEAST8_MAX__ && defined YY_STDINT_H \
       && UINT_LEAST8_MAX <= INT_MAX)
typedef uint_least8_t yytype_uint8;
#elif !defined __UINT_LEAST8_MAX__ && UCHAR_MAX <= INT_MAX
typedef unsigned char yytype_uint8;
#else
typedef short yytype_uint8;
#endif

#if defined __UINT_LEAST16_MAX__ && __UINT_LEAST16_MAX__ <= __INT_MAX__
typedef __UINT_LEAST16_TYPE__ yytype_uint16;
#elif (!defined __UINT_LEAST16_MAX__ && defined YY_STDINT_H \
       && UINT_LEAST16_MAX <= INT_MAX)
typedef uint_least16_t yytype_uint16;
#elif !defined __UINT_LEAST16_MAX__ && USHRT_MAX <= INT_MAX
typedef unsigned short yytype_uint16;
#else
typedef int yytype_uint16;
#endif

#ifndef YYPTRDIFF_T
# if defined __PTRDIFF_TYPE__ && defined __PTRDIFF_MAX__
#  define YYPTRDIFF_T __PTRDIFF_TYPE__
#  define YYPTRDIFF_MAXIMUM __PTRDIFF_MAX__
# elif defined PTRDIFF_MAX
#  ifndef ptrdiff_t
#   include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  endif
#  define YYPTRDIFF_T ptrdiff_t
#  define YYPTRDIFF_MAXIMUM PTRDIFF_MAX
# else
#  define YYPTRDIFF_T long
#  define YYPTRDIFF_MAXIMUM LONG_MAX
# endif
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned
# endif
#endif

#define YYSIZE_MAXIMUM                                  \
  YY_CAST (YYPTRDIFF_T,                                 \
           (YYPTRDIFF_MAXIMUM < YY_CAST (YYSIZE_T, -1)  \
            ? YYPTRDIFF_MAXIMUM                         \
            : YY_CAST (YYSIZE_T, -1)))

#define YYSIZEOF(X) YY_CAST (YYPTRDIFF_T, sizeof (X))


/* Stored state numbers (used for stacks). */
typedef yytype_int16 yy_state_t;

/* State numbers in computations.  */
typedef int yy_state_fast_t;

#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(Msgid) Msgid
# endif
#endif


#ifndef YY_ATTRIBUTE_PURE
# if defined __GNUC__ && 2 < __GNUC__ + (96 <= __GNUC_MINOR__)
#  define YY_ATTRIBUTE_PURE __attribute__ ((__pure__))
# else
#  define YY_ATTRIBUTE_PURE
# endif
#endif

#ifndef YY_ATTRIBUTE_UNUSED
# if defined __GNUC__ && 2 < __GNUC__ + (7 <= __GNUC_MINOR__)
#  define YY_ATTRIBUTE_UNUSED __attribute__ ((__unused__))
# else
#  define YY_ATTRIBUTE_UNUSED
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YY_USE(E) ((void) (E))
#else
# define YY_USE(E) /* empty */
#endif

/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
#if defined __GNUC__ && ! defined __ICC && 406 <= __GNUC__ * 100 + __GNUC_MINOR__
# if __GNUC__ * 100 + __GNUC_MINOR__ < 407
#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
    _Pragma ("GCC diagnostic push")                                     \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")
# else
#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
    _Pragma ("GCC diagnostic push")                                     \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")              \
    _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
# endif
# define YY_IGNORE_MAYBE_UNINITIALIZED_END      \
    _Pragma ("GCC diagnostic pop")
#else
# define YY_INITIAL_VALUE(Value) Value
#endif
#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_END
#endif
#ifndef YY_INITIAL_VALUE
# define YY_INITIAL_VALUE(Value) /* Nothing. */
#endif

#if defined __cplusplus && defined __GNUC__ && ! defined __ICC && 6 <= __GNUC__
# define YY_IGNORE_USELESS_CAST_BEGIN                          \
    _Pragma ("GCC diagnostic push")                            \
    _Pragma ("GCC diagnostic ignored \"-Wuseless-cast\"")
# define YY_IGNORE_USELESS_CAST_END            \
    _Pragma ("GCC diagnostic pop")
#endif
#ifndef YY_IGNORE_USELESS_CAST_BEGIN
# define YY_IGNORE_USELESS_CAST_BEGIN
# define YY_IGNORE_USELESS_CAST_END
#endif


#define YY_ASSERT(E) ((void) (0 && (E)))

#if !defined yyoverflow

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
#     ifndef EXIT_SUCCESS
#      define EXIT_SUCCESS 0
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's 'empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
       && ! ((defined YYMALLOC || defined malloc) \
             && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef EXIT_SUCCESS
#    define EXIT_SUCCESS 0
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined EXIT_SUCCESS
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined EXIT_SUCCESS
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* !defined yyoverflow */

#if (! defined yyoverflow \
     && (! defined __cplusplus \
         || (defined YLSTYPE_IS_TRIVIAL && YLSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yy_state_t yyss_alloc;
  YYSTYPE yyvs_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (YYSIZEOF (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (YYSIZEOF (yy_state_t) + YYSIZEOF (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

# define YYCOPY_NEEDED 1

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)                           \
    do                                                                  \
      {                                                                 \
        YYPTRDIFF_T yynewbytes;                                         \
        YYCOPY (&yyptr->Stack_alloc, Stack, yysize);                    \
        Stack = &yyptr->Stack_alloc;                                    \
        yynewbytes = yystacksize * YYSIZEOF (*Stack) + YYSTACK_GAP_MAXIMUM; \
        yyptr += yynewbytes / YYSIZEOF (*yyptr);                        \
      }                                                                 \
    while (0)

#endif

#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from SRC to DST.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(Dst, Src, Count) \
      __builtin_memcpy (Dst, Src, YY_CAST (YYSIZE_T, (Count)) * sizeof (*(Src)))
#  else
#   define YYCOPY(Dst, Src, Count)              \
      do                                        \
        {                                       \
          YYPTRDIFF_T yyi;                      \
          for (yyi = 0; yyi < (Count); yyi++)   \
            (Dst)[yyi] = (Src)[yyi];            \
        }                                       \
      while (0)
#  endif
# endif
#endif /* !YYCOPY_NEEDED */

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  3
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   2984

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  137
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  155
/* YYNRULES -- Number of rules.  */
#define YYNRULES  414
/* YYNSTATES -- Number of states.  */
#define YYNSTATES  684

/* YYMAXUTOK -- Last valid token kind.  */
#define YYMAXUTOK   391


/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex, with out-of-bounds checking.  */
#define YYTRANSLATE(YYX)                                \
  (0 <= (YYX) && (YYX) <= YYMAXUTOK                     \
   ? YY_CAST (yysymbol_kind_t, yytranslate[YYX])        \
   : YYSYMBOL_YYUNDEF)

/* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex.  */
static const yytype_uint8 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60,    61,    62,    63,    64,
      65,    66,    67,    68,    69,    70,    71,    72,    73,    74,
      75,    76,    77,    78,    79,    80,    81,    82,    83,    84,
      85,    86,    87,    88,    89,    90,    91,    92,    93,    94,
      95,    96,    97,    98,    99,   100,   101,   102,   103,   104,
     105,   106,   107,   108,   109,   110,   111,   112,   113,   114,
     115,   116,   117,   118,   119,   120,   121,   122,   123,   124,
     125,   126,   127,   128,   129,   130,   131,   132,   133,   134,
     135,   136
};

#if YLDEBUG
/* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
static const yytype_int16 yyrline[] =
{
       0,   382,   382,   382,   387,   388,   392,   393,   397,   398,
     399,   403,   404,   408,   409,   410,   414,   421,   426,   428,
     430,   432,   434,   436,   441,   446,   447,   451,   453,   458,
     459,   463,   463,   468,   470,   472,   474,   479,   484,   486,
     488,   493,   494,   498,   499,   500,   504,   504,   512,   512,
     526,   525,   530,   535,   535,   535,   537,   538,   537,   540,
     541,   540,   543,   543,   543,   548,   549,   548,   551,   553,
     570,   572,   577,   578,   580,   584,   585,   589,   594,   596,
     601,   603,   605,   607,   612,   613,   617,   619,   621,   625,
     627,   631,   633,   637,   638,   639,   644,   645,   648,   651,
     655,   657,   662,   663,   668,   669,   674,   675,   676,   680,
     681,   685,   690,   691,   695,   696,   700,   701,   704,   708,
     709,   713,   714,   718,   719,   720,   721,   725,   726,   730,
     731,   732,   733,   734,   738,   739,   743,   744,   748,   749,
     753,   754,   755,   759,   760,   764,   765,   766,   770,   771,
     774,   779,   785,   794,   796,   798,   800,   805,   806,   810,
     811,   812,   813,   814,   815,   816,   818,   823,   824,   825,
     826,   830,   831,   835,   836,   840,   840,   850,   851,   856,
     856,   861,   862,   866,   867,   868,   869,   870,   871,   872,
     873,   874,   875,   884,   885,   891,   893,   900,   901,   902,
     903,   904,   905,   906,   907,   908,   909,   910,   911,   912,
     913,   914,   915,   916,   917,   918,   919,   920,   921,   922,
     923,   924,   925,   926,   927,   928,   929,   930,   931,   932,
     933,   934,   935,   939,   941,   943,   945,   947,   957,   958,
     964,   965,   970,   969,   974,   973,   977,   979,   984,   985,
     989,   990,   996,  1000,  1002,  1007,  1008,  1012,  1014,  1019,
    1020,  1031,  1032,  1036,  1037,  1038,  1039,  1040,  1041,  1045,
    1046,  1047,  1048,  1049,  1050,  1060,  1061,  1062,  1063,  1064,
    1071,  1072,  1073,  1084,  1085,  1086,  1092,  1093,  1097,  1098,
    1099,  1100,  1101,  1102,  1103,  1104,  1108,  1109,  1113,  1115,
    1117,  1119,  1121,  1124,  1126,  1128,  1130,  1132,  1134,  1142,
    1144,  1146,  1149,  1152,  1155,  1161,  1162,  1166,  1167,  1171,
    1172,  1173,  1177,  1178,  1182,  1183,  1187,  1188,  1192,  1196,
    1197,  1201,  1202,  1206,  1210,  1217,  1219,  1220,  1224,  1225,
    1230,  1232,  1237,  1238,  1239,  1243,  1244,  1248,  1249,  1253,
    1254,  1258,  1259,  1263,  1264,  1265,  1266,  1267,  1268,  1269,
    1273,  1274,  1278,  1281,  1283,  1287,  1292,  1293,  1297,  1298,
    1302,  1304,  1306,  1308,  1309,  1311,  1313,  1315,  1318,  1320,
    1325,  1326,  1330,  1331,  1332,  1333,  1337,  1338,  1339,  1340,
    1341,  1342,  1347,  1353,  1364,  1365,  1366,  1367,  1371,  1373,
    1378,  1378,  1386,  1387,  1391,  1392,  1396,  1397,  1401,  1402,
    1403,  1404,  1405,  1406,  1407
};
#endif

/** Accessing symbol of state STATE.  */
#define YY_ACCESSING_SYMBOL(State) YY_CAST (yysymbol_kind_t, yystos[State])

#if YLDEBUG || 0
/* The user-facing name of the symbol whose (internal) number is
   YYSYMBOL.  No bounds checking.  */
static const char *yysymbol_name (yysymbol_kind_t yysymbol) YY_ATTRIBUTE_UNUSED;

/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "\"end of file\"", "error", "\"invalid token\"", "PREFIX_OP",
  "POSTFIX_OP", "ITERATION_OP", "LLT_IF_THEN_ELSE", "eqSepSym",
  "equationSym", "commentSym", "LLT_WHITESPACE", "LLT_EOL",
  "LLT_TYPEDEF_NAME", "quantifierSym", "logicalOp", "selectSym", "openSym",
  "closeSym", "sepSym", "simpleId", "mapSym", "markerSym", "preSym",
  "postSym", "anySym", "simpleOp", "LLT_COLON", "LLT_COMMA", "LLT_EQUALS",
  "LLT_LBRACE", "LLT_RBRACE", "LLT_LBRACKET", "LLT_RBRACKET", "LLT_LPAR",
  "LLT_RPAR", "LLT_QUOTE", "LLT_SEMI", "LLT_VERTICALBAR", "eqOp",
  "LLT_MULOP", "LLT_CCHAR", "LLT_CFLOAT", "LLT_CINTEGER", "LLT_LCSTRING",
  "LLT_ALL", "LLT_ANYTHING", "LLT_BE", "LLT_BODY", "LLT_CLAIMS",
  "LLT_CHECKS", "LLT_CONSTANT", "LLT_ELSE", "LLT_ENSURES", "LLT_FOR",
  "LLT_FRESH", "LLT_IF", "LLT_IMMUTABLE", "LLT_IMPORTS", "LLT_CONSTRAINT",
  "LLT_ISSUB", "LLT_LET", "LLT_MODIFIES", "LLT_MUTABLE", "LLT_NOTHING",
  "LLT_INTERNAL", "LLT_FILESYS", "LLT_OBJ", "LLT_OUT", "LLT_SEF",
  "LLT_ONLY", "LLT_PARTIAL", "LLT_OWNED", "LLT_DEPENDENT", "LLT_KEEP",
  "LLT_KEPT", "LLT_TEMP", "LLT_SHARED", "LLT_UNIQUE", "LLT_UNUSED",
  "LLT_EXITS", "LLT_MAYEXIT", "LLT_NEVEREXIT", "LLT_TRUEEXIT",
  "LLT_FALSEEXIT", "LLT_UNDEF", "LLT_KILLED", "LLT_CHECKMOD",
  "LLT_CHECKED", "LLT_UNCHECKED", "LLT_CHECKEDSTRICT", "LLT_TRUENULL",
  "LLT_FALSENULL", "LLT_LNULL", "LLT_LNOTNULL", "LLT_RETURNED",
  "LLT_OBSERVER", "LLT_EXPOSED", "LLT_REFCOUNTED", "LLT_REFS",
  "LLT_RELNULL", "LLT_RELDEF", "LLT_KILLREF", "LLT_NULLTERMINATED",
  "LLT_TEMPREF", "LLT_NEWREF", "LLT_PRIVATE", "LLT_REQUIRES", "LLT_RESULT",
  "LLT_SIZEOF", "LLT_SPEC", "LLT_TAGGEDUNION", "LLT_THEN", "LLT_TYPE",
  "LLT_TYPEDEF", "LLT_UNCHANGED", "LLT_USES", "LLT_CHAR", "LLT_CONST",
  "LLT_DOUBLE", "LLT_ENUM", "LLT_FLOAT", "LLT_INT", "LLT_ITER",
  "LLT_YIELD", "LLT_LONG", "LLT_SHORT", "LLT_SIGNED", "LLT_UNKNOWN",
  "LLT_STRUCT", "LLT_TELIPSIS", "LLT_UNION", "LLT_UNSIGNED", "LLT_VOID",
  "LLT_VOLATILE", "LLT_PRINTFLIKE", "LLT_SCANFLIKE", "LLT_MESSAGELIKE",
  "$accept", "interface", "$@1", "externals", "external",
  "optDeclarations", "declarations", "declaration", "imports", "uses",
  "export", "iter", "iterParamList", "realIterParamList", "iterParam",
  "private", "$@2", "private2", "constDeclaration", "varDeclaration",
  "type", "special", "fcn", "$@3", "$@4", "claim", "$@5", "abstract",
  "$@6", "$@7", "$@8", "$@9", "$@10", "$@11", "$@12", "$@13", "exposed",
  "$@14", "$@15", "importNameList", "importName", "interfaceNameList",
  "interfaceName", "traitRefNodeList", "traitRef", "traitIdList",
  "renaming", "nameList", "replaceNodeList", "replace", "name",
  "initializer", "constLclExpr", "initDecls", "initDecl", "globals",
  "globalDecl", "privateInits", "privateInit", "optLetDecl", "beDeclList",
  "beDecl", "sortSpec", "optChecks", "optRequire", "optModify",
  "storeRefList", "storeRef", "optEnsure", "optClaim", "optParamList",
  "realParamList", "paramList", "optBody", "callExpr", "stmt", "valueList",
  "value", "abstBody", "fcns", "optTypeInv", "typeInv", "$@16",
  "declaratorInvs", "declaratorInv", "$@17", "optExposedBody", "CType",
  "CTypes", "typeSpecifier", "specialQualifier", "lclTypeSpec", "lclType",
  "pointers", "structOrUnionSpec", "$@18", "$@19", "optTagId",
  "structDecls", "structDecl", "declaratorList", "optCOMMA", "enumSpec",
  "enumeratorList", "declarator", "notype_decl", "after_type_decl",
  "parameter_decl", "param", "typeName", "optAbstDeclarator",
  "abstDeclarator", "arrayQual", "opForm", "open", "close", "anyOp",
  "middle", "placeList", "separator", "signature", "domain", "sortList",
  "lclPredicate", "term", "term0", "equalityTerm", "simpleOpTerm",
  "simpleOp2", "prefixOpTerm", "postfixOps", "infixOpPart", "secondary",
  "bracketed", "sqBracketed", "matched", "args", "primary", "termList",
  "stateFcn", "lclPrimary", "cLiteral", "quantifiers", "quantifier",
  "$@20", "quantifiedList", "quantified", "simpleIdOrTypedefName", "fcnId",
  "varId", "tagId", "claimId", "sortId", "traitId", "opId", YY_NULLPTR
};

static const char *
yysymbol_name (yysymbol_kind_t yysymbol)
{
  return yytname[yysymbol];
}
#endif

#define YYPACT_NINF (-531)

#define yypact_value_is_default(Yyn) \
  ((Yyn) == YYPACT_NINF)

#define YYTABLE_NINF (-409)

#define yytable_value_is_error(Yyn) \
  0

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
static const yytype_int16 yypact[] =
{
    -531,    58,   -18,  -531,    96,   229,   664,  -531,  -531,  -531,
    -531,  -531,   104,  -531,   155,  -531,  -531,  -531,   104,   225,
    -531,  -531,    40,  -531,  2602,   202,  2602,  -531,    44,  -531,
    -531,  -531,  -531,  -531,  -531,  -531,  -531,  -531,  -531,  -531,
    -531,  -531,  -531,  -531,  -531,  -531,  -531,  -531,  -531,  -531,
    -531,  -531,  -531,  -531,  -531,  -531,  -531,  -531,   119,  -531,
    -531,  -531,  -531,  -531,  -531,  -531,  2602,  -531,  2602,  -531,
     104,  -531,  -531,   139,  -531,  -531,  -531,  -531,   104,   104,
    -531,  -531,  2602,  -531,  -531,  -531,  -531,  -531,  -531,  -531,
    -531,  -531,  -531,  2602,  -531,  -531,  -531,  -531,  -531,   279,
    -531,  2602,   189,   163,   179,   233,    96,  -531,   348,  -531,
     229,  -531,  1483,  -531,   241,   258,  -531,  -531,   316,  -531,
     104,   331,   189,   308,   325,   273,  -531,   764,  -531,   189,
     365,  -531,   387,  -531,   407,  -531,   387,  -531,   387,   189,
     564,   564,   189,  -531,  -531,  -531,   189,   189,   255,  -531,
     191,   198,   213,  -531,  -531,  -531,  -531,  -531,   104,   429,
    -531,  -531,   104,  -531,   104,   319,  -531,  -531,   445,  -531,
    -531,   451,  2602,   441,   475,   481,  -531,   120,   432,  -531,
     445,   457,  -531,  -531,   484,  2602,   490,  2104,   301,   492,
     518,   522,   427,   428,  -531,  -531,  -531,  -531,  -531,   189,
     304,   525,  2178,   516,   517,   305,  -531,  -531,  -531,  -531,
    -531,   476,   482,   198,   213,   189,  -531,  2845,  1734,  2723,
    1808,  -531,  1882,  -531,  -531,  1483,  -531,  -531,   104,   104,
     445,   445,   531,  -531,   521,   318,   443,   120,  -531,  1483,
    1483,  1660,   120,  -531,   264,  -531,   235,    34,  -531,  -531,
     523,  -531,  -531,   524,  -531,   532,   173,  -531,  -531,  -531,
    -531,   551,   552,   541,  -531,  -531,  -531,  -531,   542,  2602,
     536,   544,  -531,  -531,  2602,  2602,  -531,  1734,  -531,  -531,
    -531,  -531,   316,  2755,  2845,  -531,  -531,  -531,  -531,   540,
    2845,   545,  -531,   548,   550,  -531,  -531,   414,  -531,   560,
    -531,    63,   458,  -531,    51,  2870,  2870,   549,   687,  -531,
    -531,    53,  -531,  -531,  -531,   553,   554,   557,   555,  -531,
     189,  -531,   556,  -531,   543,  -531,   561,   562,  -531,  -531,
     566,    34,  -531,   573,  -531,  -531,   578,   579,  -531,   481,
     432,  -531,   432,   568,   498,   264,  1956,  -531,   559,  -531,
    -531,  -531,  -531,  -531,   587,  -531,  -531,  2252,  -531,  1586,
     173,   198,   434,  -531,   347,   347,  -531,  -531,   189,   574,
     582,   594,   585,  -531,   580,  2178,   189,  2355,  -531,  2454,
     588,   139,   592,  -531,   249,    84,  2845,    16,  2845,  1362,
    1120,  -531,   293,  2845,   458,   458,  -531,  -531,   284,    51,
      51,   263,   263,   104,   104,   104,  -531,  -531,  -531,   104,
    2813,  -531,  2870,  -531,  2845,  -531,  2845,  -531,  -531,  -531,
     327,  -531,  -531,  -531,  -531,   598,   602,  -531,  -531,   576,
    -531,  -531,  -531,   590,   104,  -531,  -531,  1734,  -531,  -531,
     226,   434,  2030,  -531,    87,  -531,  -531,  -531,   347,   347,
    -531,  -531,   570,  -531,  -531,  -531,  -531,  -531,   341,  -531,
    -531,  -531,  -531,  -531,   603,  -531,   624,   104,   641,  2845,
    -531,   560,   385,  2845,   642,   637,   638,   640,   644,  -531,
    -531,  2602,   390,  -531,  -531,  -531,  -531,  -531,  -531,  -531,
    -531,  -531,   284,  -531,  -531,  -531,  -531,  -531,  -531,   409,
     263,   653,  -531,   391,     7,  -531,  -531,  -531,   650,  -531,
     655,   666,  -531,   675,  -531,   671,   670,    30,  -531,   874,
    -531,  -531,  -531,   678,  -531,   189,  -531,     7,   139,  2528,
    -531,   104,  -531,  2845,  -531,    33,  2845,  -531,  -531,  -531,
    -531,  1241,  -531,  -531,  -531,  -531,  -531,   139,  2602,  -531,
     668,  -531,   104,   104,   659,  -531,  -531,   104,   679,  -531,
    -531,   189,   708,  -531,  -531,   668,  -531,  2602,  -531,  -531,
    -531,   560,  2845,   689,  -531,   342,  -531,   131,   189,  2845,
     618,  -531,  -531,   618,  -531,  -531,  -531,   692,   618,  -531,
     560,  -531,   139,  -531,  2602,  2845,   354,   691,  2845,   667,
     682,  2845,   667,  -531,   684,  -531,  -531,  -531,   714,   999,
     715,   740,   715,   736,   715,  2845,  -531,   735,   738,   366,
    2845,   724,   167,   745,  -531,   724,  -531,  -531,  -531,  -531,
     742,  2845,   749,   754,   167,   282,  -531,   760,   774,  -531,
     773,  -531,   768,  -531,   456,  -531,   269,   167,  -531,   346,
     786,  -531,  -531,  -531,   167,  -531,   769,  -531,   463,   463,
    -531,   395,   782,  -531,   775,  -531,  -531,   776,  -531,   389,
     463,  -531,   197,   508,   882,  -531,   782,  -531,  -531,   408,
    -531,   425,  -531,  -531
};

/* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
   Performed when YYTABLE does not specify something else to do.  Zero
   means the default is an error.  */
static const yytype_int16 yydefact[] =
{
       4,     0,     2,     1,     0,     0,     8,     5,     6,     7,
     407,   406,     0,    74,     0,    70,    72,    77,     0,     0,
      78,   413,    80,   195,     0,     0,     0,    62,    53,   197,
     199,   200,   229,   201,   202,   203,   204,   211,   212,   213,
     198,   206,   207,   210,   208,   209,   231,   232,   214,   215,
     216,   217,   218,   225,   226,   227,   205,   228,   221,   222,
     219,   220,   224,   230,   223,    31,     0,   184,     0,   185,
     248,   186,   187,     0,   188,   189,   190,   192,   248,   248,
     191,   183,     0,    43,    44,    45,     3,    11,    23,    11,
      18,    19,    20,     0,    21,    22,    41,    42,   193,   196,
     233,     0,     0,   234,   235,     0,     0,    16,     0,    84,
       0,    17,     0,   221,   238,     0,   234,   235,   408,   411,
       0,     0,     0,     0,     0,     0,    59,     0,    65,     0,
       0,   410,   258,   409,     0,   242,   246,   244,   247,     0,
       9,    10,     0,   194,   236,   269,     0,     0,     0,   100,
     104,   262,   261,   263,    68,    69,    73,    71,     0,    82,
      79,   320,     0,   315,     0,     0,   345,   316,   322,   321,
     346,     0,     0,     0,    87,    86,    91,   286,    89,   285,
     322,   299,   319,   240,   239,     0,     0,   138,     0,   102,
       0,     0,     0,     0,    32,    33,    34,    35,    36,     0,
       0,     0,    25,     0,     0,     0,    12,    15,    13,    14,
     104,     0,     0,   265,   271,     0,    38,     0,    46,     0,
       0,   266,     0,   272,    85,     0,   311,   312,     0,     0,
     322,   322,   300,   324,     0,   323,     0,   286,    81,     0,
       0,     0,   290,   283,   287,   291,     0,     0,   301,   241,
       0,    52,   141,     0,   139,   140,   286,   143,    37,    63,
      54,     0,     0,    66,   177,   179,    39,   259,   255,     0,
       0,    26,    27,    30,     0,     0,    40,    48,   264,   270,
     101,   400,   409,     0,     0,   396,   397,   394,   395,     0,
       0,     0,   387,     0,     0,   103,    98,     0,    99,   334,
     336,   338,     0,   342,   347,   354,   358,   361,   353,   373,
     386,     0,   398,   414,   371,     0,     0,     0,     0,   105,
       0,   296,     0,   267,     0,   273,     0,     0,   313,   314,
       0,     0,   302,   307,   327,   326,     0,     0,   284,    88,
      90,    92,     0,     0,     0,   289,     0,   292,    94,    93,
      97,    96,   317,   318,   303,   237,   104,     0,   275,     0,
     290,   281,   280,   282,     0,     0,    57,    60,     0,     0,
     181,   256,     0,    29,     0,     0,     0,     0,   250,     0,
       0,     0,   365,   368,     0,     0,     0,     0,     0,     0,
       0,   367,     0,     0,     0,     0,   348,   347,   349,   343,
     344,   355,   359,     0,     0,     0,   382,   383,   384,     0,
       0,   385,   356,   374,     0,   399,     0,   107,   108,   109,
       0,   297,   268,   274,    83,   309,   304,   308,   325,     0,
     294,   288,   293,     0,   329,    95,   305,    50,   142,   144,
     290,   276,     0,   277,   171,   167,    64,    55,     0,     0,
     178,    67,   173,   180,   260,   257,    24,    28,     0,   253,
     243,   251,   245,   109,   401,   402,     0,     0,   363,     0,
     370,   380,     0,     0,     0,   195,     0,     0,     0,   132,
     133,     0,     0,   127,   130,   129,   366,   337,   341,   340,
     351,   350,     0,   412,   360,   375,   376,   379,   377,     0,
     357,     0,   333,     0,   112,   106,   310,   306,     0,   295,
       0,   330,   331,     0,   278,     0,     0,     0,    75,     0,
      58,    61,   175,     0,   174,     0,   252,   112,     0,     0,
     364,     0,   369,     0,   388,     0,     0,   393,   391,   389,
     131,     0,   390,   352,   378,   339,   372,     0,     0,   110,
     119,   298,     0,     0,   112,   279,   170,     0,     0,   168,
     172,     0,     0,   182,   254,   119,   403,     0,   404,   118,
     362,   381,     0,     0,   128,     0,   114,     0,     0,     0,
     121,   328,   332,   121,    76,   169,   104,     0,   121,   405,
     335,   392,     0,   113,     0,     0,     0,     0,     0,   123,
     145,     0,   123,   115,     0,   117,   111,   120,     0,     0,
     134,     0,   134,     0,   134,     0,   122,     0,     0,     0,
       0,   136,     0,     0,   176,   136,   116,   125,   124,   126,
       0,     0,     0,   409,     0,     0,   148,     0,     0,    51,
       0,   135,     0,    47,     0,   146,     0,     0,   150,     0,
       0,    49,   137,   149,     0,   147,   152,   151,     0,     0,
     154,     0,   157,   159,     0,   160,   408,     0,   161,     0,
       0,   153,   162,     0,     0,   164,   158,   163,   165,     0,
     155,     0,   166,   156
};

/* YYPGOTO[NTERM-NUM].  */
static const yytype_int16 yypgoto[] =
{
    -531,  -531,  -531,  -531,  -531,  -531,   721,  -531,  -531,   809,
     806,  -531,  -531,  -531,   438,   810,  -531,  -531,   688,   690,
     694,  -531,  -123,  -531,  -531,  -531,  -531,  -531,  -531,  -531,
    -531,  -531,  -531,  -531,  -531,  -531,  -531,  -531,  -531,  -531,
     712,  -531,   -10,  -531,   709,  -531,   597,  -531,   584,   589,
    -531,  -531,   605,  -115,   610,  -195,  -531,   364,  -531,  -485,
    -531,   236,  -524,   265,  -137,   248,   260,   326,  -133,   245,
    -531,  -174,  -531,  -531,  -484,  -531,  -471,  -461,  -315,  -531,
    -531,  -531,  -531,  -531,   503,  -531,  -531,   -73,  -531,  -531,
    -531,    -5,   -21,  -531,    38,  -531,  -531,   251,   599,   107,
    -531,  -531,    47,  -531,   -97,  -136,   161,   512,  -182,   210,
    -188,  -204,  -119,   627,   -56,  -266,   710,  -126,  -531,   643,
    -531,  -531,  -531,  -520,  -194,  -256,  -531,   124,   -94,   577,
    -531,  -531,  -285,   595,  -531,  -531,   596,  -265,   -64,  -531,
    -531,  -530,  -531,  -299,  -531,  -531,   359,     4,   -25,   -67,
     459,   756,  -382,    18,   656
};

/* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int16 yydefgoto[] =
{
       0,     1,     6,     2,     7,    86,   140,   206,     8,   207,
     208,    88,   270,   271,   272,   209,   127,   194,    90,    91,
      92,    93,    94,   318,   380,    95,   513,    96,   124,   365,
     125,   448,   193,   449,   123,   364,    97,   199,   369,    14,
      15,   517,    16,    19,    20,   108,   173,   174,   175,   176,
     348,   295,   296,   148,   149,   218,   319,   504,   549,   550,
     575,   576,   568,   580,   599,   610,   482,   483,   621,   632,
     253,   343,   255,   612,   656,   636,   661,   662,   446,   519,
     523,   524,   562,   263,   264,   370,   453,    98,    99,   100,
     101,   256,   484,   184,   116,   203,   204,   130,   377,   378,
     458,   372,   117,   268,   189,   151,   152,   362,   257,   178,
     243,   244,   245,   179,   297,   354,   181,   234,   235,   469,
     435,   510,   511,   501,   502,   299,   300,   301,   302,   303,
     399,   400,   304,   305,   306,   307,   384,   308,   472,   413,
     309,   310,   311,   312,   381,   464,   465,   313,   664,   314,
     132,   121,   494,    22,   315
};

/* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule whose
   number is the opposite.  If YYTABLE_NINF, syntax error.  */
static const yytype_int16 yytable[] =
{
     120,   102,   105,   115,   198,   150,   134,   188,    17,    21,
     211,   213,   415,   254,   200,   277,    17,   397,   182,   114,
     273,   122,    21,   298,   205,   298,   143,   497,   385,   119,
     393,   391,   221,   223,   387,   153,   109,   344,   345,     4,
     401,   402,   565,   589,   103,   210,   324,   393,   326,   338,
     447,   352,   512,   104,   247,   153,   180,   557,     3,   597,
     558,   128,   153,   129,   353,   426,   281,   547,   363,   583,
     604,   182,   153,   112,   131,   153,   166,   139,   608,   153,
     153,   613,   131,   131,   572,   530,   414,   373,   142,   383,
     170,   394,   221,   223,   221,   223,   144,     5,   393,    10,
     630,   395,   265,   383,   330,   331,    11,   177,    10,   231,
      17,   642,   548,   490,    21,    11,    10,   516,   470,   663,
     361,    12,   102,    11,   119,   347,   486,   473,   663,   663,
     471,   182,   153,   520,   521,   102,   102,   487,   635,    13,
     663,   -56,   663,   663,   663,   182,   182,   500,   153,   570,
     644,   219,   182,   241,   471,   344,   345,   594,   133,   242,
     471,   437,    21,   657,   250,   103,   226,   237,   227,   180,
     581,   582,   433,   349,   104,   439,   224,   595,   103,   103,
     114,   126,   106,   180,   180,   358,   633,   104,   104,   153,
     180,   107,   133,   273,   474,   477,   485,   668,   669,   154,
     634,   145,   679,   681,   219,   420,   359,   543,   133,   676,
     398,   677,   360,   320,    10,   155,   633,   535,  -102,   217,
     177,   118,   146,   211,   213,   347,   347,  -102,   147,   219,
     659,   220,   328,   329,   177,   177,   345,   285,   286,   287,
     288,    10,   221,   443,   219,   133,   222,    10,    11,   161,
     162,   163,   110,   153,    11,   164,   165,   219,   156,   359,
     166,   111,    18,   587,   167,   440,   168,   334,   515,   376,
     376,   265,   320,   169,   170,   532,   335,   571,   404,   459,
     183,   468,   215,   405,   185,   406,   407,   408,   633,   409,
     171,   216,   153,   153,   410,   219,    10,   346,   411,   655,
     163,   153,   634,   282,   213,   491,   492,   212,   214,   153,
     352,   334,   645,   167,   466,   283,   590,   284,   646,   647,
     335,   648,   443,   353,   285,   286,   287,   288,   215,   135,
     137,   215,   215,   161,   228,   163,   334,   258,   289,   229,
     266,   276,   573,   291,   166,   335,   499,   485,   167,  -406,
     230,    67,   503,    69,   215,    71,    72,   169,   170,    74,
      75,    76,    77,   505,   187,   633,    80,    81,   525,   592,
     192,   658,   376,   153,   376,   158,   444,   526,   593,   659,
     660,   215,   159,   445,   476,   114,   285,   286,   287,   288,
     606,   292,   293,   541,   201,    67,   560,    69,   294,    71,
      72,   605,   629,    74,    75,    76,    77,   493,   495,   496,
      80,    81,   533,   493,   672,   485,  -249,   541,   533,   534,
     190,   626,   670,   675,   542,   546,    10,   281,   564,   671,
     163,   352,   320,   282,   518,   670,   533,   191,   493,   166,
     202,   544,   682,   167,   353,   283,   600,   284,    17,   340,
     342,   602,   670,   170,   285,   286,   287,   288,   153,   683,
     540,   466,   225,   596,   586,   219,   233,   442,   289,   290,
      10,   493,   236,   291,   163,   238,   114,   282,   248,   623,
     577,   625,   633,   166,   461,   246,   461,   167,   658,   283,
     653,   284,   654,   647,   153,   648,   659,   170,   285,   286,
     287,   288,   239,   285,   286,   287,   288,   219,   240,   220,
     278,   153,   289,   219,   561,   222,   279,   291,   488,   489,
     217,   292,   293,   249,   569,   577,   251,   633,   294,   219,
     259,   346,   431,   658,   260,   493,   114,   136,   138,   261,
     262,   659,   678,   578,   267,   274,   275,   584,   285,   286,
     287,   288,   332,   333,   337,   638,   493,   493,   356,   357,
     355,    17,   569,   366,   367,   292,   293,   638,   368,   371,
     374,   375,   294,   386,   393,   403,    23,   422,   388,   638,
     638,   389,   665,   390,   419,   434,   416,   638,   421,   569,
     417,   665,   665,   418,   427,   423,   424,   637,   425,   428,
     429,    24,   430,   665,   114,   665,   665,   665,   436,   637,
     451,   452,    25,   454,    26,   455,   456,   463,   467,   506,
      27,   637,   637,   507,   509,   667,    28,   508,   522,   637,
     528,    29,    30,    31,    32,    33,    34,    35,    36,    37,
      38,    39,    40,    41,    42,    43,    44,    45,    46,    47,
     529,    48,    49,    50,    51,    52,    53,    54,    55,    56,
      57,    58,    59,    60,    61,    62,    63,   531,    64,   536,
    -407,   551,   537,    65,   538,   552,    23,    66,   539,     5,
      67,    68,    69,    70,    71,    72,    73,   545,    74,    75,
      76,    77,    78,   553,    79,    80,    81,    82,    83,    84,
      85,    24,   404,   163,   554,   555,   556,   405,   563,   406,
     407,   408,    25,   409,    26,   585,   167,   579,   410,   547,
      27,   281,   411,   591,   598,   601,    28,   607,   609,   611,
     615,    29,    30,    31,    32,    33,    34,    35,    36,    37,
      38,    39,    40,    41,    42,    43,    44,    45,    46,    47,
     616,    48,    49,    50,    51,    52,    53,    54,    55,    56,
      57,    58,    59,    60,    61,    62,    63,   620,    64,   622,
     624,   627,   631,    65,   628,   639,    23,    66,   641,   643,
      67,    68,    69,    70,    71,    72,    73,  -408,    74,    75,
      76,    77,    78,   649,    79,    80,    81,    82,    83,    84,
      85,    24,   650,   651,   652,   666,   647,   672,   673,   674,
     141,     9,    87,   457,    26,   195,    89,   196,   157,   160,
      27,   197,   327,   339,   322,   280,    28,   527,   603,   341,
     588,    29,    30,    31,    32,    33,    34,    35,    36,    37,
      38,    39,    40,    41,    42,    43,    44,    45,    46,    47,
     614,    48,    49,    50,    51,    52,    53,    54,    55,    56,
      57,    58,    59,    60,    61,    62,    63,   574,    64,   619,
     640,   450,   441,   350,   379,   232,   186,    66,   336,   396,
      67,    68,    69,    70,    71,    72,    23,   566,    74,    75,
      76,    77,    78,   392,    79,    80,    81,    82,    83,    84,
      85,   633,   351,   412,   559,     0,     0,   658,     0,     0,
       0,    24,     0,     0,     0,   659,   680,     0,     0,     0,
       0,     0,   285,   286,   287,   288,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,    29,    30,    31,    32,    33,    34,    35,    36,    37,
      38,    39,    40,    41,    42,    43,    44,    45,    46,    47,
       0,    48,    49,    50,    51,    52,    53,    54,    55,    56,
      57,   113,    59,    60,    61,    62,    63,     0,    64,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
      67,     0,    69,    70,    71,    72,     0,     0,    74,    75,
      76,    77,    78,     0,    79,    80,    81,     0,    83,    84,
      85,   475,   281,     0,     0,   163,     0,     0,   282,     0,
       0,     0,     0,     0,   166,     0,     0,     0,   167,     0,
     283,     0,   284,     0,     0,     0,    24,     0,   170,   285,
     286,   287,   288,     0,   617,     0,     0,     0,     0,     0,
       0,     0,     0,   289,   290,     0,     0,     0,   291,     0,
       0,     0,   618,   479,   480,   481,    29,    30,    31,    32,
      33,    34,    35,    36,    37,    38,    39,    40,    41,    42,
      43,    44,    45,    46,    47,     0,    48,    49,    50,    51,
      52,    53,    54,    55,    56,    57,   113,    59,    60,    61,
      62,    63,     0,    64,     0,     0,   292,   293,     0,     0,
       0,     0,     0,   294,     0,    67,     0,    69,    70,    71,
      72,     0,     0,    74,    75,    76,    77,    78,     0,    79,
      80,    81,   475,   281,     0,     0,   163,     0,     0,   282,
       0,     0,     0,     0,     0,   166,     0,     0,     0,   167,
       0,   283,     0,   284,     0,     0,     0,    24,     0,   170,
     285,   286,   287,   288,   478,     0,     0,     0,     0,     0,
       0,     0,     0,     0,   289,   290,     0,     0,     0,   291,
       0,     0,     0,     0,   479,   480,   481,    29,    30,    31,
      32,    33,    34,    35,    36,    37,    38,    39,    40,    41,
      42,    43,    44,    45,    46,    47,     0,    48,    49,    50,
      51,    52,    53,    54,    55,    56,    57,   113,    59,    60,
      61,    62,    63,     0,    64,     0,     0,   292,   293,     0,
       0,     0,     0,     0,   294,     0,    67,     0,    69,    70,
      71,    72,     0,     0,    74,    75,    76,    77,    78,     0,
      79,    80,    81,   475,   281,     0,     0,   163,     0,     0,
     282,     0,     0,     0,     0,     0,   166,     0,     0,     0,
     167,     0,   283,     0,   284,     0,     0,     0,    24,     0,
     170,   285,   286,   287,   288,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,   289,   290,     0,     0,     0,
     291,     0,     0,     0,     0,   479,   480,   481,    29,    30,
      31,    32,    33,    34,    35,    36,    37,    38,    39,    40,
      41,    42,    43,    44,    45,    46,    47,     0,    48,    49,
      50,    51,    52,    53,    54,    55,    56,    57,   113,    59,
      60,    61,    62,    63,     0,    64,     0,     0,   292,   293,
       0,     0,     0,     0,     0,   294,     0,    67,     0,    69,
      70,    71,    72,     0,     0,    74,    75,    76,    77,    78,
       0,    79,    80,    81,   475,   281,     0,     0,   163,     0,
       0,   282,     0,     0,     0,     0,     0,   166,     0,     0,
       0,   167,     0,   283,     0,   284,     0,     0,     0,    24,
       0,   170,   285,   286,   287,   288,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,   289,   290,     0,     0,
       0,   291,     0,     0,     0,     0,     0,     0,     0,    29,
      30,    31,    32,    33,    34,    35,    36,    37,    38,    39,
      40,    41,    42,    43,    44,    45,    46,    47,     0,    48,
      49,    50,    51,    52,    53,    54,    55,    56,    57,   113,
      59,    60,    61,    62,    63,     0,    64,     0,     0,   292,
     293,     0,     0,     0,     0,     0,   294,     0,    67,     0,
      69,    70,    71,    72,     0,     0,    74,    75,    76,    77,
      78,     0,    79,    80,    81,    23,     0,   161,   162,   163,
       0,     0,     0,   164,   165,     0,     0,     0,   166,     0,
       0,     0,   167,     0,   168,     0,     0,     0,     0,     0,
      24,   169,   170,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,   171,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,   172,
      29,    30,    31,    32,    33,    34,    35,    36,    37,    38,
      39,    40,    41,    42,    43,    44,    45,    46,    47,     0,
      48,    49,    50,    51,    52,    53,    54,    55,    56,    57,
     113,    59,    60,    61,    62,    63,     0,    64,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,    23,    67,
       0,    69,    70,    71,    72,   133,     0,    74,    75,    76,
      77,    78,     0,    79,    80,    81,     0,   219,     0,   359,
       0,     0,     0,    24,     0,   440,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,    29,    30,    31,    32,    33,    34,    35,
      36,    37,    38,    39,    40,    41,    42,    43,    44,    45,
      46,    47,    23,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57,   113,    59,    60,    61,    62,    63,     0,
      64,   219,     0,   241,     0,     0,     0,    24,     0,   242,
       0,     0,    67,     0,    69,    70,    71,    72,     0,     0,
      74,    75,    76,    77,    78,   252,    79,    80,    81,     0,
       0,     0,     0,     0,     0,     0,     0,    29,    30,    31,
      32,    33,    34,    35,    36,    37,    38,    39,    40,    41,
      42,    43,    44,    45,    46,    47,    23,    48,    49,    50,
      51,    52,    53,    54,    55,    56,    57,   113,    59,    60,
      61,    62,    63,     0,    64,     0,     0,     0,     0,     0,
       0,    24,     0,     0,     0,     0,    67,     0,    69,    70,
      71,    72,     0,     0,    74,    75,    76,    77,    78,   252,
      79,    80,    81,     0,     0,     0,     0,     0,   316,   317,
       0,    29,    30,    31,    32,    33,    34,    35,    36,    37,
      38,    39,    40,    41,    42,    43,    44,    45,    46,    47,
      23,    48,    49,    50,    51,    52,    53,    54,    55,    56,
      57,   113,    59,    60,    61,    62,    63,     0,    64,     0,
       0,     0,   323,     0,     0,    24,     0,     0,     0,     0,
      67,     0,    69,    70,    71,    72,     0,     0,    74,    75,
      76,    77,    78,     0,    79,    80,    81,     0,     0,     0,
       0,     0,     0,     0,     0,    29,    30,    31,    32,    33,
      34,    35,    36,    37,    38,    39,    40,    41,    42,    43,
      44,    45,    46,    47,    23,    48,    49,    50,    51,    52,
      53,    54,    55,    56,    57,   113,    59,    60,    61,    62,
      63,     0,    64,     0,     0,     0,   325,     0,     0,    24,
       0,     0,     0,     0,    67,     0,    69,    70,    71,    72,
       0,     0,    74,    75,    76,    77,    78,   252,    79,    80,
      81,     0,     0,     0,     0,     0,     0,     0,     0,    29,
      30,    31,    32,    33,    34,    35,    36,    37,    38,    39,
      40,    41,    42,    43,    44,    45,    46,    47,    23,    48,
      49,    50,    51,    52,    53,    54,    55,    56,    57,   113,
      59,    60,    61,    62,    63,     0,    64,     0,     0,     0,
     432,     0,     0,    24,     0,     0,     0,     0,    67,     0,
      69,    70,    71,    72,     0,     0,    74,    75,    76,    77,
      78,   252,    79,    80,    81,     0,     0,     0,     0,     0,
       0,     0,     0,    29,    30,    31,    32,    33,    34,    35,
      36,    37,    38,    39,    40,    41,    42,    43,    44,    45,
      46,    47,    23,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57,   113,    59,    60,    61,    62,    63,     0,
      64,     0,     0,     0,   514,     0,     0,    24,     0,     0,
       0,     0,    67,     0,    69,    70,    71,    72,     0,     0,
      74,    75,    76,    77,    78,   252,    79,    80,    81,     0,
       0,     0,     0,     0,     0,     0,     0,    29,    30,    31,
      32,    33,    34,    35,    36,    37,    38,    39,    40,    41,
      42,    43,    44,    45,    46,    47,    23,    48,    49,    50,
      51,    52,    53,    54,    55,    56,    57,   113,    59,    60,
      61,    62,    63,     0,    64,     0,     0,     0,     0,     0,
       0,    24,     0,     0,     0,     0,    67,     0,    69,    70,
      71,    72,     0,     0,    74,    75,    76,    77,    78,   252,
      79,    80,    81,     0,     0,     0,     0,     0,     0,     0,
       0,    29,    30,    31,    32,    33,    34,    35,    36,    37,
      38,    39,    40,    41,    42,    43,    44,    45,    46,    47,
      23,    48,    49,    50,    51,    52,    53,    54,    55,    56,
      57,   113,    59,    60,    61,    62,    63,     0,    64,     0,
       0,     0,     0,     0,     0,    24,     0,     0,     0,     0,
      67,     0,    69,    70,    71,    72,     0,     0,    74,    75,
      76,    77,    78,   252,    79,    80,    81,     0,     0,     0,
       0,     0,     0,     0,     0,    29,    30,    31,    32,    33,
      34,    35,    36,    37,    38,    39,    40,    41,    42,    43,
      44,    45,    46,    47,    23,    48,    49,    50,    51,    52,
      53,    54,    55,    56,    57,   113,    59,    60,    61,    62,
      63,     0,    64,     0,     0,     0,     0,     0,     0,    24,
       0,     0,     0,     0,    67,     0,    69,    70,    71,    72,
       0,   269,    74,    75,    76,    77,    78,     0,    79,    80,
      81,     0,     0,     0,     0,     0,     0,     0,     0,    29,
      30,    31,    32,    33,    34,    35,    36,    37,    38,    39,
      40,    41,    42,    43,    44,    45,    46,    47,     0,    48,
      49,    50,    51,    52,    53,    54,    55,    56,    57,   113,
      59,    60,    61,    62,    63,     0,    64,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,    23,    67,     0,
      69,    70,    71,    72,     0,     0,    74,    75,    76,    77,
      78,   438,    79,    80,    81,   460,     0,     0,     0,     0,
       0,     0,    24,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,    29,    30,    31,    32,    33,    34,    35,    36,
      37,    38,    39,    40,    41,    42,    43,    44,    45,    46,
      47,     0,    48,    49,    50,    51,    52,    53,    54,    55,
      56,    57,   113,    59,    60,    61,    62,    63,     0,    64,
       0,     0,     0,     0,     0,     0,    23,     0,     0,     0,
       0,    67,     0,    69,    70,    71,    72,     0,     0,    74,
      75,    76,    77,    78,   462,    79,    80,    81,     0,     0,
       0,    24,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,    29,    30,    31,    32,    33,    34,    35,    36,    37,
      38,    39,    40,    41,    42,    43,    44,    45,    46,    47,
      23,    48,    49,    50,    51,    52,    53,    54,    55,    56,
      57,   113,    59,    60,    61,    62,    63,     0,    64,     0,
       0,     0,     0,     0,     0,    24,     0,     0,     0,     0,
      67,     0,    69,    70,    71,    72,     0,     0,    74,    75,
      76,    77,    78,     0,    79,    80,    81,     0,     0,     0,
       0,     0,     0,     0,   567,    29,    30,    31,    32,    33,
      34,    35,    36,    37,    38,    39,    40,    41,    42,    43,
      44,    45,    46,    47,    23,    48,    49,    50,    51,    52,
      53,    54,    55,    56,    57,   113,    59,    60,    61,    62,
      63,     0,    64,     0,     0,     0,     0,     0,     0,    24,
       0,     0,     0,     0,    67,     0,    69,    70,    71,    72,
       0,     0,    74,    75,    76,    77,    78,     0,    79,    80,
      81,     0,     0,     0,     0,     0,     0,     0,     0,    29,
      30,    31,    32,    33,    34,    35,    36,    37,    38,    39,
      40,    41,    42,    43,    44,    45,    46,    47,     0,    48,
      49,    50,    51,    52,    53,    54,    55,    56,    57,   113,
      59,    60,    61,    62,    63,     0,    64,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,    67,     0,
      69,    70,    71,    72,     0,     0,    74,    75,    76,    77,
      78,     0,    79,    80,    81,    10,   281,     0,     0,   163,
       0,     0,   282,     0,     0,     0,     0,     0,   166,     0,
       0,     0,   167,     0,   283,   321,   284,     0,     0,     0,
       0,     0,   170,   285,   286,   287,   288,    10,   281,     0,
       0,   163,     0,     0,   282,     0,     0,   289,   290,     0,
     166,     0,   291,     0,   167,     0,   283,   382,   284,     0,
       0,     0,     0,     0,   170,   285,   286,   287,   288,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,   289,
     290,     0,     0,     0,   291,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,    10,   281,     0,     0,   163,
     292,   293,   282,     0,     0,     0,     0,   294,   166,     0,
       0,     0,   167,     0,   283,   498,   284,     0,     0,     0,
       0,     0,   170,   285,   286,   287,   288,    10,   281,     0,
       0,   163,   292,   293,   282,     0,     0,   289,   290,   294,
     166,     0,   291,     0,   167,     0,   283,     0,   284,     0,
       0,     0,    10,     0,   170,   285,   286,   287,   288,   282,
       0,     0,     0,     0,     0,     0,     0,     0,     0,   289,
     290,     0,     0,   284,   291,     0,     0,     0,     0,     0,
     285,   286,   287,   288,     0,     0,     0,     0,     0,     0,
     292,   293,     0,     0,   289,     0,     0,   294,     0,   291,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,   292,   293,     0,     0,     0,     0,     0,   294,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,   292,   293,     0,
       0,     0,     0,     0,   294
};

static const yytype_int16 yycheck[] =
{
      25,     6,    12,    24,   127,   102,    73,   122,     4,     5,
     146,   147,   311,   187,   129,   210,    12,   302,   112,    24,
     202,    26,    18,   217,   139,   219,    99,   409,   284,    25,
      14,   297,   151,   152,   290,   102,    18,   241,   242,    57,
     305,   306,   527,   567,     6,   142,   220,    14,   222,   237,
     365,    17,   434,     6,   180,   122,   112,    27,     0,   579,
      30,    66,   129,    68,    30,   331,    13,    60,   256,   554,
     594,   165,   139,    33,    70,   142,    25,    82,   598,   146,
     147,   601,    78,    79,    51,   467,    33,   269,    93,   283,
      39,    28,   211,   212,   213,   214,   101,   115,    14,    12,
     620,    38,   199,   297,   230,   231,    19,   112,    12,   165,
     106,   631,   105,   398,   110,    19,    12,    30,    34,   649,
     256,    25,   127,    19,   120,   244,   392,   111,   658,   659,
     386,   225,   199,   448,   449,   140,   141,   393,   622,    43,
     670,    97,   672,   673,   674,   239,   240,   412,   215,   531,
     634,    31,   246,    33,   410,   359,   360,    26,    19,    39,
     416,   356,   158,   647,   185,   127,   162,   172,   164,   225,
     552,   553,   346,   246,   127,   357,   158,    46,   140,   141,
     185,    62,    27,   239,   240,    12,    19,   140,   141,   256,
     246,    36,    19,   375,   388,   389,   390,   658,   659,    36,
      33,    12,   673,   674,    31,   320,    33,   492,    19,   670,
     304,   672,    39,   218,    12,    36,    19,   473,    27,    28,
     225,    19,    33,   359,   360,   344,   345,    36,    39,    31,
      33,    33,   228,   229,   239,   240,   440,    40,    41,    42,
      43,    12,   361,   362,    31,    19,    33,    12,    19,    14,
      15,    16,    27,   320,    19,    20,    21,    31,    25,    33,
      25,    36,    33,   562,    29,    39,    31,    18,   442,   274,
     275,   368,   277,    38,    39,   469,    27,   533,    15,   376,
      39,    32,    27,    20,    26,    22,    23,    24,    19,    26,
      55,    36,   359,   360,    31,    31,    12,    33,    35,    30,
      16,   368,    33,    19,   440,   399,   400,   146,   147,   376,
      17,    18,    30,    29,   381,    31,   572,    33,    36,    37,
      27,    39,   441,    30,    40,    41,    42,    43,    27,    78,
      79,    27,    27,    14,    15,    16,    18,    36,    54,    20,
      36,    36,   536,    59,    25,    27,   410,   541,    29,    33,
      31,   116,   416,   118,    27,   120,   121,    38,    39,   124,
     125,   126,   127,    36,    33,    19,   131,   132,    27,    27,
      97,    25,   377,   440,   379,    27,    29,    36,    36,    33,
      34,    27,    34,    36,   389,   390,    40,    41,    42,    43,
      36,   107,   108,    27,    29,   116,   519,   118,   114,   120,
     121,   595,    36,   124,   125,   126,   127,   403,   404,   405,
     131,   132,    27,   409,    25,   609,    29,    27,    27,    34,
     112,   615,    27,    34,    34,    34,    12,    13,   525,    34,
      16,    17,   437,    19,   444,    27,    27,   112,   434,    25,
      33,    32,    34,    29,    30,    31,   583,    33,   444,   239,
     240,   588,    27,    39,    40,    41,    42,    43,   525,    34,
     481,   528,    33,   578,   561,    31,    21,    33,    54,    55,
      12,   467,    21,    59,    16,    34,   481,    19,    21,   612,
     547,   614,    19,    25,   377,    53,   379,    29,    25,    31,
      34,    33,    36,    37,   561,    39,    33,    39,    40,    41,
      42,    43,    27,    40,    41,    42,    43,    31,    27,    33,
      34,   578,    54,    31,   519,    33,    34,    59,   394,   395,
      28,   107,   108,    39,   529,   592,    36,    19,   114,    31,
      12,    33,    34,    25,    12,   531,   541,    78,    79,   112,
     112,    33,    34,   548,    19,    29,    29,   557,    40,    41,
      42,    43,    21,    32,   111,   622,   552,   553,    34,    27,
      37,   557,   567,    12,    12,   107,   108,   634,    27,    27,
      34,    27,   114,    33,    14,    26,    12,    34,    33,   646,
     647,    33,   649,    33,    29,    26,    33,   654,    32,   594,
      36,   658,   659,    36,    21,    34,    34,   622,    32,    21,
      21,    37,    34,   670,   609,   672,   673,   674,    21,   634,
      36,    29,    48,    19,    50,    30,    36,    29,    26,    21,
      56,   646,   647,    21,    34,   650,    62,    51,    58,   654,
      27,    67,    68,    69,    70,    71,    72,    73,    74,    75,
      76,    77,    78,    79,    80,    81,    82,    83,    84,    85,
      26,    87,    88,    89,    90,    91,    92,    93,    94,    95,
      96,    97,    98,    99,   100,   101,   102,    26,   104,    27,
      33,    21,    34,   109,    34,    20,    12,   113,    34,   115,
     116,   117,   118,   119,   120,   121,   122,    34,   124,   125,
     126,   127,   128,    27,   130,   131,   132,   133,   134,   135,
     136,    37,    15,    16,    29,    34,    36,    20,    30,    22,
      23,    24,    48,    26,    50,    36,    29,    49,    31,    60,
      56,    13,    35,    34,   106,    33,    62,    36,    61,    47,
      46,    67,    68,    69,    70,    71,    72,    73,    74,    75,
      76,    77,    78,    79,    80,    81,    82,    83,    84,    85,
      36,    87,    88,    89,    90,    91,    92,    93,    94,    95,
      96,    97,    98,    99,   100,   101,   102,    52,   104,    29,
      34,    36,    48,   109,    36,    30,    12,   113,    36,    30,
     116,   117,   118,   119,   120,   121,   122,    33,   124,   125,
     126,   127,   128,    33,   130,   131,   132,   133,   134,   135,
     136,    37,    28,    30,    36,    19,    37,    25,    33,    33,
      89,     2,     6,   375,    50,   127,     6,   127,   106,   110,
      56,   127,   225,   239,   219,   215,    62,   463,   592,   240,
     565,    67,    68,    69,    70,    71,    72,    73,    74,    75,
      76,    77,    78,    79,    80,    81,    82,    83,    84,    85,
     602,    87,    88,    89,    90,    91,    92,    93,    94,    95,
      96,    97,    98,    99,   100,   101,   102,   541,   104,   609,
     625,   368,   360,   246,   275,   165,   120,   113,   235,   302,
     116,   117,   118,   119,   120,   121,    12,   528,   124,   125,
     126,   127,   128,   297,   130,   131,   132,   133,   134,   135,
     136,    19,   246,   308,    30,    -1,    -1,    25,    -1,    -1,
      -1,    37,    -1,    -1,    -1,    33,    34,    -1,    -1,    -1,
      -1,    -1,    40,    41,    42,    43,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    67,    68,    69,    70,    71,    72,    73,    74,    75,
      76,    77,    78,    79,    80,    81,    82,    83,    84,    85,
      -1,    87,    88,    89,    90,    91,    92,    93,    94,    95,
      96,    97,    98,    99,   100,   101,   102,    -1,   104,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
     116,    -1,   118,   119,   120,   121,    -1,    -1,   124,   125,
     126,   127,   128,    -1,   130,   131,   132,    -1,   134,   135,
     136,    12,    13,    -1,    -1,    16,    -1,    -1,    19,    -1,
      -1,    -1,    -1,    -1,    25,    -1,    -1,    -1,    29,    -1,
      31,    -1,    33,    -1,    -1,    -1,    37,    -1,    39,    40,
      41,    42,    43,    -1,    45,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    54,    55,    -1,    -1,    -1,    59,    -1,
      -1,    -1,    63,    64,    65,    66,    67,    68,    69,    70,
      71,    72,    73,    74,    75,    76,    77,    78,    79,    80,
      81,    82,    83,    84,    85,    -1,    87,    88,    89,    90,
      91,    92,    93,    94,    95,    96,    97,    98,    99,   100,
     101,   102,    -1,   104,    -1,    -1,   107,   108,    -1,    -1,
      -1,    -1,    -1,   114,    -1,   116,    -1,   118,   119,   120,
     121,    -1,    -1,   124,   125,   126,   127,   128,    -1,   130,
     131,   132,    12,    13,    -1,    -1,    16,    -1,    -1,    19,
      -1,    -1,    -1,    -1,    -1,    25,    -1,    -1,    -1,    29,
      -1,    31,    -1,    33,    -1,    -1,    -1,    37,    -1,    39,
      40,    41,    42,    43,    44,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    54,    55,    -1,    -1,    -1,    59,
      -1,    -1,    -1,    -1,    64,    65,    66,    67,    68,    69,
      70,    71,    72,    73,    74,    75,    76,    77,    78,    79,
      80,    81,    82,    83,    84,    85,    -1,    87,    88,    89,
      90,    91,    92,    93,    94,    95,    96,    97,    98,    99,
     100,   101,   102,    -1,   104,    -1,    -1,   107,   108,    -1,
      -1,    -1,    -1,    -1,   114,    -1,   116,    -1,   118,   119,
     120,   121,    -1,    -1,   124,   125,   126,   127,   128,    -1,
     130,   131,   132,    12,    13,    -1,    -1,    16,    -1,    -1,
      19,    -1,    -1,    -1,    -1,    -1,    25,    -1,    -1,    -1,
      29,    -1,    31,    -1,    33,    -1,    -1,    -1,    37,    -1,
      39,    40,    41,    42,    43,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    54,    55,    -1,    -1,    -1,
      59,    -1,    -1,    -1,    -1,    64,    65,    66,    67,    68,
      69,    70,    71,    72,    73,    74,    75,    76,    77,    78,
      79,    80,    81,    82,    83,    84,    85,    -1,    87,    88,
      89,    90,    91,    92,    93,    94,    95,    96,    97,    98,
      99,   100,   101,   102,    -1,   104,    -1,    -1,   107,   108,
      -1,    -1,    -1,    -1,    -1,   114,    -1,   116,    -1,   118,
     119,   120,   121,    -1,    -1,   124,   125,   126,   127,   128,
      -1,   130,   131,   132,    12,    13,    -1,    -1,    16,    -1,
      -1,    19,    -1,    -1,    -1,    -1,    -1,    25,    -1,    -1,
      -1,    29,    -1,    31,    -1,    33,    -1,    -1,    -1,    37,
      -1,    39,    40,    41,    42,    43,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    54,    55,    -1,    -1,
      -1,    59,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    67,
      68,    69,    70,    71,    72,    73,    74,    75,    76,    77,
      78,    79,    80,    81,    82,    83,    84,    85,    -1,    87,
      88,    89,    90,    91,    92,    93,    94,    95,    96,    97,
      98,    99,   100,   101,   102,    -1,   104,    -1,    -1,   107,
     108,    -1,    -1,    -1,    -1,    -1,   114,    -1,   116,    -1,
     118,   119,   120,   121,    -1,    -1,   124,   125,   126,   127,
     128,    -1,   130,   131,   132,    12,    -1,    14,    15,    16,
      -1,    -1,    -1,    20,    21,    -1,    -1,    -1,    25,    -1,
      -1,    -1,    29,    -1,    31,    -1,    -1,    -1,    -1,    -1,
      37,    38,    39,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    55,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    66,
      67,    68,    69,    70,    71,    72,    73,    74,    75,    76,
      77,    78,    79,    80,    81,    82,    83,    84,    85,    -1,
      87,    88,    89,    90,    91,    92,    93,    94,    95,    96,
      97,    98,    99,   100,   101,   102,    -1,   104,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    12,   116,
      -1,   118,   119,   120,   121,    19,    -1,   124,   125,   126,
     127,   128,    -1,   130,   131,   132,    -1,    31,    -1,    33,
      -1,    -1,    -1,    37,    -1,    39,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    67,    68,    69,    70,    71,    72,    73,
      74,    75,    76,    77,    78,    79,    80,    81,    82,    83,
      84,    85,    12,    87,    88,    89,    90,    91,    92,    93,
      94,    95,    96,    97,    98,    99,   100,   101,   102,    -1,
     104,    31,    -1,    33,    -1,    -1,    -1,    37,    -1,    39,
      -1,    -1,   116,    -1,   118,   119,   120,   121,    -1,    -1,
     124,   125,   126,   127,   128,   129,   130,   131,   132,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    67,    68,    69,
      70,    71,    72,    73,    74,    75,    76,    77,    78,    79,
      80,    81,    82,    83,    84,    85,    12,    87,    88,    89,
      90,    91,    92,    93,    94,    95,    96,    97,    98,    99,
     100,   101,   102,    -1,   104,    -1,    -1,    -1,    -1,    -1,
      -1,    37,    -1,    -1,    -1,    -1,   116,    -1,   118,   119,
     120,   121,    -1,    -1,   124,   125,   126,   127,   128,   129,
     130,   131,   132,    -1,    -1,    -1,    -1,    -1,    64,    65,
      -1,    67,    68,    69,    70,    71,    72,    73,    74,    75,
      76,    77,    78,    79,    80,    81,    82,    83,    84,    85,
      12,    87,    88,    89,    90,    91,    92,    93,    94,    95,
      96,    97,    98,    99,   100,   101,   102,    -1,   104,    -1,
      -1,    -1,    34,    -1,    -1,    37,    -1,    -1,    -1,    -1,
     116,    -1,   118,   119,   120,   121,    -1,    -1,   124,   125,
     126,   127,   128,    -1,   130,   131,   132,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    67,    68,    69,    70,    71,
      72,    73,    74,    75,    76,    77,    78,    79,    80,    81,
      82,    83,    84,    85,    12,    87,    88,    89,    90,    91,
      92,    93,    94,    95,    96,    97,    98,    99,   100,   101,
     102,    -1,   104,    -1,    -1,    -1,    34,    -1,    -1,    37,
      -1,    -1,    -1,    -1,   116,    -1,   118,   119,   120,   121,
      -1,    -1,   124,   125,   126,   127,   128,   129,   130,   131,
     132,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    67,
      68,    69,    70,    71,    72,    73,    74,    75,    76,    77,
      78,    79,    80,    81,    82,    83,    84,    85,    12,    87,
      88,    89,    90,    91,    92,    93,    94,    95,    96,    97,
      98,    99,   100,   101,   102,    -1,   104,    -1,    -1,    -1,
      34,    -1,    -1,    37,    -1,    -1,    -1,    -1,   116,    -1,
     118,   119,   120,   121,    -1,    -1,   124,   125,   126,   127,
     128,   129,   130,   131,   132,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    67,    68,    69,    70,    71,    72,    73,
      74,    75,    76,    77,    78,    79,    80,    81,    82,    83,
      84,    85,    12,    87,    88,    89,    90,    91,    92,    93,
      94,    95,    96,    97,    98,    99,   100,   101,   102,    -1,
     104,    -1,    -1,    -1,    34,    -1,    -1,    37,    -1,    -1,
      -1,    -1,   116,    -1,   118,   119,   120,   121,    -1,    -1,
     124,   125,   126,   127,   128,   129,   130,   131,   132,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    67,    68,    69,
      70,    71,    72,    73,    74,    75,    76,    77,    78,    79,
      80,    81,    82,    83,    84,    85,    12,    87,    88,    89,
      90,    91,    92,    93,    94,    95,    96,    97,    98,    99,
     100,   101,   102,    -1,   104,    -1,    -1,    -1,    -1,    -1,
      -1,    37,    -1,    -1,    -1,    -1,   116,    -1,   118,   119,
     120,   121,    -1,    -1,   124,   125,   126,   127,   128,   129,
     130,   131,   132,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    67,    68,    69,    70,    71,    72,    73,    74,    75,
      76,    77,    78,    79,    80,    81,    82,    83,    84,    85,
      12,    87,    88,    89,    90,    91,    92,    93,    94,    95,
      96,    97,    98,    99,   100,   101,   102,    -1,   104,    -1,
      -1,    -1,    -1,    -1,    -1,    37,    -1,    -1,    -1,    -1,
     116,    -1,   118,   119,   120,   121,    -1,    -1,   124,   125,
     126,   127,   128,   129,   130,   131,   132,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    67,    68,    69,    70,    71,
      72,    73,    74,    75,    76,    77,    78,    79,    80,    81,
      82,    83,    84,    85,    12,    87,    88,    89,    90,    91,
      92,    93,    94,    95,    96,    97,    98,    99,   100,   101,
     102,    -1,   104,    -1,    -1,    -1,    -1,    -1,    -1,    37,
      -1,    -1,    -1,    -1,   116,    -1,   118,   119,   120,   121,
      -1,   123,   124,   125,   126,   127,   128,    -1,   130,   131,
     132,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    67,
      68,    69,    70,    71,    72,    73,    74,    75,    76,    77,
      78,    79,    80,    81,    82,    83,    84,    85,    -1,    87,
      88,    89,    90,    91,    92,    93,    94,    95,    96,    97,
      98,    99,   100,   101,   102,    -1,   104,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    12,   116,    -1,
     118,   119,   120,   121,    -1,    -1,   124,   125,   126,   127,
     128,   129,   130,   131,   132,    30,    -1,    -1,    -1,    -1,
      -1,    -1,    37,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    67,    68,    69,    70,    71,    72,    73,    74,
      75,    76,    77,    78,    79,    80,    81,    82,    83,    84,
      85,    -1,    87,    88,    89,    90,    91,    92,    93,    94,
      95,    96,    97,    98,    99,   100,   101,   102,    -1,   104,
      -1,    -1,    -1,    -1,    -1,    -1,    12,    -1,    -1,    -1,
      -1,   116,    -1,   118,   119,   120,   121,    -1,    -1,   124,
     125,   126,   127,   128,    30,   130,   131,   132,    -1,    -1,
      -1,    37,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    67,    68,    69,    70,    71,    72,    73,    74,    75,
      76,    77,    78,    79,    80,    81,    82,    83,    84,    85,
      12,    87,    88,    89,    90,    91,    92,    93,    94,    95,
      96,    97,    98,    99,   100,   101,   102,    -1,   104,    -1,
      -1,    -1,    -1,    -1,    -1,    37,    -1,    -1,    -1,    -1,
     116,    -1,   118,   119,   120,   121,    -1,    -1,   124,   125,
     126,   127,   128,    -1,   130,   131,   132,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    66,    67,    68,    69,    70,    71,
      72,    73,    74,    75,    76,    77,    78,    79,    80,    81,
      82,    83,    84,    85,    12,    87,    88,    89,    90,    91,
      92,    93,    94,    95,    96,    97,    98,    99,   100,   101,
     102,    -1,   104,    -1,    -1,    -1,    -1,    -1,    -1,    37,
      -1,    -1,    -1,    -1,   116,    -1,   118,   119,   120,   121,
      -1,    -1,   124,   125,   126,   127,   128,    -1,   130,   131,
     132,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    67,
      68,    69,    70,    71,    72,    73,    74,    75,    76,    77,
      78,    79,    80,    81,    82,    83,    84,    85,    -1,    87,
      88,    89,    90,    91,    92,    93,    94,    95,    96,    97,
      98,    99,   100,   101,   102,    -1,   104,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,   116,    -1,
     118,   119,   120,   121,    -1,    -1,   124,   125,   126,   127,
     128,    -1,   130,   131,   132,    12,    13,    -1,    -1,    16,
      -1,    -1,    19,    -1,    -1,    -1,    -1,    -1,    25,    -1,
      -1,    -1,    29,    -1,    31,    32,    33,    -1,    -1,    -1,
      -1,    -1,    39,    40,    41,    42,    43,    12,    13,    -1,
      -1,    16,    -1,    -1,    19,    -1,    -1,    54,    55,    -1,
      25,    -1,    59,    -1,    29,    -1,    31,    32,    33,    -1,
      -1,    -1,    -1,    -1,    39,    40,    41,    42,    43,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    54,
      55,    -1,    -1,    -1,    59,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    12,    13,    -1,    -1,    16,
     107,   108,    19,    -1,    -1,    -1,    -1,   114,    25,    -1,
      -1,    -1,    29,    -1,    31,    32,    33,    -1,    -1,    -1,
      -1,    -1,    39,    40,    41,    42,    43,    12,    13,    -1,
      -1,    16,   107,   108,    19,    -1,    -1,    54,    55,   114,
      25,    -1,    59,    -1,    29,    -1,    31,    -1,    33,    -1,
      -1,    -1,    12,    -1,    39,    40,    41,    42,    43,    19,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    54,
      55,    -1,    -1,    33,    59,    -1,    -1,    -1,    -1,    -1,
      40,    41,    42,    43,    -1,    -1,    -1,    -1,    -1,    -1,
     107,   108,    -1,    -1,    54,    -1,    -1,   114,    -1,    59,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,   107,   108,    -1,    -1,    -1,    -1,    -1,   114,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,   107,   108,    -1,
      -1,    -1,    -1,    -1,   114
};

/* YYSTOS[STATE-NUM] -- The symbol kind of the accessing symbol of
   state STATE-NUM.  */
static const yytype_int16 yystos[] =
{
       0,   138,   140,     0,    57,   115,   139,   141,   145,   146,
      12,    19,    25,    43,   176,   177,   179,   284,    33,   180,
     181,   284,   290,    12,    37,    48,    50,    56,    62,    67,
      68,    69,    70,    71,    72,    73,    74,    75,    76,    77,
      78,    79,    80,    81,    82,    83,    84,    85,    87,    88,
      89,    90,    91,    92,    93,    94,    95,    96,    97,    98,
      99,   100,   101,   102,   104,   109,   113,   116,   117,   118,
     119,   120,   121,   122,   124,   125,   126,   127,   128,   130,
     131,   132,   133,   134,   135,   136,   142,   147,   148,   152,
     155,   156,   157,   158,   159,   162,   164,   173,   224,   225,
     226,   227,   228,   231,   239,   179,    27,    36,   182,   290,
      27,    36,    33,    97,   228,   229,   231,   239,    19,   284,
     285,   288,   228,   171,   165,   167,    62,   153,   228,   228,
     234,   284,   287,    19,   286,   234,   287,   234,   287,   228,
     143,   143,   228,   224,   228,    12,    33,    39,   190,   191,
     241,   242,   243,   286,    36,    36,    25,   177,    27,    34,
     181,    14,    15,    16,    20,    21,    25,    29,    31,    38,
      39,    55,    66,   183,   184,   185,   186,   228,   246,   250,
     251,   253,   265,    39,   230,    26,   288,    33,   190,   241,
     112,   112,    97,   169,   154,   155,   156,   157,   159,   174,
     190,    29,    33,   232,   233,   190,   144,   146,   147,   152,
     241,   242,   243,   242,   243,    27,    36,    28,   192,    31,
      33,   249,    33,   249,   290,    33,   284,   284,    15,    20,
      31,   251,   253,    21,   254,   255,    21,   228,    34,    27,
      27,    33,    39,   247,   248,   249,    53,   254,    21,    39,
     229,    36,   129,   207,   208,   209,   228,   245,    36,    12,
      12,   112,   112,   220,   221,   241,    36,    19,   240,   123,
     149,   150,   151,   245,    29,    29,    36,   192,    34,    34,
     191,    13,    19,    31,    33,    40,    41,    42,    43,    54,
      55,    59,   107,   108,   114,   188,   189,   251,   261,   262,
     263,   264,   265,   266,   269,   270,   271,   272,   274,   277,
     278,   279,   280,   284,   286,   291,    64,    65,   160,   193,
     228,    32,   189,    34,   208,    34,   208,   183,   284,   284,
     254,   254,    21,    32,    18,    27,   256,   111,   247,   185,
     246,   186,   246,   208,   248,   248,    33,   249,   187,   224,
     250,   291,    17,    30,   252,    37,    34,    27,    12,    33,
      39,   242,   244,   247,   172,   166,    12,    12,    27,   175,
     222,    27,   238,   245,    34,    27,   228,   235,   236,   235,
     161,   281,    32,   261,   273,   262,    33,   262,    33,    33,
      33,   252,   273,    14,    28,    38,   266,   269,   265,   267,
     268,   274,   274,    26,    15,    20,    22,    23,    24,    26,
      31,    35,   270,   276,    33,   280,    33,    36,    36,    29,
     190,    32,    34,    34,    34,    32,   252,    21,    21,    21,
      34,    34,    34,   208,    26,   257,    21,   192,   129,   245,
      39,   244,    33,   249,    29,    36,   215,   215,   168,   170,
     221,    36,    29,   223,    19,    30,    36,   151,   237,   241,
      30,   236,    30,    29,   282,   283,   286,    26,    32,   256,
      34,   262,   275,   111,   261,    12,   228,   261,    44,    64,
      65,    66,   203,   204,   229,   261,   252,   262,   264,   264,
     269,   265,   265,   284,   289,   284,   284,   289,    32,   275,
     274,   260,   261,   275,   194,    36,    21,    21,    51,    34,
     258,   259,   289,   163,    34,   208,    30,   178,   179,   216,
     215,   215,    58,   217,   218,    27,    36,   194,    27,    26,
     289,    26,   261,    27,    34,   262,    27,    34,    34,    34,
     229,    27,    34,   269,    32,    34,    34,    60,   105,   195,
     196,    21,    20,    27,    29,    34,    36,    27,    30,    30,
     159,   228,   219,    30,   241,   196,   283,    66,   199,   228,
     289,   262,    51,   261,   204,   197,   198,   286,   228,    49,
     200,   289,   289,   196,   179,    36,   241,   280,   200,   199,
     262,    34,    27,    36,    26,    46,   190,   260,   106,   201,
     201,    33,   201,   198,   199,   261,    36,    36,   260,    61,
     202,    47,   210,   260,   202,    46,    36,    45,    63,   203,
      52,   205,    29,   205,    34,   205,   261,    36,    36,    36,
     260,    48,   206,    19,    33,   211,   212,   285,   286,    30,
     206,    36,   260,    30,   211,    30,    36,    37,    39,    33,
      28,    30,    36,    34,    36,    30,   211,   211,    25,    33,
      34,   213,   214,   278,   285,   286,    19,   285,   214,   214,
      27,    34,    25,    33,    33,    34,   214,   214,    34,   213,
      34,   213,    34,    34
};

/* YYR1[RULE-NUM] -- Symbol kind of the left-hand side of rule RULE-NUM.  */
static const yytype_int16 yyr1[] =
{
       0,   137,   139,   138,   140,   140,   141,   141,   142,   142,
     142,   143,   143,   144,   144,   144,   145,   146,   147,   147,
     147,   147,   147,   147,   148,   149,   149,   150,   150,   151,
     151,   153,   152,   154,   154,   154,   154,   155,   156,   156,
     156,   157,   157,   158,   158,   158,   160,   159,   161,   159,
     163,   162,   162,   165,   166,   164,   167,   168,   164,   169,
     170,   164,   171,   172,   164,   174,   175,   173,   173,   173,
     176,   176,   177,   177,   177,   178,   178,   179,   180,   180,
     181,   181,   181,   181,   182,   182,   183,   183,   183,   184,
     184,   185,   185,   186,   186,   186,   187,   187,   188,   189,
     190,   190,   191,   191,   192,   192,   193,   193,   193,   194,
     194,   195,   196,   196,   197,   197,   198,   198,   199,   200,
     200,   201,   201,   202,   202,   202,   202,   203,   203,   204,
     204,   204,   204,   204,   205,   205,   206,   206,   207,   207,
     208,   208,   208,   209,   209,   210,   210,   210,   211,   211,
     211,   211,   211,   212,   212,   212,   212,   213,   213,   214,
     214,   214,   214,   214,   214,   214,   214,   215,   215,   215,
     215,   216,   216,   217,   217,   219,   218,   220,   220,   222,
     221,   223,   223,   224,   224,   224,   224,   224,   224,   224,
     224,   224,   224,   225,   225,   226,   226,   227,   227,   227,
     227,   227,   227,   227,   227,   227,   227,   227,   227,   227,
     227,   227,   227,   227,   227,   227,   227,   227,   227,   227,
     227,   227,   227,   227,   227,   227,   227,   227,   227,   227,
     227,   227,   227,   228,   228,   228,   228,   228,   229,   229,
     230,   230,   232,   231,   233,   231,   231,   231,   234,   234,
     235,   235,   236,   237,   237,   238,   238,   239,   239,   240,
     240,   241,   241,   242,   242,   242,   242,   242,   242,   243,
     243,   243,   243,   243,   243,   244,   244,   244,   244,   244,
     245,   245,   245,   246,   246,   246,   247,   247,   248,   248,
     248,   248,   248,   248,   248,   248,   249,   249,   250,   250,
     250,   250,   250,   250,   250,   250,   250,   250,   250,   250,
     250,   250,   250,   250,   250,   251,   251,   252,   252,   253,
     253,   253,   254,   254,   255,   255,   256,   256,   257,   258,
     258,   259,   259,   260,   261,   262,   262,   262,   263,   263,
     263,   263,   264,   264,   264,   265,   265,   266,   266,   267,
     267,   268,   268,   269,   269,   269,   269,   269,   269,   269,
     270,   270,   271,   271,   271,   271,   272,   272,   273,   273,
     274,   274,   274,   274,   274,   274,   274,   274,   274,   274,
     275,   275,   276,   276,   276,   276,   277,   277,   277,   277,
     277,   277,   277,   277,   278,   278,   278,   278,   279,   279,
     281,   280,   282,   282,   283,   283,   284,   284,   285,   286,
     287,   288,   289,   290,   291
};

/* YYR2[RULE-NUM] -- Number of symbols on the right-hand side of rule RULE-NUM.  */
static const yytype_int8 yyr2[] =
{
       0,     2,     0,     3,     0,     2,     1,     1,     0,     2,
       2,     0,     2,     1,     1,     1,     3,     3,     1,     1,
       1,     1,     1,     1,     6,     0,     1,     1,     3,     2,
       1,     0,     3,     1,     1,     1,     1,     4,     3,     4,
       4,     1,     1,     1,     1,     1,     0,    13,     0,    14,
       0,    13,     4,     0,     0,     6,     0,     0,     7,     0,
       0,     7,     0,     0,     6,     0,     0,     6,     2,     2,
       1,     3,     1,     3,     1,     1,     3,     1,     1,     3,
       1,     4,     3,     6,     1,     3,     1,     1,     3,     1,
       3,     1,     3,     3,     3,     4,     1,     1,     1,     1,
       1,     3,     1,     3,     0,     2,     3,     2,     2,     0,
       2,     4,     0,     3,     1,     3,     5,     3,     1,     0,
       3,     0,     3,     0,     3,     3,     3,     1,     3,     1,
       1,     2,     1,     1,     0,     3,     0,     3,     0,     1,
       1,     1,     3,     1,     3,     0,     4,     5,     1,     3,
       2,     3,     3,     4,     3,     5,     6,     1,     3,     1,
       1,     2,     2,     3,     3,     3,     4,     1,     3,     4,
       3,     0,     2,     0,     1,     0,     6,     1,     3,     0,
       3,     0,     3,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     2,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     2,     5,     1,     2,
       1,     2,     0,     6,     0,     6,     2,     2,     0,     1,
       1,     2,     3,     1,     3,     0,     1,     6,     2,     1,
       3,     1,     1,     1,     3,     2,     2,     3,     4,     1,
       3,     2,     2,     3,     4,     1,     2,     2,     3,     4,
       2,     2,     2,     2,     3,     1,     0,     1,     3,     2,
       1,     1,     2,     3,     3,     4,     2,     3,     6,     1,
       2,     2,     3,     3,     4,     4,     5,     3,     4,     4,
       5,     2,     2,     3,     3,     1,     1,     1,     1,     1,
       1,     1,     0,     1,     1,     3,     1,     1,     4,     0,
       1,     1,     3,     1,     1,     6,     1,     3,     1,     4,
       3,     3,     1,     2,     2,     1,     1,     1,     2,     1,
       2,     2,     3,     1,     1,     2,     2,     3,     1,     2,
       3,     1,     5,     3,     4,     2,     3,     2,     1,     3,
       3,     1,     4,     1,     2,     3,     3,     3,     4,     3,
       1,     3,     1,     1,     1,     1,     1,     1,     4,     4,
       4,     4,     6,     4,     1,     1,     1,     1,     1,     2,
       0,     3,     1,     3,     3,     4,     1,     1,     1,     1,
       1,     1,     1,     1,     1
};


enum { YYENOMEM = -2 };

#define yyerrok         (yyerrstatus = 0)
#define yyclearin       (yychar = YLEMPTY)

#define YYACCEPT        goto yyacceptlab
#define YYABORT         goto yyabortlab
#define YYERROR         goto yyerrorlab
#define YYNOMEM         goto yyexhaustedlab


#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)                                    \
  do                                                              \
    if (yychar == YLEMPTY)                                        \
      {                                                           \
        yychar = (Token);                                         \
        yylval = (Value);                                         \
        YYPOPSTACK (yylen);                                       \
        yystate = *yyssp;                                         \
        goto yybackup;                                            \
      }                                                           \
    else                                                          \
      {                                                           \
        yyerror (YY_("syntax error: cannot back up")); \
        YYERROR;                                                  \
      }                                                           \
  while (0)

/* Backward compatibility with an undocumented macro.
   Use YLerror or YLUNDEF. */
#define YYERRCODE YLUNDEF


/* Enable debugging if requested.  */
#if YLDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)                        \
do {                                            \
  if (yydebug)                                  \
    YYFPRINTF Args;                             \
} while (0)




# define YY_SYMBOL_PRINT(Title, Kind, Value, Location)                    \
do {                                                                      \
  if (yydebug)                                                            \
    {                                                                     \
      YYFPRINTF (stderr, "%s ", Title);                                   \
      yy_symbol_print (stderr,                                            \
                  Kind, Value); \
      YYFPRINTF (stderr, "\n");                                           \
    }                                                                     \
} while (0)


/*-----------------------------------.
| Print this symbol's value on YYO.  |
`-----------------------------------*/

static void
yy_symbol_value_print (FILE *yyo,
                       yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep)
{
  FILE *yyoutput = yyo;
  YY_USE (yyoutput);
  if (!yyvaluep)
    return;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YY_USE (yykind);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}


/*---------------------------.
| Print this symbol on YYO.  |
`---------------------------*/

static void
yy_symbol_print (FILE *yyo,
                 yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep)
{
  YYFPRINTF (yyo, "%s %s (",
             yykind < YYNTOKENS ? "token" : "nterm", yysymbol_name (yykind));

  yy_symbol_value_print (yyo, yykind, yyvaluep);
  YYFPRINTF (yyo, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

static void
yy_stack_print (yy_state_t *yybottom, yy_state_t *yytop)
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)                            \
do {                                                            \
  if (yydebug)                                                  \
    yy_stack_print ((Bottom), (Top));                           \
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

static void
yy_reduce_print (yy_state_t *yyssp, YYSTYPE *yyvsp,
                 int yyrule)
{
  int yylno = yyrline[yyrule];
  int yynrhs = yyr2[yyrule];
  int yyi;
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %d):\n",
             yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr,
                       YY_ACCESSING_SYMBOL (+yyssp[yyi + 1 - yynrhs]),
                       &yyvsp[(yyi + 1) - (yynrhs)]);
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)          \
do {                                    \
  if (yydebug)                          \
    yy_reduce_print (yyssp, yyvsp, Rule); \
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YLDEBUG */
# define YYDPRINTF(Args) ((void) 0)
# define YY_SYMBOL_PRINT(Title, Kind, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YLDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif






/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

static void
yydestruct (const char *yymsg,
            yysymbol_kind_t yykind, YYSTYPE *yyvaluep)
{
  YY_USE (yyvaluep);
  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yykind, yyvaluep, yylocationp);

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YY_USE (yykind);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}


/* Lookahead token kind.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;
/* Number of syntax errors so far.  */
int yynerrs;




/*----------.
| yyparse.  |
`----------*/

int
yyparse (void)
{
    yy_state_fast_t yystate = 0;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus = 0;

    /* Refer to the stacks through separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* Their size.  */
    YYPTRDIFF_T yystacksize = YYINITDEPTH;

    /* The state stack: array, bottom, top.  */
    yy_state_t yyssa[YYINITDEPTH];
    yy_state_t *yyss = yyssa;
    yy_state_t *yyssp = yyss;

    /* The semantic value stack: array, bottom, top.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs = yyvsa;
    YYSTYPE *yyvsp = yyvs;

  int yyn;
  /* The return value of yyparse.  */
  int yyresult;
  /* Lookahead symbol kind.  */
  yysymbol_kind_t yytoken = YYSYMBOL_YYEMPTY;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;



#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yychar = YLEMPTY; /* Cause a token to be read.  */

  goto yysetstate;


/*------------------------------------------------------------.
| yynewstate -- push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;


/*--------------------------------------------------------------------.
| yysetstate -- set current state (the top of the stack) to yystate.  |
`--------------------------------------------------------------------*/
yysetstate:
  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
  YY_ASSERT (0 <= yystate && yystate < YYNSTATES);
  YY_IGNORE_USELESS_CAST_BEGIN
  *yyssp = YY_CAST (yy_state_t, yystate);
  YY_IGNORE_USELESS_CAST_END
  YY_STACK_PRINT (yyss, yyssp);

  if (yyss + yystacksize - 1 <= yyssp)
#if !defined yyoverflow && !defined YYSTACK_RELOCATE
    YYNOMEM;
#else
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYPTRDIFF_T yysize = yyssp - yyss + 1;

# if defined yyoverflow
      {
        /* Give user a chance to reallocate the stack.  Use copies of
           these so that the &'s don't force the real ones into
           memory.  */
        yy_state_t *yyss1 = yyss;
        YYSTYPE *yyvs1 = yyvs;

        /* Each stack pointer address is followed by the size of the
           data in use in that stack, in bytes.  This used to be a
           conditional around just the two extra args, but that might
           be undefined if yyoverflow is a macro.  */
        yyoverflow (YY_("memory exhausted"),
                    &yyss1, yysize * YYSIZEOF (*yyssp),
                    &yyvs1, yysize * YYSIZEOF (*yyvsp),
                    &yystacksize);
        yyss = yyss1;
        yyvs = yyvs1;
      }
# else /* defined YYSTACK_RELOCATE */
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
        YYNOMEM;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
        yystacksize = YYMAXDEPTH;

      {
        yy_state_t *yyss1 = yyss;
        union yyalloc *yyptr =
          YY_CAST (union yyalloc *,
                   YYSTACK_ALLOC (YY_CAST (YYSIZE_T, YYSTACK_BYTES (yystacksize))));
        if (! yyptr)
          YYNOMEM;
        YYSTACK_RELOCATE (yyss_alloc, yyss);
        YYSTACK_RELOCATE (yyvs_alloc, yyvs);
#  undef YYSTACK_RELOCATE
        if (yyss1 != yyssa)
          YYSTACK_FREE (yyss1);
      }
# endif

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;

      YY_IGNORE_USELESS_CAST_BEGIN
      YYDPRINTF ((stderr, "Stack size increased to %ld\n",
                  YY_CAST (long, yystacksize)));
      YY_IGNORE_USELESS_CAST_END

      if (yyss + yystacksize - 1 <= yyssp)
        YYABORT;
    }
#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */


  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;


/*-----------.
| yybackup.  |
`-----------*/
yybackup:
  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yypact_value_is_default (yyn))
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either empty, or end-of-input, or a valid lookahead.  */
  if (yychar == YLEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token\n"));
      yychar = yylex ();
    }

  if (yychar <= YLEOF)
    {
      yychar = YLEOF;
      yytoken = YYSYMBOL_YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else if (yychar == YLerror)
    {
      /* The scanner already issued an error message, process directly
         to error recovery.  But do not keep the error token as
         lookahead, it is too special and may lead us to an endless
         loop in error recovery. */
      yychar = YLUNDEF;
      yytoken = YYSYMBOL_YYerror;
      goto yyerrlab1;
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yytable_value_is_error (yyn))
        goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
  yystate = yyn;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END

  /* Discard the shifted token.  */
  yychar = YLEMPTY;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     '$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
  case 2: /* $@1: %empty  */
#line 382 "llgrammar.y"
             { lhExternals ((yyvsp[0].interfacelist)); }
#line 2798 "llgrammar.c"
    break;

  case 3: /* interface: externals $@1 optDeclarations  */
#line 383 "llgrammar.y"
   { interfaceNodeList_free ((yyvsp[-2].interfacelist)); interfaceNodeList_free ((yyvsp[0].interfacelist)); }
#line 2804 "llgrammar.c"
    break;

  case 4: /* externals: %empty  */
#line 387 "llgrammar.y"
                      { (yyval.interfacelist) = interfaceNodeList_new (); }
#line 2810 "llgrammar.c"
    break;

  case 5: /* externals: externals external  */
#line 388 "llgrammar.y"
                      { (yyval.interfacelist) = interfaceNodeList_addh ((yyvsp[-1].interfacelist), (yyvsp[0].iface));}
#line 2816 "llgrammar.c"
    break;

  case 8: /* optDeclarations: %empty  */
#line 397 "llgrammar.y"
                            { (yyval.interfacelist) = interfaceNodeList_new (); }
#line 2822 "llgrammar.c"
    break;

  case 9: /* optDeclarations: export declarations  */
#line 398 "llgrammar.y"
                            { (yyval.interfacelist) = consInterfaceNode ((yyvsp[-1].iface), (yyvsp[0].interfacelist));}
#line 2828 "llgrammar.c"
    break;

  case 10: /* optDeclarations: private declarations  */
#line 399 "llgrammar.y"
                            { (yyval.interfacelist) = consInterfaceNode ((yyvsp[-1].iface), (yyvsp[0].interfacelist));}
#line 2834 "llgrammar.c"
    break;

  case 11: /* declarations: %empty  */
#line 403 "llgrammar.y"
                            { (yyval.interfacelist) = interfaceNodeList_new (); }
#line 2840 "llgrammar.c"
    break;

  case 12: /* declarations: declarations declaration  */
#line 404 "llgrammar.y"
                            { (yyval.interfacelist) = interfaceNodeList_addh ((yyvsp[-1].interfacelist), (yyvsp[0].iface));}
#line 2846 "llgrammar.c"
    break;

  case 16: /* imports: LLT_IMPORTS importNameList LLT_SEMI  */
#line 415 "llgrammar.y"
   { (yyval.iface) = makeInterfaceNodeImports ((yyvsp[-1].importlist));
     /* assume subspecs are already processed, symbol table info in external file */
   }
#line 2854 "llgrammar.c"
    break;

  case 17: /* uses: LLT_USES traitRefNodeList LLT_SEMI  */
#line 422 "llgrammar.y"
   { (yyval.iface) = makeInterfaceNodeUses ((yyvsp[-1].traitreflist)); readlsignatures ((yyval.iface));}
#line 2860 "llgrammar.c"
    break;

  case 18: /* export: constDeclaration  */
#line 427 "llgrammar.y"
   { declareConstant ((yyvsp[0].constdeclaration)); (yyval.iface) = interfaceNode_makeConst ((yyvsp[0].constdeclaration)); }
#line 2866 "llgrammar.c"
    break;

  case 19: /* export: varDeclaration  */
#line 429 "llgrammar.y"
   { declareVar ((yyvsp[0].vardeclaration)); (yyval.iface) = interfaceNode_makeVar ((yyvsp[0].vardeclaration)); }
#line 2872 "llgrammar.c"
    break;

  case 20: /* export: type  */
#line 431 "llgrammar.y"
   { declareType ((yyvsp[0].type)); (yyval.iface) = interfaceNode_makeType ((yyvsp[0].type)); }
#line 2878 "llgrammar.c"
    break;

  case 21: /* export: fcn  */
#line 433 "llgrammar.y"
   { declareFcn ((yyvsp[0].fcn), typeId_invalid); (yyval.iface) = interfaceNode_makeFcn ((yyvsp[0].fcn)); }
#line 2884 "llgrammar.c"
    break;

  case 22: /* export: claim  */
#line 435 "llgrammar.y"
   { (yyval.iface) = interfaceNode_makeClaim ((yyvsp[0].claim)); }
#line 2890 "llgrammar.c"
    break;

  case 23: /* export: iter  */
#line 437 "llgrammar.y"
   { declareIter ((yyvsp[0].iter)); (yyval.iface) = interfaceNode_makeIter ((yyvsp[0].iter)); }
#line 2896 "llgrammar.c"
    break;

  case 24: /* iter: LLT_ITER varId LLT_LPAR iterParamList LLT_RPAR LLT_SEMI  */
#line 442 "llgrammar.y"
   { (yyval.iter) = makeIterNode ((yyvsp[-4].ltok), (yyvsp[-2].paramlist)); }
#line 2902 "llgrammar.c"
    break;

  case 25: /* iterParamList: %empty  */
#line 446 "llgrammar.y"
                       { (yyval.paramlist) = paramNodeList_new (); }
#line 2908 "llgrammar.c"
    break;

  case 26: /* iterParamList: realIterParamList  */
#line 447 "llgrammar.y"
                       { (yyval.paramlist) = (yyvsp[0].paramlist); }
#line 2914 "llgrammar.c"
    break;

  case 27: /* realIterParamList: iterParam  */
#line 452 "llgrammar.y"
   { (yyval.paramlist) = paramNodeList_add (paramNodeList_new (),  (yyvsp[0].param)); }
#line 2920 "llgrammar.c"
    break;

  case 28: /* realIterParamList: realIterParamList LLT_COMMA iterParam  */
#line 454 "llgrammar.y"
   { (yyval.paramlist) = paramNodeList_add ((yyvsp[-2].paramlist),(yyvsp[0].param)); }
#line 2926 "llgrammar.c"
    break;

  case 29: /* iterParam: LLT_YIELD param  */
#line 458 "llgrammar.y"
                              { (yyval.param) = markYieldParamNode ((yyvsp[0].param)); }
#line 2932 "llgrammar.c"
    break;

  case 30: /* iterParam: param  */
#line 459 "llgrammar.y"
                          { (yyval.param) = (yyvsp[0].param); }
#line 2938 "llgrammar.c"
    break;

  case 31: /* $@2: %empty  */
#line 463 "llgrammar.y"
            { symtable_export (g_symtab, FALSE); }
#line 2944 "llgrammar.c"
    break;

  case 32: /* private: LLT_SPEC $@2 private2  */
#line 464 "llgrammar.y"
   { (yyval.iface) = (yyvsp[0].iface); symtable_export (g_symtab, TRUE); }
#line 2950 "llgrammar.c"
    break;

  case 33: /* private2: constDeclaration  */
#line 469 "llgrammar.y"
   { declarePrivConstant ((yyvsp[0].constdeclaration)); (yyval.iface) =  interfaceNode_makePrivConst ((yyvsp[0].constdeclaration)); }
#line 2956 "llgrammar.c"
    break;

  case 34: /* private2: varDeclaration  */
#line 471 "llgrammar.y"
   { declarePrivVar ((yyvsp[0].vardeclaration)); (yyval.iface) = interfaceNode_makePrivVar ((yyvsp[0].vardeclaration)); }
#line 2962 "llgrammar.c"
    break;

  case 35: /* private2: type  */
#line 473 "llgrammar.y"
   { declarePrivType ((yyvsp[0].type)); (yyval.iface) = interfaceNode_makePrivType ((yyvsp[0].type)); }
#line 2968 "llgrammar.c"
    break;

  case 36: /* private2: fcn  */
#line 475 "llgrammar.y"
   { declarePrivFcn ((yyvsp[0].fcn), typeId_invalid); (yyval.iface) = interfaceNode_makePrivFcn ((yyvsp[0].fcn)); }
#line 2974 "llgrammar.c"
    break;

  case 37: /* constDeclaration: LLT_CONSTANT lclTypeSpec initDecls LLT_SEMI  */
#line 480 "llgrammar.y"
   { (yyval.constdeclaration) = makeConstDeclarationNode ((yyvsp[-2].lcltypespec), (yyvsp[-1].initdecls)); }
#line 2980 "llgrammar.c"
    break;

  case 38: /* varDeclaration: lclTypeSpec initDecls LLT_SEMI  */
#line 485 "llgrammar.y"
   { (yyval.vardeclaration) = makeVarDeclarationNode ((yyvsp[-2].lcltypespec), (yyvsp[-1].initdecls), FALSE, FALSE); (yyval.vardeclaration)->qualifier = QLF_NONE; }
#line 2986 "llgrammar.c"
    break;

  case 39: /* varDeclaration: LLT_CONST lclTypeSpec initDecls LLT_SEMI  */
#line 487 "llgrammar.y"
   { (yyval.vardeclaration) = makeVarDeclarationNode ((yyvsp[-2].lcltypespec), (yyvsp[-1].initdecls), FALSE, FALSE); (yyval.vardeclaration)->qualifier = QLF_CONST; }
#line 2992 "llgrammar.c"
    break;

  case 40: /* varDeclaration: LLT_VOLATILE lclTypeSpec initDecls LLT_SEMI  */
#line 489 "llgrammar.y"
   { (yyval.vardeclaration) = makeVarDeclarationNode ((yyvsp[-2].lcltypespec), (yyvsp[-1].initdecls), FALSE, FALSE); (yyval.vardeclaration)->qualifier = QLF_VOLATILE; }
#line 2998 "llgrammar.c"
    break;

  case 41: /* type: abstract  */
#line 493 "llgrammar.y"
                                { (yyval.type) = makeAbstractTypeNode ((yyvsp[0].abstract)); }
#line 3004 "llgrammar.c"
    break;

  case 42: /* type: exposed  */
#line 494 "llgrammar.y"
                                { (yyval.type) = makeExposedTypeNode ((yyvsp[0].exposed)); }
#line 3010 "llgrammar.c"
    break;

  case 43: /* special: LLT_PRINTFLIKE  */
#line 498 "llgrammar.y"
                   { (yyval.typequal) = qual_createPrintfLike (); }
#line 3016 "llgrammar.c"
    break;

  case 44: /* special: LLT_SCANFLIKE  */
#line 499 "llgrammar.y"
                   { (yyval.typequal) = qual_createScanfLike (); }
#line 3022 "llgrammar.c"
    break;

  case 45: /* special: LLT_MESSAGELIKE  */
#line 500 "llgrammar.y"
                   { (yyval.typequal) = qual_createMessageLike (); }
#line 3028 "llgrammar.c"
    break;

  case 46: /* $@3: %empty  */
#line 504 "llgrammar.y"
                                  { enteringFcnScope ((yyvsp[-2].lcltypespec), (yyvsp[-1].declare), (yyvsp[0].globals)); }
#line 3034 "llgrammar.c"
    break;

  case 47: /* fcn: lclTypeSpec declarator globals $@3 LLT_LBRACE privateInits optLetDecl optChecks optRequire optModify optEnsure optClaim LLT_RBRACE  */
#line 506 "llgrammar.y"
   { (yyval.fcn) = makeFcnNode (qual_createUnknown (),  (yyvsp[-12].lcltypespec), (yyvsp[-11].declare), (yyvsp[-10].globals), (yyvsp[-7].vardeclarationlist), (yyvsp[-6].letdecls), 
		       (yyvsp[-5].lclpredicate), (yyvsp[-4].lclpredicate), (yyvsp[-3].modify), (yyvsp[-2].lclpredicate), (yyvsp[-1].lclpredicate)); 
     /* type, declarator, glovbls, privateinits,
	lets, checks, requires, modifies, ensures, claims */
     symtable_exitScope (g_symtab);
   }
#line 3045 "llgrammar.c"
    break;

  case 48: /* $@4: %empty  */
#line 512 "llgrammar.y"
                                          { enteringFcnScope ((yyvsp[-2].lcltypespec), (yyvsp[-1].declare), (yyvsp[0].globals)); }
#line 3051 "llgrammar.c"
    break;

  case 49: /* fcn: special lclTypeSpec declarator globals $@4 LLT_LBRACE privateInits optLetDecl optChecks optRequire optModify optEnsure optClaim LLT_RBRACE  */
#line 516 "llgrammar.y"
   { (yyval.fcn) = makeFcnNode ((yyvsp[-13].typequal), (yyvsp[-12].lcltypespec), (yyvsp[-11].declare), (yyvsp[-10].globals), (yyvsp[-7].vardeclarationlist), 
		       (yyvsp[-6].letdecls), (yyvsp[-5].lclpredicate), (yyvsp[-4].lclpredicate), (yyvsp[-3].modify), (yyvsp[-2].lclpredicate), (yyvsp[-1].lclpredicate)); 
     /* type, declarator, glovbls, privateinits,
	lets, checks, requires, modifies, ensures, claims */
     symtable_exitScope (g_symtab);
   }
#line 3062 "llgrammar.c"
    break;

  case 50: /* $@5: %empty  */
#line 526 "llgrammar.y"
   { enteringClaimScope ((yyvsp[-2].paramlist), (yyvsp[0].globals)); }
#line 3068 "llgrammar.c"
    break;

  case 51: /* claim: LLT_CLAIMS claimId LLT_LPAR optParamList LLT_RPAR globals $@5 LLT_LBRACE optLetDecl optRequire optBody optEnsure LLT_RBRACE  */
#line 528 "llgrammar.y"
   {      (yyval.claim) = makeClaimNode ((yyvsp[-11].ltok), (yyvsp[-9].paramlist), (yyvsp[-7].globals), (yyvsp[-4].letdecls), (yyvsp[-3].lclpredicate), (yyvsp[-2].program), (yyvsp[-1].lclpredicate)); 
     symtable_exitScope (g_symtab); }
#line 3075 "llgrammar.c"
    break;

  case 52: /* claim: LLT_CLAIMS fcnId claimId LLT_SEMI  */
#line 531 "llgrammar.y"
   { (yyval.claim) = (claimNode) 0; }
#line 3081 "llgrammar.c"
    break;

  case 53: /* $@6: %empty  */
#line 535 "llgrammar.y"
               {g_inTypeDef = TRUE; }
#line 3087 "llgrammar.c"
    break;

  case 54: /* $@7: %empty  */
#line 535 "llgrammar.y"
                                                                {g_inTypeDef = FALSE; }
#line 3093 "llgrammar.c"
    break;

  case 55: /* abstract: LLT_MUTABLE $@6 LLT_TYPE LLT_TYPEDEF_NAME $@7 abstBody  */
#line 536 "llgrammar.y"
   { (yyval.abstract) = makeAbstractNode ((yyvsp[-5].ltok), (yyvsp[-2].ltok), TRUE, FALSE, (yyvsp[0].abstbody)); }
#line 3099 "llgrammar.c"
    break;

  case 56: /* $@8: %empty  */
#line 537 "llgrammar.y"
               {g_inTypeDef = TRUE; }
#line 3105 "llgrammar.c"
    break;

  case 57: /* $@9: %empty  */
#line 538 "llgrammar.y"
                    {g_inTypeDef = FALSE; }
#line 3111 "llgrammar.c"
    break;

  case 58: /* abstract: LLT_MUTABLE $@8 LLT_REFCOUNTED LLT_TYPE LLT_TYPEDEF_NAME $@9 abstBody  */
#line 539 "llgrammar.y"
   { (yyval.abstract) = makeAbstractNode ((yyvsp[-6].ltok), (yyvsp[-2].ltok), TRUE, TRUE, (yyvsp[0].abstbody)); }
#line 3117 "llgrammar.c"
    break;

  case 59: /* $@10: %empty  */
#line 540 "llgrammar.y"
                              {g_inTypeDef = TRUE; }
#line 3123 "llgrammar.c"
    break;

  case 60: /* $@11: %empty  */
#line 541 "llgrammar.y"
                    {g_inTypeDef = FALSE; }
#line 3129 "llgrammar.c"
    break;

  case 61: /* abstract: LLT_REFCOUNTED LLT_MUTABLE $@10 LLT_TYPE LLT_TYPEDEF_NAME $@11 abstBody  */
#line 542 "llgrammar.y"
   { (yyval.abstract) = makeAbstractNode ((yyvsp[-5].ltok), (yyvsp[-2].ltok), TRUE, TRUE, (yyvsp[0].abstbody)); }
#line 3135 "llgrammar.c"
    break;

  case 62: /* $@12: %empty  */
#line 543 "llgrammar.y"
                 {g_inTypeDef = TRUE; }
#line 3141 "llgrammar.c"
    break;

  case 63: /* $@13: %empty  */
#line 543 "llgrammar.y"
                                                                  {g_inTypeDef = FALSE; }
#line 3147 "llgrammar.c"
    break;

  case 64: /* abstract: LLT_IMMUTABLE $@12 LLT_TYPE LLT_TYPEDEF_NAME $@13 abstBody  */
#line 544 "llgrammar.y"
   { (yyval.abstract) = makeAbstractNode ((yyvsp[-5].ltok), (yyvsp[-2].ltok), FALSE, FALSE, (yyvsp[0].abstbody)); }
#line 3153 "llgrammar.c"
    break;

  case 65: /* $@14: %empty  */
#line 548 "llgrammar.y"
                           { g_inTypeDef = TRUE; setExposedType ((yyvsp[0].lcltypespec)); }
#line 3159 "llgrammar.c"
    break;

  case 66: /* $@15: %empty  */
#line 549 "llgrammar.y"
   { g_inTypeDef = FALSE; }
#line 3165 "llgrammar.c"
    break;

  case 67: /* exposed: LLT_TYPEDEF lclTypeSpec $@14 declaratorInvs $@15 LLT_SEMI  */
#line 550 "llgrammar.y"
   { (yyval.exposed) = makeExposedNode ((yyvsp[-5].ltok), (yyvsp[-4].lcltypespec), (yyvsp[-2].declaratorinvs)); /* to support mutually recursive types */ }
#line 3171 "llgrammar.c"
    break;

  case 68: /* exposed: structOrUnionSpec LLT_SEMI  */
#line 552 "llgrammar.y"
   { (yyval.exposed) = makeExposedNode ((yyvsp[0].ltok), makeLclTypeSpecNodeSU ((yyvsp[-1].structorunion)), declaratorInvNodeList_new ()); }
#line 3177 "llgrammar.c"
    break;

  case 69: /* exposed: enumSpec LLT_SEMI  */
#line 554 "llgrammar.y"
   { (yyval.exposed) = makeExposedNode ((yyvsp[0].ltok), makeLclTypeSpecNodeEnum ((yyvsp[-1].enumspec)), declaratorInvNodeList_new ()); }
#line 3183 "llgrammar.c"
    break;

  case 70: /* importNameList: importName  */
#line 571 "llgrammar.y"
   { (yyval.importlist) = importNodeList_add (importNodeList_new (),  (yyvsp[0].import)); }
#line 3189 "llgrammar.c"
    break;

  case 71: /* importNameList: importNameList LLT_COMMA importName  */
#line 573 "llgrammar.y"
   { (yyval.importlist) = importNodeList_add ((yyvsp[-2].importlist), (yyvsp[0].import)); }
#line 3195 "llgrammar.c"
    break;

  case 72: /* importName: interfaceName  */
#line 577 "llgrammar.y"
                      { (yyval.import) = importNode_makePlain ((yyvsp[0].ltok)); }
#line 3201 "llgrammar.c"
    break;

  case 73: /* importName: simpleOp interfaceName simpleOp  */
#line 579 "llgrammar.y"
   { checkBrackets ((yyvsp[-2].ltok), (yyvsp[0].ltok)); (yyval.import) = importNode_makeBracketed ((yyvsp[-1].ltok)); }
#line 3207 "llgrammar.c"
    break;

  case 74: /* importName: LLT_LCSTRING  */
#line 580 "llgrammar.y"
                          { (yyval.import) = importNode_makeQuoted ((yyvsp[0].ltok)); }
#line 3213 "llgrammar.c"
    break;

  case 75: /* interfaceNameList: interfaceName  */
#line 584 "llgrammar.y"
                                         { (yyval.ltokenList) = ltokenList_singleton ((yyvsp[0].ltok)); }
#line 3219 "llgrammar.c"
    break;

  case 76: /* interfaceNameList: interfaceNameList LLT_COMMA interfaceName  */
#line 585 "llgrammar.y"
                                             { (yyval.ltokenList) = ltokenList_push ((yyvsp[-2].ltokenList), (yyvsp[0].ltok)); }
#line 3225 "llgrammar.c"
    break;

  case 78: /* traitRefNodeList: traitRef  */
#line 595 "llgrammar.y"
   { (yyval.traitreflist) = traitRefNodeList_add (traitRefNodeList_new (),  (yyvsp[0].traitref)); }
#line 3231 "llgrammar.c"
    break;

  case 79: /* traitRefNodeList: traitRefNodeList LLT_COMMA traitRef  */
#line 597 "llgrammar.y"
   { (yyval.traitreflist) = traitRefNodeList_add ((yyvsp[-2].traitreflist), (yyvsp[0].traitref)); }
#line 3237 "llgrammar.c"
    break;

  case 80: /* traitRef: traitId  */
#line 602 "llgrammar.y"
   { (yyval.traitref) = makeTraitRefNode (ltokenList_singleton ((yyvsp[0].ltok)), (renamingNode)0); }
#line 3243 "llgrammar.c"
    break;

  case 81: /* traitRef: traitId LLT_LPAR renaming LLT_RPAR  */
#line 604 "llgrammar.y"
   { (yyval.traitref) = makeTraitRefNode (ltokenList_singleton ((yyvsp[-3].ltok)), (yyvsp[-1].renaming)); }
#line 3249 "llgrammar.c"
    break;

  case 82: /* traitRef: LLT_LPAR traitIdList LLT_RPAR  */
#line 606 "llgrammar.y"
   { (yyval.traitref) = makeTraitRefNode ((yyvsp[-1].ltokenList), (renamingNode)0); }
#line 3255 "llgrammar.c"
    break;

  case 83: /* traitRef: LLT_LPAR traitIdList LLT_RPAR LLT_LPAR renaming LLT_RPAR  */
#line 608 "llgrammar.y"
   { (yyval.traitref) = makeTraitRefNode ((yyvsp[-4].ltokenList), (yyvsp[-1].renaming)); }
#line 3261 "llgrammar.c"
    break;

  case 84: /* traitIdList: traitId  */
#line 612 "llgrammar.y"
                               { (yyval.ltokenList) = ltokenList_singleton ((yyvsp[0].ltok)); }
#line 3267 "llgrammar.c"
    break;

  case 85: /* traitIdList: traitIdList LLT_COMMA traitId  */
#line 613 "llgrammar.y"
                                   { (yyval.ltokenList) = ltokenList_push ((yyvsp[-2].ltokenList), (yyvsp[0].ltok)); }
#line 3273 "llgrammar.c"
    break;

  case 86: /* renaming: replaceNodeList  */
#line 618 "llgrammar.y"
   { (yyval.renaming) = makeRenamingNode (typeNameNodeList_new (),  (yyvsp[0].replacelist)); }
#line 3279 "llgrammar.c"
    break;

  case 87: /* renaming: nameList  */
#line 620 "llgrammar.y"
   { (yyval.renaming) = makeRenamingNode ((yyvsp[0].namelist), replaceNodeList_new ()); }
#line 3285 "llgrammar.c"
    break;

  case 88: /* renaming: nameList LLT_COMMA replaceNodeList  */
#line 621 "llgrammar.y"
                                      { (yyval.renaming) = makeRenamingNode ((yyvsp[-2].namelist), (yyvsp[0].replacelist)); }
#line 3291 "llgrammar.c"
    break;

  case 89: /* nameList: typeName  */
#line 626 "llgrammar.y"
   { (yyval.namelist) = typeNameNodeList_add (typeNameNodeList_new (),  (yyvsp[0].typname)); }
#line 3297 "llgrammar.c"
    break;

  case 90: /* nameList: nameList LLT_COMMA typeName  */
#line 627 "llgrammar.y"
                                     { (yyval.namelist) = typeNameNodeList_add ((yyvsp[-2].namelist), (yyvsp[0].typname)); }
#line 3303 "llgrammar.c"
    break;

  case 91: /* replaceNodeList: replace  */
#line 632 "llgrammar.y"
   { (yyval.replacelist) = replaceNodeList_add (replaceNodeList_new (),  (yyvsp[0].replace)); }
#line 3309 "llgrammar.c"
    break;

  case 92: /* replaceNodeList: replaceNodeList LLT_COMMA replace  */
#line 633 "llgrammar.y"
                                     { (yyval.replacelist) = replaceNodeList_add ((yyvsp[-2].replacelist), (yyvsp[0].replace)); }
#line 3315 "llgrammar.c"
    break;

  case 93: /* replace: typeName LLT_FOR CType  */
#line 637 "llgrammar.y"
                                     { (yyval.replace) = makeReplaceNode ((yyvsp[-1].ltok), (yyvsp[-2].typname), TRUE, (yyvsp[0].ltok), NULL, NULL); }
#line 3321 "llgrammar.c"
    break;

  case 94: /* replace: typeName LLT_FOR name  */
#line 638 "llgrammar.y"
                                     { (yyval.replace) = makeReplaceNameNode ((yyvsp[-1].ltok), (yyvsp[-2].typname), (yyvsp[0].name)); }
#line 3327 "llgrammar.c"
    break;

  case 95: /* replace: typeName LLT_FOR name signature  */
#line 639 "llgrammar.y"
                                     { (yyval.replace) = makeReplaceNode ((yyvsp[-2].ltok), (yyvsp[-3].typname), FALSE, ltoken_undefined,
							 (yyvsp[-1].name), (yyvsp[0].signature)); }
#line 3334 "llgrammar.c"
    break;

  case 96: /* name: opId  */
#line 644 "llgrammar.y"
                                 { (yyval.name) = makeNameNodeId ((yyvsp[0].ltok)); }
#line 3340 "llgrammar.c"
    break;

  case 97: /* name: opForm  */
#line 645 "llgrammar.y"
                                 { (yyval.name) = makeNameNodeForm ((yyvsp[0].opform)); }
#line 3346 "llgrammar.c"
    break;

  case 100: /* initDecls: initDecl  */
#line 656 "llgrammar.y"
   { (yyval.initdecls) = initDeclNodeList_add (initDeclNodeList_new (),  (yyvsp[0].initdecl)); }
#line 3352 "llgrammar.c"
    break;

  case 101: /* initDecls: initDecls LLT_COMMA initDecl  */
#line 658 "llgrammar.y"
   { (yyval.initdecls) = initDeclNodeList_add ((yyvsp[-2].initdecls), (yyvsp[0].initdecl)); }
#line 3358 "llgrammar.c"
    break;

  case 102: /* initDecl: declarator  */
#line 662 "llgrammar.y"
                                 { (yyval.initdecl) = makeInitDeclNode ((yyvsp[0].declare), (termNode)0); }
#line 3364 "llgrammar.c"
    break;

  case 103: /* initDecl: declarator LLT_EQUALS initializer  */
#line 663 "llgrammar.y"
                                     { (yyval.initdecl) = makeInitDeclNode ((yyvsp[-2].declare), (yyvsp[0].term)); }
#line 3370 "llgrammar.c"
    break;

  case 104: /* globals: %empty  */
#line 668 "llgrammar.y"
   { (yyval.globals) = varDeclarationNodeList_new (); }
#line 3376 "llgrammar.c"
    break;

  case 105: /* globals: globals globalDecl  */
#line 670 "llgrammar.y"
   { varDeclarationNodeList_addh ((yyvsp[-1].globals), (yyvsp[0].vardeclaration)); (yyval.globals) = (yyvsp[-1].globals); }
#line 3382 "llgrammar.c"
    break;

  case 106: /* globalDecl: lclTypeSpec initDecls LLT_SEMI  */
#line 674 "llgrammar.y"
                                     { (yyval.vardeclaration) = makeVarDeclarationNode ((yyvsp[-2].lcltypespec), (yyvsp[-1].initdecls), TRUE, FALSE); }
#line 3388 "llgrammar.c"
    break;

  case 107: /* globalDecl: LLT_INTERNAL LLT_SEMI  */
#line 675 "llgrammar.y"
                                         { (yyval.vardeclaration) = makeInternalStateNode (); }
#line 3394 "llgrammar.c"
    break;

  case 108: /* globalDecl: LLT_FILESYS LLT_SEMI  */
#line 676 "llgrammar.y"
                                         { (yyval.vardeclaration) = makeFileSystemNode (); }
#line 3400 "llgrammar.c"
    break;

  case 109: /* privateInits: %empty  */
#line 680 "llgrammar.y"
                                { (yyval.vardeclarationlist) = varDeclarationNodeList_new (); }
#line 3406 "llgrammar.c"
    break;

  case 110: /* privateInits: privateInits privateInit  */
#line 681 "llgrammar.y"
                                { varDeclarationNodeList_addh ((yyvsp[-1].vardeclarationlist), (yyvsp[0].vardeclaration)); (yyval.vardeclarationlist) = (yyvsp[-1].vardeclarationlist); }
#line 3412 "llgrammar.c"
    break;

  case 111: /* privateInit: LLT_PRIVATE lclTypeSpec initDecls LLT_SEMI  */
#line 686 "llgrammar.y"
   { (yyval.vardeclaration) = makeVarDeclarationNode ((yyvsp[-2].lcltypespec), (yyvsp[-1].initdecls), FALSE, TRUE); }
#line 3418 "llgrammar.c"
    break;

  case 112: /* optLetDecl: %empty  */
#line 690 "llgrammar.y"
                               { (yyval.letdecls) = letDeclNodeList_new (); }
#line 3424 "llgrammar.c"
    break;

  case 113: /* optLetDecl: LLT_LET beDeclList LLT_SEMI  */
#line 691 "llgrammar.y"
                                       { (yyval.letdecls) = (yyvsp[-1].letdecls); }
#line 3430 "llgrammar.c"
    break;

  case 114: /* beDeclList: beDecl  */
#line 695 "llgrammar.y"
                               { (yyval.letdecls) = letDeclNodeList_add (letDeclNodeList_new (),  (yyvsp[0].letdecl)); }
#line 3436 "llgrammar.c"
    break;

  case 115: /* beDeclList: beDeclList LLT_COMMA beDecl  */
#line 696 "llgrammar.y"
                                   { (yyval.letdecls) = letDeclNodeList_add ((yyvsp[-2].letdecls), (yyvsp[0].letdecl)); }
#line 3442 "llgrammar.c"
    break;

  case 116: /* beDecl: varId LLT_COLON sortSpec LLT_BE term  */
#line 700 "llgrammar.y"
                                        { (yyval.letdecl) = makeLetDeclNode ((yyvsp[-4].ltok), (yyvsp[-2].lcltypespec), (yyvsp[0].term)); }
#line 3448 "llgrammar.c"
    break;

  case 117: /* beDecl: varId LLT_BE term  */
#line 701 "llgrammar.y"
                                    { (yyval.letdecl) = makeLetDeclNode ((yyvsp[-2].ltok), (lclTypeSpecNode)0, (yyvsp[0].term)); }
#line 3454 "llgrammar.c"
    break;

  case 119: /* optChecks: %empty  */
#line 708 "llgrammar.y"
                                { (yyval.lclpredicate) = (lclPredicateNode)0; }
#line 3460 "llgrammar.c"
    break;

  case 120: /* optChecks: LLT_CHECKS lclPredicate LLT_SEMI  */
#line 709 "llgrammar.y"
                                        { checkLclPredicate ((yyvsp[-2].ltok), (yyvsp[-1].lclpredicate)); (yyval.lclpredicate) = makeChecksNode ((yyvsp[-2].ltok), (yyvsp[-1].lclpredicate)); }
#line 3466 "llgrammar.c"
    break;

  case 121: /* optRequire: %empty  */
#line 713 "llgrammar.y"
                                { (yyval.lclpredicate) = (lclPredicateNode)0; }
#line 3472 "llgrammar.c"
    break;

  case 122: /* optRequire: LLT_REQUIRES lclPredicate LLT_SEMI  */
#line 714 "llgrammar.y"
                                        { checkLclPredicate ((yyvsp[-2].ltok), (yyvsp[-1].lclpredicate)); (yyval.lclpredicate) = makeRequiresNode ((yyvsp[-2].ltok), (yyvsp[-1].lclpredicate));}
#line 3478 "llgrammar.c"
    break;

  case 123: /* optModify: %empty  */
#line 718 "llgrammar.y"
                                { (yyval.modify) = (modifyNode)0; }
#line 3484 "llgrammar.c"
    break;

  case 124: /* optModify: LLT_MODIFIES LLT_NOTHING LLT_SEMI  */
#line 719 "llgrammar.y"
                                            { (yyval.modify) = makeModifyNodeSpecial ((yyvsp[-2].ltok), TRUE); }
#line 3490 "llgrammar.c"
    break;

  case 125: /* optModify: LLT_MODIFIES LLT_ANYTHING LLT_SEMI  */
#line 720 "llgrammar.y"
                                            { (yyval.modify) = makeModifyNodeSpecial ((yyvsp[-2].ltok), FALSE); }
#line 3496 "llgrammar.c"
    break;

  case 126: /* optModify: LLT_MODIFIES storeRefList LLT_SEMI  */
#line 721 "llgrammar.y"
                                        { (yyval.modify) = makeModifyNodeRef ((yyvsp[-2].ltok), (yyvsp[-1].storereflist)); }
#line 3502 "llgrammar.c"
    break;

  case 127: /* storeRefList: storeRef  */
#line 725 "llgrammar.y"
                                { (yyval.storereflist) = storeRefNodeList_add (storeRefNodeList_new (),  (yyvsp[0].storeref)); }
#line 3508 "llgrammar.c"
    break;

  case 128: /* storeRefList: storeRefList LLT_COMMA storeRef  */
#line 726 "llgrammar.y"
                                    { (yyval.storereflist) = storeRefNodeList_add ((yyvsp[-2].storereflist), (yyvsp[0].storeref)); }
#line 3514 "llgrammar.c"
    break;

  case 129: /* storeRef: term  */
#line 730 "llgrammar.y"
                                { (yyval.storeref) = makeStoreRefNodeTerm ((yyvsp[0].term)); }
#line 3520 "llgrammar.c"
    break;

  case 130: /* storeRef: lclType  */
#line 731 "llgrammar.y"
                                { (yyval.storeref) = makeStoreRefNodeType ((yyvsp[0].lcltypespec), FALSE); }
#line 3526 "llgrammar.c"
    break;

  case 131: /* storeRef: LLT_OBJ lclType  */
#line 732 "llgrammar.y"
                                    { (yyval.storeref) = makeStoreRefNodeType ((yyvsp[0].lcltypespec), TRUE); }
#line 3532 "llgrammar.c"
    break;

  case 132: /* storeRef: LLT_INTERNAL  */
#line 733 "llgrammar.y"
                                    { (yyval.storeref) = makeStoreRefNodeInternal (); }
#line 3538 "llgrammar.c"
    break;

  case 133: /* storeRef: LLT_FILESYS  */
#line 734 "llgrammar.y"
                                    { (yyval.storeref) = makeStoreRefNodeSystem (); }
#line 3544 "llgrammar.c"
    break;

  case 134: /* optEnsure: %empty  */
#line 738 "llgrammar.y"
                                { (yyval.lclpredicate) = (lclPredicateNode)0; }
#line 3550 "llgrammar.c"
    break;

  case 135: /* optEnsure: LLT_ENSURES lclPredicate LLT_SEMI  */
#line 739 "llgrammar.y"
                                        { checkLclPredicate ((yyvsp[-2].ltok), (yyvsp[-1].lclpredicate)); (yyval.lclpredicate) = makeEnsuresNode ((yyvsp[-2].ltok), (yyvsp[-1].lclpredicate));}
#line 3556 "llgrammar.c"
    break;

  case 136: /* optClaim: %empty  */
#line 743 "llgrammar.y"
                                { (yyval.lclpredicate) = (lclPredicateNode)0; }
#line 3562 "llgrammar.c"
    break;

  case 137: /* optClaim: LLT_CLAIMS lclPredicate LLT_SEMI  */
#line 744 "llgrammar.y"
                                        { checkLclPredicate ((yyvsp[-2].ltok), (yyvsp[-1].lclpredicate)); (yyval.lclpredicate) = makeIntraClaimNode ((yyvsp[-2].ltok), (yyvsp[-1].lclpredicate));}
#line 3568 "llgrammar.c"
    break;

  case 138: /* optParamList: %empty  */
#line 748 "llgrammar.y"
                                { (yyval.paramlist) = paramNodeList_new (); }
#line 3574 "llgrammar.c"
    break;

  case 139: /* optParamList: realParamList  */
#line 749 "llgrammar.y"
                                { (yyval.paramlist) = (yyvsp[0].paramlist); }
#line 3580 "llgrammar.c"
    break;

  case 141: /* realParamList: LLT_TELIPSIS  */
#line 754 "llgrammar.y"
                                 { (yyval.paramlist) = paramNodeList_add (paramNodeList_new (),  paramNode_elipsis ()); }
#line 3586 "llgrammar.c"
    break;

  case 142: /* realParamList: paramList LLT_COMMA LLT_TELIPSIS  */
#line 755 "llgrammar.y"
                                     { (yyval.paramlist) = paramNodeList_add ((yyvsp[-2].paramlist), paramNode_elipsis ()); }
#line 3592 "llgrammar.c"
    break;

  case 143: /* paramList: param  */
#line 759 "llgrammar.y"
                             { (yyval.paramlist) = paramNodeList_single ((yyvsp[0].param)); }
#line 3598 "llgrammar.c"
    break;

  case 144: /* paramList: paramList LLT_COMMA param  */
#line 760 "llgrammar.y"
                                 { (yyval.paramlist) = paramNodeList_add ((yyvsp[-2].paramlist), (yyvsp[0].param)); }
#line 3604 "llgrammar.c"
    break;

  case 145: /* optBody: %empty  */
#line 764 "llgrammar.y"
                                    { (yyval.program) = (programNode)0; }
#line 3610 "llgrammar.c"
    break;

  case 146: /* optBody: LLT_BODY LLT_LBRACE callExpr LLT_RBRACE  */
#line 765 "llgrammar.y"
                                                { (yyval.program) = (yyvsp[-1].program); }
#line 3616 "llgrammar.c"
    break;

  case 147: /* optBody: LLT_BODY LLT_LBRACE callExpr LLT_SEMI LLT_RBRACE  */
#line 766 "llgrammar.y"
                                                    { (yyval.program) = (yyvsp[-2].program); }
#line 3622 "llgrammar.c"
    break;

  case 148: /* callExpr: stmt  */
#line 770 "llgrammar.y"
                                    { (yyval.program) = makeProgramNode ((yyvsp[0].stmt)); }
#line 3628 "llgrammar.c"
    break;

  case 149: /* callExpr: LLT_LPAR callExpr LLT_RPAR  */
#line 773 "llgrammar.y"
   { (yyval.program) = (yyvsp[-1].program); (yyval.program)->wrapped = (yyval.program)->wrapped + 1; }
#line 3634 "llgrammar.c"
    break;

  case 150: /* callExpr: callExpr LLT_MULOP  */
#line 775 "llgrammar.y"
   { programNodeList x = programNodeList_new ();
     programNodeList_addh (x, (yyvsp[-1].program));
     (yyval.program) = makeProgramNodeAction (x, ACT_ITER); 
   }
#line 3643 "llgrammar.c"
    break;

  case 151: /* callExpr: callExpr LLT_VERTICALBAR callExpr  */
#line 780 "llgrammar.y"
   { programNodeList x = programNodeList_new ();
     programNodeList_addh (x, (yyvsp[-2].program));
     programNodeList_addh (x, (yyvsp[0].program));
     (yyval.program) = makeProgramNodeAction (x, ACT_ALTERNATE); 
   }
#line 3653 "llgrammar.c"
    break;

  case 152: /* callExpr: callExpr LLT_SEMI callExpr  */
#line 786 "llgrammar.y"
   { programNodeList x = programNodeList_new ();
     programNodeList_addh (x, (yyvsp[-2].program));
     programNodeList_addh (x, (yyvsp[0].program));
     (yyval.program) = makeProgramNodeAction (x, ACT_SEQUENCE); 
   }
#line 3663 "llgrammar.c"
    break;

  case 153: /* stmt: fcnId LLT_LPAR valueList LLT_RPAR  */
#line 795 "llgrammar.y"
   { (yyval.stmt) = makeStmtNode (ltoken_undefined, (yyvsp[-3].ltok), (yyvsp[-1].termlist)); }
#line 3669 "llgrammar.c"
    break;

  case 154: /* stmt: fcnId LLT_LPAR LLT_RPAR  */
#line 797 "llgrammar.y"
   { (yyval.stmt) = makeStmtNode (ltoken_undefined, (yyvsp[-2].ltok), termNodeList_new ()); }
#line 3675 "llgrammar.c"
    break;

  case 155: /* stmt: varId LLT_EQUALS fcnId LLT_LPAR LLT_RPAR  */
#line 799 "llgrammar.y"
   { (yyval.stmt) = makeStmtNode ((yyvsp[-4].ltok), (yyvsp[-2].ltok), termNodeList_new ()); }
#line 3681 "llgrammar.c"
    break;

  case 156: /* stmt: varId LLT_EQUALS fcnId LLT_LPAR valueList LLT_RPAR  */
#line 801 "llgrammar.y"
   { (yyval.stmt) = makeStmtNode ((yyvsp[-5].ltok), (yyvsp[-3].ltok), (yyvsp[-1].termlist)); }
#line 3687 "llgrammar.c"
    break;

  case 157: /* valueList: value  */
#line 805 "llgrammar.y"
                         { (yyval.termlist) = termNodeList_push (termNodeList_new (),  (yyvsp[0].term)); }
#line 3693 "llgrammar.c"
    break;

  case 158: /* valueList: valueList LLT_COMMA value  */
#line 806 "llgrammar.y"
                             { (yyval.termlist) = termNodeList_push ((yyvsp[-2].termlist), (yyvsp[0].term)); }
#line 3699 "llgrammar.c"
    break;

  case 160: /* value: varId  */
#line 811 "llgrammar.y"
                                    { (yyval.term) = makeSimpleTermNode ((yyvsp[0].ltok)); }
#line 3705 "llgrammar.c"
    break;

  case 161: /* value: simpleOp value  */
#line 812 "llgrammar.y"
                                    { (yyval.term) = makePrefixTermNode ((yyvsp[-1].ltok), (yyvsp[0].term)); }
#line 3711 "llgrammar.c"
    break;

  case 162: /* value: value simpleOp  */
#line 813 "llgrammar.y"
                                    { (yyval.term) = makePostfixTermNode2 ((yyvsp[-1].term), (yyvsp[0].ltok)); }
#line 3717 "llgrammar.c"
    break;

  case 163: /* value: value simpleOp value  */
#line 814 "llgrammar.y"
                                    { (yyval.term) = makeInfixTermNode ((yyvsp[-2].term), (yyvsp[-1].ltok), (yyvsp[0].term)); }
#line 3723 "llgrammar.c"
    break;

  case 164: /* value: LLT_LPAR value LLT_RPAR  */
#line 815 "llgrammar.y"
                                            { (yyval.term) = (yyvsp[-1].term); (yyval.term)->wrapped = (yyval.term)->wrapped + 1; }
#line 3729 "llgrammar.c"
    break;

  case 165: /* value: fcnId LLT_LPAR LLT_RPAR  */
#line 817 "llgrammar.y"
   { (yyval.term) = makeOpCallTermNode ((yyvsp[-2].ltok), (yyvsp[-1].ltok), termNodeList_new (),  (yyvsp[0].ltok)); }
#line 3735 "llgrammar.c"
    break;

  case 166: /* value: fcnId LLT_LPAR valueList LLT_RPAR  */
#line 819 "llgrammar.y"
   { (yyval.term) = makeOpCallTermNode ((yyvsp[-3].ltok), (yyvsp[-2].ltok), (yyvsp[-1].termlist), (yyvsp[0].ltok)); }
#line 3741 "llgrammar.c"
    break;

  case 167: /* abstBody: LLT_SEMI  */
#line 823 "llgrammar.y"
                                             { (yyval.abstbody) = (abstBodyNode)0; }
#line 3747 "llgrammar.c"
    break;

  case 168: /* abstBody: LLT_LBRACE fcns LLT_RBRACE  */
#line 824 "llgrammar.y"
                                                 { (yyval.abstbody) = makeAbstBodyNode ((yyvsp[-2].ltok), (yyvsp[-1].fcns)); }
#line 3753 "llgrammar.c"
    break;

  case 169: /* abstBody: LLT_LBRACE interfaceNameList LLT_RBRACE LLT_SEMI  */
#line 825 "llgrammar.y"
                                                     { (yyval.abstbody) = makeAbstBodyNode2 ((yyvsp[-3].ltok), (yyvsp[-2].ltokenList)); }
#line 3759 "llgrammar.c"
    break;

  case 170: /* abstBody: LLT_LBRACE LLT_RBRACE LLT_SEMI  */
#line 826 "llgrammar.y"
                                                     { (yyval.abstbody) = (abstBodyNode)0; }
#line 3765 "llgrammar.c"
    break;

  case 171: /* fcns: %empty  */
#line 830 "llgrammar.y"
                                         { (yyval.fcns) = fcnNodeList_new (); }
#line 3771 "llgrammar.c"
    break;

  case 172: /* fcns: fcns fcn  */
#line 831 "llgrammar.y"
                                         { (yyval.fcns) = fcnNodeList_add ((yyvsp[-1].fcns), (yyvsp[0].fcn)); }
#line 3777 "llgrammar.c"
    break;

  case 173: /* optTypeInv: %empty  */
#line 835 "llgrammar.y"
                                         { (yyval.lclpredicate) = (lclPredicateNode)0; }
#line 3783 "llgrammar.c"
    break;

  case 175: /* $@16: %empty  */
#line 840 "llgrammar.y"
                  { g_inTypeDef = FALSE; }
#line 3789 "llgrammar.c"
    break;

  case 176: /* typeInv: LLT_CONSTRAINT $@16 quantifier LLT_LPAR lclPredicate LLT_RPAR  */
#line 841 "llgrammar.y"
   { (yyvsp[-1].lclpredicate)->tok = (yyvsp[-5].ltok); (yyvsp[-1].lclpredicate)->kind = LPD_CONSTRAINT;
     checkLclPredicate ((yyvsp[-5].ltok), (yyvsp[-1].lclpredicate));
     (yyval.lclpredicate) = (yyvsp[-1].lclpredicate);
     symtable_exitScope (g_symtab); 
     g_inTypeDef = TRUE;
   }
#line 3800 "llgrammar.c"
    break;

  case 177: /* declaratorInvs: declaratorInv  */
#line 850 "llgrammar.y"
                        { (yyval.declaratorinvs) = declaratorInvNodeList_add (declaratorInvNodeList_new (),  (yyvsp[0].declaratorinv)); }
#line 3806 "llgrammar.c"
    break;

  case 178: /* declaratorInvs: declaratorInvs LLT_COMMA declaratorInv  */
#line 852 "llgrammar.y"
   { (yyval.declaratorinvs) = declaratorInvNodeList_add ((yyvsp[-2].declaratorinvs), (yyvsp[0].declaratorinv)); }
#line 3812 "llgrammar.c"
    break;

  case 179: /* $@17: %empty  */
#line 856 "llgrammar.y"
              { declareForwardType ((yyvsp[0].declare)); }
#line 3818 "llgrammar.c"
    break;

  case 180: /* declaratorInv: declarator $@17 optExposedBody  */
#line 857 "llgrammar.y"
   { (yyval.declaratorinv) = makeDeclaratorInvNode ((yyvsp[-2].declare), (yyvsp[0].abstbody)); }
#line 3824 "llgrammar.c"
    break;

  case 181: /* optExposedBody: %empty  */
#line 861 "llgrammar.y"
                                { (yyval.abstbody) = (abstBodyNode)0; }
#line 3830 "llgrammar.c"
    break;

  case 182: /* optExposedBody: LLT_LBRACE optTypeInv LLT_RBRACE  */
#line 862 "llgrammar.y"
                                        { (yyval.abstbody) = makeExposedBodyNode ((yyvsp[-2].ltok), (yyvsp[-1].lclpredicate)); }
#line 3836 "llgrammar.c"
    break;

  case 183: /* CType: LLT_VOID  */
#line 866 "llgrammar.y"
                      { (yyval.ltok) = (yyvsp[0].ltok); ltoken_setIntField ((yyval.ltok), fixBits (TS_VOID, 0)); }
#line 3842 "llgrammar.c"
    break;

  case 184: /* CType: LLT_CHAR  */
#line 867 "llgrammar.y"
                      { (yyval.ltok) = (yyvsp[0].ltok); ltoken_setIntField ((yyval.ltok), fixBits (TS_CHAR, 0)); }
#line 3848 "llgrammar.c"
    break;

  case 185: /* CType: LLT_DOUBLE  */
#line 868 "llgrammar.y"
                      { (yyval.ltok) = (yyvsp[0].ltok); ltoken_setIntField ((yyval.ltok), fixBits (TS_DOUBLE, 0)); }
#line 3854 "llgrammar.c"
    break;

  case 186: /* CType: LLT_FLOAT  */
#line 869 "llgrammar.y"
                      { (yyval.ltok) = (yyvsp[0].ltok); ltoken_setIntField ((yyval.ltok), fixBits (TS_FLOAT, 0)); }
#line 3860 "llgrammar.c"
    break;

  case 187: /* CType: LLT_INT  */
#line 870 "llgrammar.y"
                      { (yyval.ltok) = (yyvsp[0].ltok); ltoken_setIntField ((yyval.ltok), fixBits (TS_INT, 0)); }
#line 3866 "llgrammar.c"
    break;

  case 188: /* CType: LLT_LONG  */
#line 871 "llgrammar.y"
                      { (yyval.ltok) = (yyvsp[0].ltok); ltoken_setIntField ((yyval.ltok), fixBits (TS_LONG, 0)); }
#line 3872 "llgrammar.c"
    break;

  case 189: /* CType: LLT_SHORT  */
#line 872 "llgrammar.y"
                      { (yyval.ltok) = (yyvsp[0].ltok); ltoken_setIntField ((yyval.ltok), fixBits (TS_SHORT, 0)); }
#line 3878 "llgrammar.c"
    break;

  case 190: /* CType: LLT_SIGNED  */
#line 873 "llgrammar.y"
                      { (yyval.ltok) = (yyvsp[0].ltok); ltoken_setIntField ((yyval.ltok), fixBits (TS_SIGNED, 0)); }
#line 3884 "llgrammar.c"
    break;

  case 191: /* CType: LLT_UNSIGNED  */
#line 874 "llgrammar.y"
                      { (yyval.ltok) = (yyvsp[0].ltok); ltoken_setIntField ((yyval.ltok), fixBits (TS_UNSIGNED, 0)); }
#line 3890 "llgrammar.c"
    break;

  case 192: /* CType: LLT_UNKNOWN  */
#line 875 "llgrammar.y"
                      { (yyval.ltok) = (yyvsp[0].ltok); ltoken_setIntField ((yyval.ltok), fixBits (TS_UNKNOWN, 0)); }
#line 3896 "llgrammar.c"
    break;

  case 193: /* CTypes: CType  */
#line 884 "llgrammar.y"
                               { (yyval.ctypes) = makeCTypesNode ((CTypesNode)0, (yyvsp[0].ltok)); }
#line 3902 "llgrammar.c"
    break;

  case 194: /* CTypes: CTypes CType  */
#line 885 "llgrammar.y"
                               { (yyval.ctypes) = makeCTypesNode ((yyvsp[-1].ctypes), (yyvsp[0].ltok)); }
#line 3908 "llgrammar.c"
    break;

  case 195: /* typeSpecifier: LLT_TYPEDEF_NAME  */
#line 892 "llgrammar.y"
   { (yyval.ctypes) = makeTypeSpecifier ((yyvsp[0].ltok)); }
#line 3914 "llgrammar.c"
    break;

  case 196: /* typeSpecifier: CTypes  */
#line 894 "llgrammar.y"
   { (yyval.ctypes) = (yyvsp[0].ctypes); (yyval.ctypes)->sort = sort_lookupName (lclctype_toSort ((yyvsp[0].ctypes)->intfield)); }
#line 3920 "llgrammar.c"
    break;

  case 197: /* specialQualifier: LLT_OUT  */
#line 900 "llgrammar.y"
                 { (yyval.typequal) = qual_createOut (); }
#line 3926 "llgrammar.c"
    break;

  case 198: /* specialQualifier: LLT_UNUSED  */
#line 901 "llgrammar.y"
              { (yyval.typequal) = qual_createUnused (); }
#line 3932 "llgrammar.c"
    break;

  case 199: /* specialQualifier: LLT_SEF  */
#line 902 "llgrammar.y"
                 { (yyval.typequal) = qual_createSef (); }
#line 3938 "llgrammar.c"
    break;

  case 200: /* specialQualifier: LLT_ONLY  */
#line 903 "llgrammar.y"
                 { (yyval.typequal) = qual_createOnly (); }
#line 3944 "llgrammar.c"
    break;

  case 201: /* specialQualifier: LLT_OWNED  */
#line 904 "llgrammar.y"
                 { (yyval.typequal) = qual_createOwned (); }
#line 3950 "llgrammar.c"
    break;

  case 202: /* specialQualifier: LLT_DEPENDENT  */
#line 905 "llgrammar.y"
                 { (yyval.typequal) = qual_createDependent (); }
#line 3956 "llgrammar.c"
    break;

  case 203: /* specialQualifier: LLT_KEEP  */
#line 906 "llgrammar.y"
                 { (yyval.typequal) = qual_createKeep (); }
#line 3962 "llgrammar.c"
    break;

  case 204: /* specialQualifier: LLT_KEPT  */
#line 907 "llgrammar.y"
                 { (yyval.typequal) = qual_createKept (); }
#line 3968 "llgrammar.c"
    break;

  case 205: /* specialQualifier: LLT_OBSERVER  */
#line 908 "llgrammar.y"
                 { (yyval.typequal) = qual_createObserver (); }
#line 3974 "llgrammar.c"
    break;

  case 206: /* specialQualifier: LLT_EXITS  */
#line 909 "llgrammar.y"
                 { (yyval.typequal) = qual_createExits (); }
#line 3980 "llgrammar.c"
    break;

  case 207: /* specialQualifier: LLT_MAYEXIT  */
#line 910 "llgrammar.y"
                 { (yyval.typequal) = qual_createMayExit (); }
#line 3986 "llgrammar.c"
    break;

  case 208: /* specialQualifier: LLT_TRUEEXIT  */
#line 911 "llgrammar.y"
                 { (yyval.typequal) = qual_createTrueExit (); }
#line 3992 "llgrammar.c"
    break;

  case 209: /* specialQualifier: LLT_FALSEEXIT  */
#line 912 "llgrammar.y"
                 { (yyval.typequal) = qual_createFalseExit (); }
#line 3998 "llgrammar.c"
    break;

  case 210: /* specialQualifier: LLT_NEVEREXIT  */
#line 913 "llgrammar.y"
                 { (yyval.typequal) = qual_createNeverExit (); }
#line 4004 "llgrammar.c"
    break;

  case 211: /* specialQualifier: LLT_TEMP  */
#line 914 "llgrammar.y"
                 { (yyval.typequal) = qual_createOnly (); }
#line 4010 "llgrammar.c"
    break;

  case 212: /* specialQualifier: LLT_SHARED  */
#line 915 "llgrammar.y"
                 { (yyval.typequal) = qual_createShared (); }
#line 4016 "llgrammar.c"
    break;

  case 213: /* specialQualifier: LLT_UNIQUE  */
#line 916 "llgrammar.y"
                 { (yyval.typequal) = qual_createUnique (); }
#line 4022 "llgrammar.c"
    break;

  case 214: /* specialQualifier: LLT_CHECKED  */
#line 917 "llgrammar.y"
                 { (yyval.typequal) = qual_createChecked (); }
#line 4028 "llgrammar.c"
    break;

  case 215: /* specialQualifier: LLT_UNCHECKED  */
#line 918 "llgrammar.y"
                 { (yyval.typequal) = qual_createUnchecked (); }
#line 4034 "llgrammar.c"
    break;

  case 216: /* specialQualifier: LLT_CHECKEDSTRICT  */
#line 919 "llgrammar.y"
                     { (yyval.typequal) = qual_createCheckedStrict (); }
#line 4040 "llgrammar.c"
    break;

  case 217: /* specialQualifier: LLT_TRUENULL  */
#line 920 "llgrammar.y"
                 { (yyval.typequal) = qual_createTrueNull (); }
#line 4046 "llgrammar.c"
    break;

  case 218: /* specialQualifier: LLT_FALSENULL  */
#line 921 "llgrammar.y"
                 { (yyval.typequal) = qual_createFalseNull (); }
#line 4052 "llgrammar.c"
    break;

  case 219: /* specialQualifier: LLT_RELNULL  */
#line 922 "llgrammar.y"
                 { (yyval.typequal) = qual_createRelNull (); }
#line 4058 "llgrammar.c"
    break;

  case 220: /* specialQualifier: LLT_RELDEF  */
#line 923 "llgrammar.y"
                 { (yyval.typequal) = qual_createRelDef (); }
#line 4064 "llgrammar.c"
    break;

  case 221: /* specialQualifier: LLT_REFCOUNTED  */
#line 924 "llgrammar.y"
                 { (yyval.typequal) = qual_createRefCounted (); }
#line 4070 "llgrammar.c"
    break;

  case 222: /* specialQualifier: LLT_REFS  */
#line 925 "llgrammar.y"
                 { (yyval.typequal) = qual_createRefs (); }
#line 4076 "llgrammar.c"
    break;

  case 223: /* specialQualifier: LLT_NEWREF  */
#line 926 "llgrammar.y"
                 { (yyval.typequal) = qual_createNewRef (); }
#line 4082 "llgrammar.c"
    break;

  case 224: /* specialQualifier: LLT_KILLREF  */
#line 927 "llgrammar.y"
                 { (yyval.typequal) = qual_createKillRef (); }
#line 4088 "llgrammar.c"
    break;

  case 225: /* specialQualifier: LLT_LNULL  */
#line 928 "llgrammar.y"
                 { (yyval.typequal) = qual_createNull (); }
#line 4094 "llgrammar.c"
    break;

  case 226: /* specialQualifier: LLT_LNOTNULL  */
#line 929 "llgrammar.y"
                 { (yyval.typequal) = qual_createNotNull (); }
#line 4100 "llgrammar.c"
    break;

  case 227: /* specialQualifier: LLT_RETURNED  */
#line 930 "llgrammar.y"
                 { (yyval.typequal) = qual_createReturned (); }
#line 4106 "llgrammar.c"
    break;

  case 228: /* specialQualifier: LLT_EXPOSED  */
#line 931 "llgrammar.y"
                 { (yyval.typequal) = qual_createExposed (); }
#line 4112 "llgrammar.c"
    break;

  case 229: /* specialQualifier: LLT_PARTIAL  */
#line 932 "llgrammar.y"
                 { (yyval.typequal) = qual_createPartial (); }
#line 4118 "llgrammar.c"
    break;

  case 230: /* specialQualifier: LLT_NULLTERMINATED  */
#line 933 "llgrammar.y"
                      { (yyval.typequal) = qual_createNullTerminated () ; }
#line 4124 "llgrammar.c"
    break;

  case 231: /* specialQualifier: LLT_UNDEF  */
#line 934 "llgrammar.y"
             { (yyval.typequal) = qual_createUndef (); }
#line 4130 "llgrammar.c"
    break;

  case 232: /* specialQualifier: LLT_KILLED  */
#line 935 "llgrammar.y"
              { (yyval.typequal) = qual_createKilled (); }
#line 4136 "llgrammar.c"
    break;

  case 233: /* lclTypeSpec: typeSpecifier  */
#line 940 "llgrammar.y"
   { (yyval.lcltypespec) = makeLclTypeSpecNodeType ((yyvsp[0].ctypes)); }
#line 4142 "llgrammar.c"
    break;

  case 234: /* lclTypeSpec: structOrUnionSpec  */
#line 942 "llgrammar.y"
   { (yyval.lcltypespec) = makeLclTypeSpecNodeSU ((yyvsp[0].structorunion)); }
#line 4148 "llgrammar.c"
    break;

  case 235: /* lclTypeSpec: enumSpec  */
#line 944 "llgrammar.y"
   { (yyval.lcltypespec) = makeLclTypeSpecNodeEnum ((yyvsp[0].enumspec)); }
#line 4154 "llgrammar.c"
    break;

  case 236: /* lclTypeSpec: specialQualifier lclTypeSpec  */
#line 946 "llgrammar.y"
   { (yyval.lcltypespec) = lclTypeSpecNode_addQual ((yyvsp[0].lcltypespec), (yyvsp[-1].typequal)); }
#line 4160 "llgrammar.c"
    break;

  case 237: /* lclTypeSpec: LLT_VERTICALBAR lclType LLT_COLON lclType LLT_VERTICALBAR  */
#line 948 "llgrammar.y"
   { (yyval.lcltypespec) = makeLclTypeSpecNodeConj ((yyvsp[-3].lcltypespec), (yyvsp[-1].lcltypespec)); }
#line 4166 "llgrammar.c"
    break;

  case 239: /* lclType: lclTypeSpec pointers  */
#line 959 "llgrammar.y"
   { llassert (lclTypeSpecNode_isDefined ((yyvsp[-1].lcltypespec)));
     (yyvsp[-1].lcltypespec)->pointers = (yyvsp[0].pointers); (yyval.lcltypespec) = (yyvsp[-1].lcltypespec); }
#line 4173 "llgrammar.c"
    break;

  case 240: /* pointers: LLT_MULOP  */
#line 964 "llgrammar.y"
                      { (yyval.pointers) = pointers_createLt ((yyvsp[0].ltok)); }
#line 4179 "llgrammar.c"
    break;

  case 241: /* pointers: pointers LLT_MULOP  */
#line 965 "llgrammar.y"
                      { (yyval.pointers) = pointers_extend ((yyvsp[-1].pointers), pointers_createLt ((yyvsp[0].ltok))); }
#line 4185 "llgrammar.c"
    break;

  case 242: /* $@18: %empty  */
#line 970 "llgrammar.y"
   { (void) checkAndEnterTag (TAG_FWDSTRUCT, ltoken_copy ((yyvsp[0].ltok))); }
#line 4191 "llgrammar.c"
    break;

  case 243: /* structOrUnionSpec: LLT_STRUCT optTagId $@18 LLT_LBRACE structDecls LLT_RBRACE  */
#line 972 "llgrammar.y"
   { (yyval.structorunion) = makestrOrUnionNode ((yyvsp[-5].ltok), SU_STRUCT, (yyvsp[-4].ltok), (yyvsp[-1].structdecls)); }
#line 4197 "llgrammar.c"
    break;

  case 244: /* $@19: %empty  */
#line 974 "llgrammar.y"
   { (void) checkAndEnterTag (TAG_FWDUNION, ltoken_copy ((yyvsp[0].ltok))); }
#line 4203 "llgrammar.c"
    break;

  case 245: /* structOrUnionSpec: LLT_UNION optTagId $@19 LLT_LBRACE structDecls LLT_RBRACE  */
#line 976 "llgrammar.y"
   { (yyval.structorunion) = makestrOrUnionNode ((yyvsp[-5].ltok), SU_UNION, (yyvsp[-4].ltok), (yyvsp[-1].structdecls)); }
#line 4209 "llgrammar.c"
    break;

  case 246: /* structOrUnionSpec: LLT_STRUCT tagId  */
#line 978 "llgrammar.y"
   { (yyval.structorunion) = makeForwardstrOrUnionNode ((yyvsp[-1].ltok), SU_STRUCT, (yyvsp[0].ltok)); }
#line 4215 "llgrammar.c"
    break;

  case 247: /* structOrUnionSpec: LLT_UNION tagId  */
#line 980 "llgrammar.y"
   { (yyval.structorunion) = makeForwardstrOrUnionNode ((yyvsp[-1].ltok), SU_UNION, (yyvsp[0].ltok)); }
#line 4221 "llgrammar.c"
    break;

  case 248: /* optTagId: %empty  */
#line 984 "llgrammar.y"
               { (yyval.ltok) = ltoken_undefined; }
#line 4227 "llgrammar.c"
    break;

  case 250: /* structDecls: structDecl  */
#line 989 "llgrammar.y"
                            { (yyval.structdecls) = stDeclNodeList_add (stDeclNodeList_new (),  (yyvsp[0].structdecl)); }
#line 4233 "llgrammar.c"
    break;

  case 251: /* structDecls: structDecls structDecl  */
#line 990 "llgrammar.y"
                            { (yyval.structdecls) = stDeclNodeList_add ((yyvsp[-1].structdecls), (yyvsp[0].structdecl)); }
#line 4239 "llgrammar.c"
    break;

  case 252: /* structDecl: lclTypeSpec declaratorList LLT_SEMI  */
#line 996 "llgrammar.y"
                                       { (yyval.structdecl) = makestDeclNode ((yyvsp[-2].lcltypespec), (yyvsp[-1].declarelist)); }
#line 4245 "llgrammar.c"
    break;

  case 253: /* declaratorList: declarator  */
#line 1001 "llgrammar.y"
   { (yyval.declarelist) = declaratorNodeList_add (declaratorNodeList_new (),  (yyvsp[0].declare)); }
#line 4251 "llgrammar.c"
    break;

  case 254: /* declaratorList: declaratorList LLT_COMMA declarator  */
#line 1003 "llgrammar.y"
   { (yyval.declarelist) = declaratorNodeList_add ((yyvsp[-2].declarelist), (yyvsp[0].declare)); }
#line 4257 "llgrammar.c"
    break;

  case 255: /* optCOMMA: %empty  */
#line 1007 "llgrammar.y"
               { ; }
#line 4263 "llgrammar.c"
    break;

  case 256: /* optCOMMA: LLT_COMMA  */
#line 1008 "llgrammar.y"
                   { ; }
#line 4269 "llgrammar.c"
    break;

  case 257: /* enumSpec: LLT_ENUM optTagId LLT_LBRACE enumeratorList optCOMMA LLT_RBRACE  */
#line 1013 "llgrammar.y"
   { (yyval.enumspec) = makeEnumSpecNode ((yyvsp[-5].ltok), (yyvsp[-4].ltok), (yyvsp[-2].ltokenList)); }
#line 4275 "llgrammar.c"
    break;

  case 258: /* enumSpec: LLT_ENUM tagId  */
#line 1015 "llgrammar.y"
   { (yyval.enumspec) = makeEnumSpecNode2 ((yyvsp[-1].ltok), (yyvsp[0].ltok)); }
#line 4281 "llgrammar.c"
    break;

  case 259: /* enumeratorList: simpleId  */
#line 1019 "llgrammar.y"
                                        { (yyval.ltokenList) = ltokenList_singleton ((yyvsp[0].ltok)); }
#line 4287 "llgrammar.c"
    break;

  case 260: /* enumeratorList: enumeratorList LLT_COMMA simpleId  */
#line 1020 "llgrammar.y"
                                            { (yyval.ltokenList) = ltokenList_push ((yyvsp[-2].ltokenList), (yyvsp[0].ltok)); }
#line 4293 "llgrammar.c"
    break;

  case 261: /* declarator: after_type_decl  */
#line 1031 "llgrammar.y"
                                        { (yyval.declare) = makeDeclaratorNode ((yyvsp[0].typeexpr)); }
#line 4299 "llgrammar.c"
    break;

  case 262: /* declarator: notype_decl  */
#line 1032 "llgrammar.y"
                                        { (yyval.declare) = makeDeclaratorNode ((yyvsp[0].typeexpr)); }
#line 4305 "llgrammar.c"
    break;

  case 263: /* notype_decl: varId  */
#line 1036 "llgrammar.y"
                                        { (yyval.typeexpr) = makeTypeExpr ((yyvsp[0].ltok)); }
#line 4311 "llgrammar.c"
    break;

  case 264: /* notype_decl: LLT_LPAR notype_decl LLT_RPAR  */
#line 1037 "llgrammar.y"
                                        { (yyval.typeexpr) = (yyvsp[-1].typeexpr); (yyval.typeexpr)->wrapped = (yyval.typeexpr)->wrapped + 1; }
#line 4317 "llgrammar.c"
    break;

  case 265: /* notype_decl: LLT_MULOP notype_decl  */
#line 1038 "llgrammar.y"
                                        { (yyval.typeexpr) = makePointerNode ((yyvsp[-1].ltok), (yyvsp[0].typeexpr)); }
#line 4323 "llgrammar.c"
    break;

  case 266: /* notype_decl: notype_decl arrayQual  */
#line 1039 "llgrammar.y"
                                        { (yyval.typeexpr) = makeArrayNode ((yyvsp[-1].typeexpr), (yyvsp[0].array)); }
#line 4329 "llgrammar.c"
    break;

  case 267: /* notype_decl: notype_decl LLT_LPAR LLT_RPAR  */
#line 1040 "llgrammar.y"
                                                { (yyval.typeexpr) = makeFunctionNode ((yyvsp[-2].typeexpr), paramNodeList_new ()); }
#line 4335 "llgrammar.c"
    break;

  case 268: /* notype_decl: notype_decl LLT_LPAR realParamList LLT_RPAR  */
#line 1041 "llgrammar.y"
                                                { (yyval.typeexpr) = makeFunctionNode ((yyvsp[-3].typeexpr), (yyvsp[-1].paramlist)); }
#line 4341 "llgrammar.c"
    break;

  case 269: /* after_type_decl: LLT_TYPEDEF_NAME  */
#line 1045 "llgrammar.y"
                                            { (yyval.typeexpr) = makeTypeExpr ((yyvsp[0].ltok)); }
#line 4347 "llgrammar.c"
    break;

  case 270: /* after_type_decl: LLT_LPAR after_type_decl LLT_RPAR  */
#line 1046 "llgrammar.y"
                                            { (yyval.typeexpr) = (yyvsp[-1].typeexpr); (yyval.typeexpr)->wrapped = (yyval.typeexpr)->wrapped + 1; }
#line 4353 "llgrammar.c"
    break;

  case 271: /* after_type_decl: LLT_MULOP after_type_decl  */
#line 1047 "llgrammar.y"
                                            { (yyval.typeexpr) = makePointerNode ((yyvsp[-1].ltok), (yyvsp[0].typeexpr)); }
#line 4359 "llgrammar.c"
    break;

  case 272: /* after_type_decl: after_type_decl arrayQual  */
#line 1048 "llgrammar.y"
                                            { (yyval.typeexpr) = makeArrayNode ((yyvsp[-1].typeexpr), (yyvsp[0].array)); }
#line 4365 "llgrammar.c"
    break;

  case 273: /* after_type_decl: after_type_decl LLT_LPAR LLT_RPAR  */
#line 1049 "llgrammar.y"
                                                    { (yyval.typeexpr) = makeFunctionNode ((yyvsp[-2].typeexpr), paramNodeList_new ()); }
#line 4371 "llgrammar.c"
    break;

  case 274: /* after_type_decl: after_type_decl LLT_LPAR realParamList LLT_RPAR  */
#line 1050 "llgrammar.y"
                                                    { (yyval.typeexpr) = makeFunctionNode ((yyvsp[-3].typeexpr), (yyvsp[-1].paramlist)); }
#line 4377 "llgrammar.c"
    break;

  case 275: /* parameter_decl: LLT_TYPEDEF_NAME  */
#line 1060 "llgrammar.y"
                                                { (yyval.typeexpr) = makeTypeExpr ((yyvsp[0].ltok)); }
#line 4383 "llgrammar.c"
    break;

  case 276: /* parameter_decl: LLT_MULOP parameter_decl  */
#line 1061 "llgrammar.y"
                                                { (yyval.typeexpr) = makePointerNode ((yyvsp[-1].ltok), (yyvsp[0].typeexpr)); }
#line 4389 "llgrammar.c"
    break;

  case 277: /* parameter_decl: parameter_decl arrayQual  */
#line 1062 "llgrammar.y"
                                            { (yyval.typeexpr) = makeArrayNode ((yyvsp[-1].typeexpr), (yyvsp[0].array)); }
#line 4395 "llgrammar.c"
    break;

  case 278: /* parameter_decl: parameter_decl LLT_LPAR LLT_RPAR  */
#line 1063 "llgrammar.y"
                                                    { (yyval.typeexpr) = makeFunctionNode ((yyvsp[-2].typeexpr), paramNodeList_new ()); }
#line 4401 "llgrammar.c"
    break;

  case 279: /* parameter_decl: parameter_decl LLT_LPAR realParamList LLT_RPAR  */
#line 1064 "llgrammar.y"
                                                    { (yyval.typeexpr) = makeFunctionNode ((yyvsp[-3].typeexpr), (yyvsp[-1].paramlist)); }
#line 4407 "llgrammar.c"
    break;

  case 280: /* param: lclTypeSpec parameter_decl  */
#line 1071 "llgrammar.y"
                                            { (yyval.param) = makeParamNode ((yyvsp[-1].lcltypespec), (yyvsp[0].typeexpr)); }
#line 4413 "llgrammar.c"
    break;

  case 281: /* param: lclTypeSpec notype_decl  */
#line 1072 "llgrammar.y"
                                            { (yyval.param) = makeParamNode ((yyvsp[-1].lcltypespec), (yyvsp[0].typeexpr)); }
#line 4419 "llgrammar.c"
    break;

  case 282: /* param: lclTypeSpec optAbstDeclarator  */
#line 1073 "llgrammar.y"
                                            { (yyval.param) = makeParamNode ((yyvsp[-1].lcltypespec), (yyvsp[0].abstDecl)); }
#line 4425 "llgrammar.c"
    break;

  case 283: /* typeName: lclTypeSpec optAbstDeclarator  */
#line 1084 "llgrammar.y"
                                           { (yyval.typname) = makeTypeNameNode (FALSE, (yyvsp[-1].lcltypespec), (yyvsp[0].abstDecl)); }
#line 4431 "llgrammar.c"
    break;

  case 284: /* typeName: LLT_OBJ lclTypeSpec optAbstDeclarator  */
#line 1085 "llgrammar.y"
                                               { (yyval.typname) = makeTypeNameNode (TRUE, (yyvsp[-1].lcltypespec), (yyvsp[0].abstDecl)); }
#line 4437 "llgrammar.c"
    break;

  case 285: /* typeName: opForm  */
#line 1086 "llgrammar.y"
                                           { (yyval.typname) = makeTypeNameNodeOp ((yyvsp[0].opform)); }
#line 4443 "llgrammar.c"
    break;

  case 286: /* optAbstDeclarator: %empty  */
#line 1092 "llgrammar.y"
                                          { (yyval.abstDecl) = (abstDeclaratorNode)0; }
#line 4449 "llgrammar.c"
    break;

  case 287: /* optAbstDeclarator: abstDeclarator  */
#line 1093 "llgrammar.y"
                                          { (yyval.abstDecl) = (abstDeclaratorNode)(yyvsp[0].typeexpr); }
#line 4455 "llgrammar.c"
    break;

  case 288: /* abstDeclarator: LLT_LPAR abstDeclarator LLT_RPAR  */
#line 1097 "llgrammar.y"
                                                  { (yyval.typeexpr) = (yyvsp[-1].typeexpr); (yyval.typeexpr)->wrapped = (yyval.typeexpr)->wrapped + 1; }
#line 4461 "llgrammar.c"
    break;

  case 289: /* abstDeclarator: LLT_MULOP abstDeclarator  */
#line 1098 "llgrammar.y"
                                              { (yyval.typeexpr) = makePointerNode ((yyvsp[-1].ltok), (yyvsp[0].typeexpr)); }
#line 4467 "llgrammar.c"
    break;

  case 290: /* abstDeclarator: LLT_MULOP  */
#line 1099 "llgrammar.y"
                                              { (yyval.typeexpr) = makePointerNode ((yyvsp[0].ltok), (typeExpr)0); }
#line 4473 "llgrammar.c"
    break;

  case 291: /* abstDeclarator: arrayQual  */
#line 1100 "llgrammar.y"
                                          { (yyval.typeexpr) = makeArrayNode ((typeExpr)0, (yyvsp[0].array)); }
#line 4479 "llgrammar.c"
    break;

  case 292: /* abstDeclarator: abstDeclarator arrayQual  */
#line 1101 "llgrammar.y"
                                          { (yyval.typeexpr) = makeArrayNode ((yyvsp[-1].typeexpr), (yyvsp[0].array)); }
#line 4485 "llgrammar.c"
    break;

  case 293: /* abstDeclarator: abstDeclarator LLT_LPAR LLT_RPAR  */
#line 1102 "llgrammar.y"
                                                  { (yyval.typeexpr) = makeFunctionNode ((yyvsp[-2].typeexpr), paramNodeList_new ()); }
#line 4491 "llgrammar.c"
    break;

  case 294: /* abstDeclarator: LLT_LPAR realParamList LLT_RPAR  */
#line 1103 "llgrammar.y"
                                                  { (yyval.typeexpr) = makeFunctionNode ((typeExpr)0, (yyvsp[-1].paramlist)); }
#line 4497 "llgrammar.c"
    break;

  case 295: /* abstDeclarator: abstDeclarator LLT_LPAR realParamList LLT_RPAR  */
#line 1104 "llgrammar.y"
                                                  { (yyval.typeexpr) = makeFunctionNode ((yyvsp[-3].typeexpr), (yyvsp[-1].paramlist)); }
#line 4503 "llgrammar.c"
    break;

  case 296: /* arrayQual: LLT_LBRACKET LLT_RBRACKET  */
#line 1108 "llgrammar.y"
                                                 { (yyval.array) = makeArrayQualNode ((yyvsp[-1].ltok), (termNode)0); }
#line 4509 "llgrammar.c"
    break;

  case 297: /* arrayQual: LLT_LBRACKET constLclExpr LLT_RBRACKET  */
#line 1109 "llgrammar.y"
                                                 { (yyval.array) = makeArrayQualNode ((yyvsp[-2].ltok), (yyvsp[-1].term)); }
#line 4515 "llgrammar.c"
    break;

  case 298: /* opForm: LLT_IF markerSym LLT_THEN markerSym LLT_ELSE markerSym  */
#line 1114 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-5].ltok), OPF_IF, opFormUnion_createMiddle (0), ltoken_undefined); }
#line 4521 "llgrammar.c"
    break;

  case 299: /* opForm: anyOp  */
#line 1116 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[0].ltok), OPF_ANYOP, opFormUnion_createAnyOp ((yyvsp[0].ltok)), ltoken_undefined); }
#line 4527 "llgrammar.c"
    break;

  case 300: /* opForm: markerSym anyOp  */
#line 1118 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-1].ltok), OPF_MANYOP, opFormUnion_createAnyOp ((yyvsp[0].ltok)), ltoken_undefined); }
#line 4533 "llgrammar.c"
    break;

  case 301: /* opForm: anyOp markerSym  */
#line 1120 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-1].ltok), OPF_ANYOPM, opFormUnion_createAnyOp ((yyvsp[-1].ltok)), ltoken_undefined); }
#line 4539 "llgrammar.c"
    break;

  case 302: /* opForm: markerSym anyOp markerSym  */
#line 1122 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-2].ltok), OPF_MANYOPM, 
			  opFormUnion_createAnyOp ((yyvsp[-1].ltok)), ltoken_undefined); }
#line 4546 "llgrammar.c"
    break;

  case 303: /* opForm: open middle close  */
#line 1125 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-2].ltok), OPF_MIDDLE, opFormUnion_createMiddle ((yyvsp[-1].count)), (yyvsp[0].ltok)); }
#line 4552 "llgrammar.c"
    break;

  case 304: /* opForm: markerSym open middle close  */
#line 1127 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-3].ltok), OPF_MMIDDLE, opFormUnion_createMiddle ((yyvsp[-1].count)), (yyvsp[0].ltok)); }
#line 4558 "llgrammar.c"
    break;

  case 305: /* opForm: open middle close markerSym  */
#line 1129 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-3].ltok), OPF_MIDDLEM, opFormUnion_createMiddle ((yyvsp[-2].count)), (yyvsp[-1].ltok)); }
#line 4564 "llgrammar.c"
    break;

  case 306: /* opForm: markerSym open middle close markerSym  */
#line 1131 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-3].ltok), OPF_MMIDDLEM, opFormUnion_createMiddle ((yyvsp[-2].count)), (yyvsp[-1].ltok)); }
#line 4570 "llgrammar.c"
    break;

  case 307: /* opForm: LLT_LBRACKET middle LLT_RBRACKET  */
#line 1133 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-2].ltok), OPF_BMIDDLE, opFormUnion_createMiddle ((yyvsp[-1].count)), (yyvsp[0].ltok)); }
#line 4576 "llgrammar.c"
    break;

  case 308: /* opForm: LLT_LBRACKET middle LLT_RBRACKET markerSym  */
#line 1135 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-3].ltok), OPF_BMIDDLEM, opFormUnion_createMiddle ((yyvsp[-2].count)), (yyvsp[-1].ltok)); }
#line 4582 "llgrammar.c"
    break;

  case 309: /* opForm: markerSym LLT_LBRACKET middle LLT_RBRACKET  */
#line 1143 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-2].ltok), OPF_BMMIDDLE, opFormUnion_createMiddle ((yyvsp[-1].count)), (yyvsp[0].ltok)); }
#line 4588 "llgrammar.c"
    break;

  case 310: /* opForm: markerSym LLT_LBRACKET middle LLT_RBRACKET markerSym  */
#line 1145 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-3].ltok), OPF_BMMIDDLEM, opFormUnion_createMiddle ((yyvsp[-2].count)), (yyvsp[-1].ltok)); }
#line 4594 "llgrammar.c"
    break;

  case 311: /* opForm: selectSym simpleIdOrTypedefName  */
#line 1147 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-1].ltok), OPF_SELECT, 
			  opFormUnion_createAnyOp ((yyvsp[0].ltok)), ltoken_undefined); }
#line 4601 "llgrammar.c"
    break;

  case 312: /* opForm: mapSym simpleIdOrTypedefName  */
#line 1150 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-1].ltok), OPF_MAP, 
			  opFormUnion_createAnyOp ((yyvsp[0].ltok)), ltoken_undefined); }
#line 4608 "llgrammar.c"
    break;

  case 313: /* opForm: markerSym selectSym simpleIdOrTypedefName  */
#line 1153 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-2].ltok), OPF_MSELECT, 
			  opFormUnion_createAnyOp ((yyvsp[0].ltok)), ltoken_undefined); }
#line 4615 "llgrammar.c"
    break;

  case 314: /* opForm: markerSym mapSym simpleIdOrTypedefName  */
#line 1156 "llgrammar.y"
   { (yyval.opform) = makeOpFormNode ((yyvsp[-2].ltok), OPF_MMAP, 
			  opFormUnion_createAnyOp ((yyvsp[0].ltok)), ltoken_undefined); }
#line 4622 "llgrammar.c"
    break;

  case 322: /* middle: %empty  */
#line 1177 "llgrammar.y"
                             { (yyval.count) = 0; }
#line 4628 "llgrammar.c"
    break;

  case 324: /* placeList: markerSym  */
#line 1182 "llgrammar.y"
                                  { (yyval.count) = 1; }
#line 4634 "llgrammar.c"
    break;

  case 325: /* placeList: placeList separator markerSym  */
#line 1183 "llgrammar.y"
                                  { (yyval.count) = (yyvsp[-2].count) + 1; }
#line 4640 "llgrammar.c"
    break;

  case 328: /* signature: LLT_COLON domain mapSym sortId  */
#line 1192 "llgrammar.y"
                                    { (yyval.signature) = makesigNode ((yyvsp[-3].ltok), (yyvsp[-2].ltokenList), (yyvsp[0].ltok)); }
#line 4646 "llgrammar.c"
    break;

  case 329: /* domain: %empty  */
#line 1196 "llgrammar.y"
                             { (yyval.ltokenList) = ltokenList_new (); }
#line 4652 "llgrammar.c"
    break;

  case 331: /* sortList: sortId  */
#line 1201 "llgrammar.y"
                             { (yyval.ltokenList) = ltokenList_singleton ((yyvsp[0].ltok)); }
#line 4658 "llgrammar.c"
    break;

  case 332: /* sortList: sortList LLT_COMMA sortId  */
#line 1202 "llgrammar.y"
                                 { (yyval.ltokenList) = ltokenList_push ((yyvsp[-2].ltokenList), (yyvsp[0].ltok)); }
#line 4664 "llgrammar.c"
    break;

  case 333: /* lclPredicate: term  */
#line 1206 "llgrammar.y"
                             { (yyval.lclpredicate) = makeLclPredicateNode (ltoken_undefined, (yyvsp[0].term), LPD_PLAIN);}
#line 4670 "llgrammar.c"
    break;

  case 334: /* term: term0  */
#line 1210 "llgrammar.y"
                             { (yyval.term) = checkSort ((yyvsp[0].term)); }
#line 4676 "llgrammar.c"
    break;

  case 335: /* term0: LLT_IF term0 LLT_THEN term0 LLT_ELSE term0  */
#line 1218 "llgrammar.y"
   { (yyval.term) = makeIfTermNode ((yyvsp[-5].ltok),(yyvsp[-4].term),(yyvsp[-3].ltok),(yyvsp[-2].term),(yyvsp[-1].ltok),(yyvsp[0].term)); }
#line 4682 "llgrammar.c"
    break;

  case 337: /* term0: term0 logicalOp term0  */
#line 1220 "llgrammar.y"
                                  { (yyval.term) = makeInfixTermNode ((yyvsp[-2].term), (yyvsp[-1].ltok), (yyvsp[0].term)); }
#line 4688 "llgrammar.c"
    break;

  case 339: /* equalityTerm: quantifiers LLT_LPAR lclPredicate LLT_RPAR  */
#line 1227 "llgrammar.y"
   { checkLclPredicate ((yyvsp[-2].ltok), (yyvsp[-1].lclpredicate)); (yyval.term) = makeQuantifiedTermNode ((yyvsp[-3].quantifiers), (yyvsp[-2].ltok), (yyvsp[-1].lclpredicate)->predicate, (yyvsp[0].ltok));
     symtable_exitScope (g_symtab); 
   }
#line 4696 "llgrammar.c"
    break;

  case 340: /* equalityTerm: simpleOpTerm eqOp simpleOpTerm  */
#line 1231 "llgrammar.y"
   { (yyval.term) = makeInfixTermNode ((yyvsp[-2].term), (yyvsp[-1].ltok), (yyvsp[0].term));}
#line 4702 "llgrammar.c"
    break;

  case 341: /* equalityTerm: simpleOpTerm LLT_EQUALS simpleOpTerm  */
#line 1233 "llgrammar.y"
   { (yyval.term) = makeInfixTermNode ((yyvsp[-2].term), (yyvsp[-1].ltok), (yyvsp[0].term));}
#line 4708 "llgrammar.c"
    break;

  case 343: /* simpleOpTerm: secondary postfixOps  */
#line 1238 "llgrammar.y"
                                 { (yyval.term) = makePostfixTermNode ((yyvsp[-1].term), (yyvsp[0].ltokenList)); }
#line 4714 "llgrammar.c"
    break;

  case 344: /* simpleOpTerm: secondary infixOpPart  */
#line 1239 "llgrammar.y"
                                 { (yyval.term) = CollapseInfixTermNode ((yyvsp[-1].term), (yyvsp[0].termlist)); }
#line 4720 "llgrammar.c"
    break;

  case 348: /* prefixOpTerm: simpleOp2 prefixOpTerm  */
#line 1249 "llgrammar.y"
                                   { (yyval.term) = makePrefixTermNode ((yyvsp[-1].ltok), (yyvsp[0].term)); }
#line 4726 "llgrammar.c"
    break;

  case 349: /* postfixOps: simpleOp2  */
#line 1253 "llgrammar.y"
                                   { (yyval.ltokenList) = ltokenList_singleton ((yyvsp[0].ltok)); }
#line 4732 "llgrammar.c"
    break;

  case 350: /* postfixOps: postfixOps simpleOp2  */
#line 1254 "llgrammar.y"
                                   { (yyval.ltokenList) = ltokenList_push ((yyvsp[-1].ltokenList), (yyvsp[0].ltok)); }
#line 4738 "llgrammar.c"
    break;

  case 351: /* infixOpPart: simpleOp2 secondary  */
#line 1258 "llgrammar.y"
                                   { (yyval.termlist) = pushInfixOpPartNode (termNodeList_new (),  (yyvsp[-1].ltok), (yyvsp[0].term)); }
#line 4744 "llgrammar.c"
    break;

  case 352: /* infixOpPart: infixOpPart simpleOp2 secondary  */
#line 1259 "llgrammar.y"
                                   { (yyval.termlist) = pushInfixOpPartNode ((yyvsp[-2].termlist), (yyvsp[-1].ltok), (yyvsp[0].term)); }
#line 4750 "llgrammar.c"
    break;

  case 354: /* secondary: bracketed  */
#line 1264 "llgrammar.y"
                             { (yyval.term) = computePossibleSorts ((yyvsp[0].term)); }
#line 4756 "llgrammar.c"
    break;

  case 355: /* secondary: bracketed primary  */
#line 1265 "llgrammar.y"
                             { (yyval.term) = updateMatchedNode ((termNode)0, (yyvsp[-1].term), (yyvsp[0].term)); }
#line 4762 "llgrammar.c"
    break;

  case 356: /* secondary: primary bracketed  */
#line 1266 "llgrammar.y"
                             { (yyval.term) = updateMatchedNode ((yyvsp[-1].term), (yyvsp[0].term), (termNode)0); }
#line 4768 "llgrammar.c"
    break;

  case 357: /* secondary: primary bracketed primary  */
#line 1267 "llgrammar.y"
                             { (yyval.term) = updateMatchedNode ((yyvsp[-2].term), (yyvsp[-1].term), (yyvsp[0].term)); }
#line 4774 "llgrammar.c"
    break;

  case 358: /* secondary: sqBracketed  */
#line 1268 "llgrammar.y"
                             { (yyval.term) = computePossibleSorts ((yyvsp[0].term)); }
#line 4780 "llgrammar.c"
    break;

  case 359: /* secondary: sqBracketed primary  */
#line 1269 "llgrammar.y"
                             { (yyval.term) = updateSqBracketedNode ((termNode)0, (yyvsp[-1].term), (yyvsp[0].term)); }
#line 4786 "llgrammar.c"
    break;

  case 360: /* bracketed: matched LLT_COLON sortId  */
#line 1273 "llgrammar.y"
                               { (yyval.term) = (yyvsp[-2].term); (yyval.term)->sort = sort_lookupName (ltoken_getText ((yyvsp[0].ltok))); }
#line 4792 "llgrammar.c"
    break;

  case 362: /* sqBracketed: LLT_LBRACKET args LLT_RBRACKET LLT_COLON sortId  */
#line 1279 "llgrammar.y"
   { (yyval.term) = makeSqBracketedNode ((yyvsp[-4].ltok), (yyvsp[-3].termlist), (yyvsp[-2].ltok)); 
     (yyval.term)->given = sort_lookupName (ltoken_getText ((yyvsp[0].ltok))); }
#line 4799 "llgrammar.c"
    break;

  case 363: /* sqBracketed: LLT_LBRACKET args LLT_RBRACKET  */
#line 1282 "llgrammar.y"
   { (yyval.term) = makeSqBracketedNode ((yyvsp[-2].ltok), (yyvsp[-1].termlist), (yyvsp[0].ltok)); }
#line 4805 "llgrammar.c"
    break;

  case 364: /* sqBracketed: LLT_LBRACKET LLT_RBRACKET LLT_COLON sortId  */
#line 1284 "llgrammar.y"
   { (yyval.term) = makeSqBracketedNode ((yyvsp[-3].ltok), termNodeList_new (),  (yyvsp[-2].ltok)); 
     (yyval.term)->given = sort_lookupName (ltoken_getText ((yyvsp[0].ltok))); 
   }
#line 4813 "llgrammar.c"
    break;

  case 365: /* sqBracketed: LLT_LBRACKET LLT_RBRACKET  */
#line 1288 "llgrammar.y"
   { (yyval.term) = makeSqBracketedNode ((yyvsp[-1].ltok), termNodeList_new (),  (yyvsp[0].ltok)); }
#line 4819 "llgrammar.c"
    break;

  case 366: /* matched: open args close  */
#line 1292 "llgrammar.y"
                             { (yyval.term) = makeMatchedNode ((yyvsp[-2].ltok), (yyvsp[-1].termlist), (yyvsp[0].ltok)); }
#line 4825 "llgrammar.c"
    break;

  case 367: /* matched: open close  */
#line 1293 "llgrammar.y"
                             { (yyval.term) = makeMatchedNode ((yyvsp[-1].ltok), termNodeList_new (),  (yyvsp[0].ltok)); }
#line 4831 "llgrammar.c"
    break;

  case 368: /* args: term  */
#line 1297 "llgrammar.y"
                             { (yyval.termlist) = termNodeList_push (termNodeList_new (),  (yyvsp[0].term)); }
#line 4837 "llgrammar.c"
    break;

  case 369: /* args: args separator term  */
#line 1298 "llgrammar.y"
                             { (yyval.termlist) = termNodeList_push ((yyvsp[-2].termlist), (yyvsp[0].term)); }
#line 4843 "llgrammar.c"
    break;

  case 370: /* primary: LLT_LPAR term0 LLT_RPAR  */
#line 1303 "llgrammar.y"
   { (yyval.term) = (yyvsp[-1].term); (yyval.term)->wrapped = (yyval.term)->wrapped + 1; }
#line 4849 "llgrammar.c"
    break;

  case 371: /* primary: varId  */
#line 1305 "llgrammar.y"
   { (yyval.term) = makeSimpleTermNode ((yyvsp[0].ltok)); }
#line 4855 "llgrammar.c"
    break;

  case 372: /* primary: opId LLT_LPAR termList LLT_RPAR  */
#line 1307 "llgrammar.y"
   { (yyval.term) = makeOpCallTermNode ((yyvsp[-3].ltok), (yyvsp[-2].ltok), (yyvsp[-1].termlist), (yyvsp[0].ltok)); }
#line 4861 "llgrammar.c"
    break;

  case 374: /* primary: primary stateFcn  */
#line 1310 "llgrammar.y"
   { (yyval.term) = makePostfixTermNode2 ((yyvsp[-1].term), (yyvsp[0].ltok)); }
#line 4867 "llgrammar.c"
    break;

  case 375: /* primary: primary selectSym simpleIdOrTypedefName  */
#line 1312 "llgrammar.y"
   { ltoken_markOwned ((yyvsp[0].ltok)); (yyval.term) = makeSelectTermNode ((yyvsp[-2].term), (yyvsp[-1].ltok), (yyvsp[0].ltok)); }
#line 4873 "llgrammar.c"
    break;

  case 376: /* primary: primary mapSym simpleIdOrTypedefName  */
#line 1314 "llgrammar.y"
   { ltoken_markOwned ((yyvsp[0].ltok)); (yyval.term) = makeMapTermNode ((yyvsp[-2].term), (yyvsp[-1].ltok), (yyvsp[0].ltok)); }
#line 4879 "llgrammar.c"
    break;

  case 377: /* primary: primary LLT_LBRACKET LLT_RBRACKET  */
#line 1316 "llgrammar.y"
   { (yyval.term) = updateSqBracketedNode ((yyvsp[-2].term), makeSqBracketedNode ((yyvsp[-1].ltok), termNodeList_new (),  (yyvsp[0].ltok)), 
				(termNode)0); }
#line 4886 "llgrammar.c"
    break;

  case 378: /* primary: primary LLT_LBRACKET termList LLT_RBRACKET  */
#line 1319 "llgrammar.y"
   { (yyval.term) = updateSqBracketedNode ((yyvsp[-3].term), makeSqBracketedNode ((yyvsp[-2].ltok), (yyvsp[-1].termlist), (yyvsp[0].ltok)), (termNode)0); }
#line 4892 "llgrammar.c"
    break;

  case 379: /* primary: primary LLT_COLON sortId  */
#line 1321 "llgrammar.y"
   { (yyval.term) = (yyvsp[-2].term); (yyval.term)->given = sort_lookupName (ltoken_getText ((yyvsp[0].ltok))); }
#line 4898 "llgrammar.c"
    break;

  case 380: /* termList: term0  */
#line 1325 "llgrammar.y"
                          { (yyval.termlist) = termNodeList_push (termNodeList_new (),  (yyvsp[0].term)); }
#line 4904 "llgrammar.c"
    break;

  case 381: /* termList: termList LLT_COMMA term0  */
#line 1326 "llgrammar.y"
                              { (yyval.termlist) = termNodeList_push ((yyvsp[-2].termlist), (yyvsp[0].term)); }
#line 4910 "llgrammar.c"
    break;

  case 387: /* lclPrimary: LLT_RESULT  */
#line 1338 "llgrammar.y"
                                        { (yyval.term) = makeSimpleTermNode ((yyvsp[0].ltok)); }
#line 4916 "llgrammar.c"
    break;

  case 388: /* lclPrimary: LLT_FRESH LLT_LPAR termList LLT_RPAR  */
#line 1339 "llgrammar.y"
                                                { (yyval.term) = makeOpCallTermNode ((yyvsp[-3].ltok), (yyvsp[-2].ltok), (yyvsp[-1].termlist), (yyvsp[0].ltok)); }
#line 4922 "llgrammar.c"
    break;

  case 389: /* lclPrimary: LLT_UNCHANGED LLT_LPAR LLT_ALL LLT_RPAR  */
#line 1340 "llgrammar.y"
                                                    { (yyval.term) = makeUnchangedTermNode1 ((yyvsp[-3].ltok), (yyvsp[-1].ltok)); }
#line 4928 "llgrammar.c"
    break;

  case 390: /* lclPrimary: LLT_UNCHANGED LLT_LPAR storeRefList LLT_RPAR  */
#line 1341 "llgrammar.y"
                                                { (yyval.term) = makeUnchangedTermNode2 ((yyvsp[-3].ltok), (yyvsp[-1].storereflist)); }
#line 4934 "llgrammar.c"
    break;

  case 391: /* lclPrimary: LLT_SIZEOF LLT_LPAR term LLT_RPAR  */
#line 1343 "llgrammar.y"
   { termNodeList x = termNodeList_new (); 
     termNodeList_addh (x, (yyvsp[-1].term));
     (yyval.term) = makeOpCallTermNode ((yyvsp[-3].ltok), (yyvsp[-2].ltok), x, (yyvsp[0].ltok)); 
   }
#line 4943 "llgrammar.c"
    break;

  case 392: /* lclPrimary: LLT_ISSUB LLT_LPAR term LLT_COMMA term LLT_RPAR  */
#line 1348 "llgrammar.y"
   { termNodeList x = termNodeList_new ();
     termNodeList_addh (x, (yyvsp[-3].term));
     termNodeList_addh (x, (yyvsp[-1].term));
     (yyval.term) = makeOpCallTermNode ((yyvsp[-5].ltok), (yyvsp[-4].ltok), x, (yyvsp[0].ltok)); 
   }
#line 4953 "llgrammar.c"
    break;

  case 393: /* lclPrimary: LLT_SIZEOF LLT_LPAR lclTypeSpec LLT_RPAR  */
#line 1353 "llgrammar.y"
                                                  { (yyval.term) = makeSizeofTermNode ((yyvsp[-3].ltok), (yyvsp[-1].lcltypespec)); }
#line 4959 "llgrammar.c"
    break;

  case 394: /* cLiteral: LLT_CINTEGER  */
#line 1364 "llgrammar.y"
                 { (yyval.term) = makeLiteralTermNode ((yyvsp[0].ltok), g_sortInt); }
#line 4965 "llgrammar.c"
    break;

  case 395: /* cLiteral: LLT_LCSTRING  */
#line 1365 "llgrammar.y"
                 { (yyval.term) = makeLiteralTermNode ((yyvsp[0].ltok), g_sortCstring); }
#line 4971 "llgrammar.c"
    break;

  case 396: /* cLiteral: LLT_CCHAR  */
#line 1366 "llgrammar.y"
                 { (yyval.term) = makeLiteralTermNode ((yyvsp[0].ltok), g_sortChar); }
#line 4977 "llgrammar.c"
    break;

  case 397: /* cLiteral: LLT_CFLOAT  */
#line 1367 "llgrammar.y"
                 { (yyval.term) = makeLiteralTermNode ((yyvsp[0].ltok), g_sortDouble); }
#line 4983 "llgrammar.c"
    break;

  case 398: /* quantifiers: quantifier  */
#line 1372 "llgrammar.y"
   { (yyval.quantifiers) = quantifierNodeList_add (quantifierNodeList_new (),  (yyvsp[0].quantifier)); }
#line 4989 "llgrammar.c"
    break;

  case 399: /* quantifiers: quantifiers quantifier  */
#line 1374 "llgrammar.y"
   { (yyval.quantifiers) = quantifierNodeList_add ((yyvsp[-1].quantifiers), (yyvsp[0].quantifier)); }
#line 4995 "llgrammar.c"
    break;

  case 400: /* $@20: %empty  */
#line 1378 "llgrammar.y"
                 { scopeInfo si = (scopeInfo) dmalloc (sizeof (*si));
		   si->kind = SPE_QUANT;
		   symtable_enterScope (g_symtab, si); }
#line 5003 "llgrammar.c"
    break;

  case 401: /* quantifier: quantifierSym $@20 quantifiedList  */
#line 1382 "llgrammar.y"
   { (yyval.quantifier) = makeQuantifierNode ((yyvsp[0].vars), (yyvsp[-2].ltok)); }
#line 5009 "llgrammar.c"
    break;

  case 402: /* quantifiedList: quantified  */
#line 1386 "llgrammar.y"
                                      { (yyval.vars) = varNodeList_add (varNodeList_new (),  (yyvsp[0].var)); }
#line 5015 "llgrammar.c"
    break;

  case 403: /* quantifiedList: quantifiedList LLT_COMMA quantified  */
#line 1387 "llgrammar.y"
                                          { (yyval.vars) = varNodeList_add ((yyvsp[-2].vars), (yyvsp[0].var)); }
#line 5021 "llgrammar.c"
    break;

  case 404: /* quantified: varId LLT_COLON sortSpec  */
#line 1391 "llgrammar.y"
                                { (yyval.var) = makeVarNode ((yyvsp[-2].ltok), FALSE, (yyvsp[0].lcltypespec)); }
#line 5027 "llgrammar.c"
    break;

  case 405: /* quantified: varId LLT_COLON LLT_OBJ sortSpec  */
#line 1392 "llgrammar.y"
                                    { (yyval.var) = makeVarNode ((yyvsp[-3].ltok), TRUE, (yyvsp[0].lcltypespec)); }
#line 5033 "llgrammar.c"
    break;


#line 5037 "llgrammar.c"

      default: break;
    }
  /* User semantic actions sometimes alter yychar, and that requires
     that yytoken be updated with the new translation.  We take the
     approach of translating immediately before every use of yytoken.
     One alternative is translating here after every semantic action,
     but that translation would be missed if the semantic action invokes
     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
     incorrect destructor might then be invoked immediately.  In the
     case of YYERROR or YYBACKUP, subsequent parser actions might lead
     to an incorrect destructor call or verbose syntax error message
     before the lookahead is translated.  */
  YY_SYMBOL_PRINT ("-> $$ =", YY_CAST (yysymbol_kind_t, yyr1[yyn]), &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;

  *++yyvsp = yyval;

  /* Now 'shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */
  {
    const int yylhs = yyr1[yyn] - YYNTOKENS;
    const int yyi = yypgoto[yylhs] + *yyssp;
    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
               ? yytable[yyi]
               : yydefgoto[yylhs]);
  }

  goto yynewstate;


/*--------------------------------------.
| yyerrlab -- here on detecting error.  |
`--------------------------------------*/
yyerrlab:
  /* Make sure we have latest lookahead translation.  See comments at
     user semantic actions for why this is necessary.  */
  yytoken = yychar == YLEMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
      yyerror (YY_("syntax error"));
    }

  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
         error, discard it.  */

      if (yychar <= YLEOF)
        {
          /* Return failure if at end of input.  */
          if (yychar == YLEOF)
            YYABORT;
        }
      else
        {
          yydestruct ("Error: discarding",
                      yytoken, &yylval);
          yychar = YLEMPTY;
        }
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:
  /* Pacify compilers when the user code never invokes YYERROR and the
     label yyerrorlab therefore never appears in user code.  */
  if (0)
    YYERROR;
  ++yynerrs;

  /* Do not reclaim the symbols of the rule whose action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;      /* Each real token shifted decrements this.  */

  /* Pop stack until we find a state that shifts the error token.  */
  for (;;)
    {
      yyn = yypact[yystate];
      if (!yypact_value_is_default (yyn))
        {
          yyn += YYSYMBOL_YYerror;
          if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYSYMBOL_YYerror)
            {
              yyn = yytable[yyn];
              if (0 < yyn)
                break;
            }
        }

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
        YYABORT;


      yydestruct ("Error: popping",
                  YY_ACCESSING_SYMBOL (yystate), yyvsp);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", YY_ACCESSING_SYMBOL (yyn), yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturnlab;


/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturnlab;


/*-----------------------------------------------------------.
| yyexhaustedlab -- YYNOMEM (memory exhaustion) comes here.  |
`-----------------------------------------------------------*/
yyexhaustedlab:
  yyerror (YY_("memory exhausted"));
  yyresult = 2;
  goto yyreturnlab;


/*----------------------------------------------------------.
| yyreturnlab -- parsing is finished, clean up and return.  |
`----------------------------------------------------------*/
yyreturnlab:
  if (yychar != YLEMPTY)
    {
      /* Make sure we have latest lookahead translation.  See comments at
         user semantic actions for why this is necessary.  */
      yytoken = YYTRANSLATE (yychar);
      yydestruct ("Cleanup: discarding lookahead",
                  yytoken, &yylval);
    }
  /* Do not reclaim the symbols of the rule whose action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
                  YY_ACCESSING_SYMBOL (+*yyssp), yyvsp);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif

  return yyresult;
}

#line 1409 "llgrammar.y"


static void
ylerror (const char *s) 
{
  /*@-mustfree@*/
  lclfatalerror (yllval.ltok,
		 message ("%s: Token code: %s, Token String: %s", 
			  cstring_fromChars (s), 
			  ltoken_unparseCodeName (yllval.ltok), 
			  ltoken_getRawString (yllval.ltok)));
  /*@=mustfree@*/
}

static void
ylprint (FILE *f, int t, YLSTYPE value) 
{
  fprintf (f, " type: %d (%s)", t, 
	   cstring_toCharsSafe (ltoken_getRawString (value.ltok)));
}

/*
** check that is it '<' and '>'
*/
static void
checkBrackets (ltoken lb, ltoken rb)
{
  /* no attempt at error recovery...not really necessary */
  cstring tname;
  char *s;

  tname = ltoken_getRawString (lb);

  if (!cstring_equalLit (tname, "<"))
    {
      s = cstring_toCharsSafeO (message ("Invalid import token: %s", tname));
      ylerror (s);
      sfree (s);
    }

  tname = ltoken_getRawString (rb);

  if (!cstring_equalLit (tname, ">"))
    {
      s = cstring_toCharsSafeO (message ("Invalid import token: %s", tname));
      ylerror (s);
      sfree (s);
    }
}

